% File src/library/base/man/Extract.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Copyright 2002-2012 The R Foundation
% Distributed under GPL 2 or later

\name{Extract}
\title{Extract or Replace Parts of an Object}
\alias{Extract}
\alias{Subscript}
\alias{[}
\alias{[.listof}
\alias{[.simple.list}
\alias{[.Dlist}
\alias{[[}
\alias{$}
\alias{getElement}
\alias{[<-}
\alias{[[<-}
\alias{$<-}
\concept{delete}

\description{
ベクトル，行列，配列，そしてリストに作用し，一部分を取り出したり
置き換える．
}

\usage{
x[i]
x[i, j, \dots , drop = TRUE]
x[[i, exact = TRUE]]
x[[i, j, \dots, exact = TRUE]]

getElement(object, name)

x[i] <- value
x[i, j, \dots] <- value
x[[i]] <- value
x$i <- value
}

\arguments{
  \item{x, object}{
    要素を取り出したり，置き換えるオブジェクト．
  }
  \item{i, j, \dots}{
取り出す，または置き換える要素を指定する添字．添字は 
 \code{numeric} か \code{character} ベクトル，または空(欠損)もしくは 
 \code{NULL}． 数値変数は \code{\link{as.integer}} を用いて
(従ってゼロへ向かって切り詰められる)整数に強制変換される．
文字列ベクトルはオブジェクトの \code{\link{names}} と
マッチングされる(もしくは行列/配列に対しては the \code{\link{dimnames}} と):
詳細は以下の \sQuote{文字添字} を見よ．

\code{[} による添字操作についてだけ: \code{i}, \code{j}, \code{\dots} は
論理値ベクトルであってよく，選択すべき要素/切片を指示する．
そうしたベクトルは必要なら対応する範囲にマッチするまでリサイクルされる．
\code{i}, \code{j}, \code{\dots} はまた負整数でもよく，
選択から除外すべき要素/切片を指示する．

\code{[} により配列を添え字操作する際は，単一の引数 \code{i} は
 \code{x} の次元と同じ数の行を持つ行列でも良い．
結果はすると \code{i} の各行中の添字の集合に対応する要素を持つベクトルになる．

添字値 \code{NULL} はあたかもそれが \code{integer(0)} であるかのように扱われる．
  }
  \item{name}{
文字通りの文字列や \link{name} (\link{backtick} で引用化
されているかもしれない)．取り出しにたいしては，これは普通
(以下の \sQuote{Environments} を見よ)オブジェクトの \code{\link{names}} 
に部分マッチングされる．
  }
  \item{drop}{行列や配列用．もし \code{TRUE} ならば，結果は
可能な最小の次元(実例を見よ)に強制変換される．これは要素の
取り出しに対してだけ有効で，置き換えには無効である．
詳細は \code{\link{drop}} を見よ．
  }
  \item{exact}{文字列ベクトルにより取り出す際に \code{[[} の可能な部分マッチング
を制御する(多くのオブジェクトに対して，しかし以下の 
 \sQuote{環境} を見よ)．既定では部分マッチングをしない．
値 \code{NA} は部分マッチングを許すが，もしそうなれば警告が出る．
値 \code{FALSE} は警告なしに部分マッチングを許す．}
  \item{value}{典型的には \code{x} と類似したクラスの配列風 \R オブジェクト．}
}

\details{
これらの演算は総称的である．特定のオブジェクトクラスに対する添字操作を
処理するメソッドを書くことが出来る．\link{InternalMethods} や 
\code{\link{[.data.frame}} そして \code{\link{[.factor}} を見よ．
ここでの記述は既定のメソッドだけに当てはまる．置き換え関数
\code{[<-}, \code{[[<-} そして \code{$<-} が表現式の付値側に置かれるときは
個別にメソッドが必要になることを注意しよう．

\code{[}, \code{[[} そして \code{$} の最も需要な違いは
\code{[} はひとつ以上の要素を選択できるが，他の二つはひとつの要素
を選ぶことである．

既定メソッドは原子的ベクトル，行列/配列，そして再帰的(リスト風，
\code{\link{is.recursive}}) オブジェクトを参照)に対して少々異なった
作用を持つので，以下の再帰的オブジェクトの節だけで議論される．

部分操作(空インデックスを除く)は \code{names}, \code{dim} そして \code{dimnames}
を除くすべての属性を取り除く．

添字操作は取り出しに対しては表現式の右辺，置き換えに対しては左辺に
置くことが出来る．添字表現が付値の左辺に登場する(\emph{部分付値}として知られている)と
\code{x} の一部分が付値の右辺の値で置き換えられる．
この場合文字添字の部分マッチングは行われず，左辺は値を受け入れるため
必要に応じて強制変換される．ベクトルに対しては，結果は
 \code{x} と \code{value} の型の順序 raw < logical < integer < double < complex < character <
  list < expression で高い方になる．
 属性は(\code{names}, \code{dim} そして \code{dimnames} は適当に調整されるが)
 保存される． 部分付値は逐次的に行われるので，
 ある添字が複数回指定されるとその添字に対して最後に付値される値が結果になる．
 
 (例えば関数のような)部分操作ができないオブジェクトにこれらの操作のいずれかを
 適用するとエラーになる．
}

\section{原子ベクトル}{
添字操作の通常の形式は \code{[} である．\code{[[} は単一の要素を
属性 \code{\link{names}} 抜きで選択するのに使うことが出来る．
一方で \code{c(abc = 123)[1]} の様に \code{[} は属性を保存する．

添字オブジェクト \code{i} は数値，論理値，文字 もしくは空で良い．
因子による添字操作は可能で，プリントされる文字値(このためには
\code{[as.character(i)]} を使う)ではなく数値コード
(\code{\link{factor}} を参照)による添字操作と同値である．

空の添字はすべての値を選択する：これはすべての項目を置き換えるが
\code{\link{attributes}} を保存する際に最もしばしば使われる．
}

\section{行列と配列}{
行列と配列は次元属性を持つベクトルであり，単一の添字を持つすべてのベクトルの
添字操作法が使える．結果は名前無しのベクトルになる．例外は \code{x} が
1次元の時で，結果は1次元配列になる．

\eqn{k}-次元配列の添字操作の一番普通の添字操作の形式は
\eqn{k} 個の添字を \code{[} に与えることである．ベクトル添字操作と同じく，
添字は数値，論理値，文字, 空もしくは因子でも良い．
空の添字(コンマで区切られた空白)添字はその次元のすべての項目が選択されたことを
意味する．引数 \code{drop} はこの添字操作形に適用される．

添字操作の三つ目の形式は各次元毎に一つの列を持つ数値行列を使う：
添字行列の各行はすると配列の一つの要素を選択し，結果はベクトルになる．
添字行列には負の添字は許されない．\code{NA} とゼロは許される：
ゼロを含む添字行列の行は無視されるが，
\code{NA} を含む行は \code{NA} という結果になる．

各次元毎に一つの列を持つ文字行列を使う添字操作はもし配列が
次元名を持てば使用できる．数値行列を使った場合と同様に，
添字行列の各行が配列の一つの列を選択する．
添字はふさわしい次元名に対してマッチングされる．
\code{NA} が使え，結果は \code{NA} になる．
マッチしない添字及び空文字列 (\code{""}) は許されずエラーとなる．

行名(もしあれば)が結果の名前を与えるように添字化される時，
行列添字操作で得られるベクトルは \code{x} が1次元でない限り名前を
持たない．
}

\section{再帰的(リスト風)オブジェクト}{
\code{[} による添字操作は原子的ベクトルに似ており，指定された要素からなる
リストを選択する．

\code{[[} と \code{$} は共にリストの単一の要素を選択する．
主な違いは \code{$} は計算する添字を認めないが，
\code{[[} は認める点である．\code{x$name} は 
\code{x[["name", exact = FALSE]]} と同値である．
また， \code{[[} の部分マッチングの挙動は \code{exact} 引数を
使って制御出来る．

\code{getElement(x, name)} は \code{x[[name, exact = TRUE]]} の
号類であり，形式的クラスをもつ(S4)オブジェクトに対し \code{\link{slot}(x, name)} を
返すので，より幅広いリスト風オブジェクトへのアクセスを提供する．

\code{[} と \code{[[} は時折 \link{call}s と \link{expression} といった
他の再帰的オブジェクトに適用される．対リストは \code{[}で取り出しされるときは
リストに強制変換されるが，三つすべての演算が置き換えに使える．

\code{[[} はリストに再帰的に適用できるので，もし単一の添字
 \code{i} が長さ \code{p} のベクトルならば，\code{alist[[i]]} は
最後の添字操作以外の結果がすべてリストであれば，\code{alist[[i1]]\dots[[ip]]}
と同値である．

三つのすべての種類の置き換えで，値 \code{NULL} はリストの
対応項目を消し去ることを注意しよう．項目を \code{NULL} に
設定するには \code{x[i] <- list(NULL)} とする必要がある．

\code{$<-} が \code{NULL} である \code{x} に適用されると．それは
先ず \code{x} を \code{list()} に強制変換する．これはまた，
置き換え値 \code{value} が1より大きな長さを持つとき \code{[[<-} で
起きることでもある．
もし \code{value} が長さ 1 か 0 ならば，\code{x} は最初
型 \code{value} の長さゼロのベクトルに強制変換される．
}

\section{環境}{
\code{$} と \code{[[} はともに環境に適用できる．
文字添字だけが許され，部分マッチングはされない．
こうした演算子の構文は \code{get(i, env = x, inherits = FALSE)} のようになる．
マッチするものがないと \code{NULL} が返される．
置き換え版の \code{$<-} と \code{[[<-} もまた使える．
再び文字引数だけが許される．この場合の構文は
\code{assign(i, value, env = x, inherits = FALSE)} のようになる．
そうした付値は新しい結合を作り出したり，\code{x} の既存の
結合を変更したりする．
}

\section{添字操作における NA}{
取り出しにおいて，数値, 論理値 もしくは 文字の \code{NA} 添字は
未知の要素を選択し，従って対応する論理値，整数，数値，複素数値 もしくは文字の
 \code{NA}，リストならば  \code{NULL} を結果として返す．
(バイト型に対しては \code{00} を返す．)

置き換え(つまり付値の左辺値とした添字操作で使用)では \code{NA}
は置き換えるべきいかなる値も選択しない．右辺値のどの要素が使われるべきか
について曖昧さがあるので，これはもし右辺値が長さ1の時だけ許される
(従って二つの解釈は同一の結果を持つであろう)．
(ドキュメント化された S の挙動では \code{NA} 置き換え添字は
 \sQuote{どこにも行かない} が \code{value} の一つまでの要素を使う:
Becker \emph{et al} p.\sspace{}359．しかしながら，それは他の移植では
これまで真ではなかった．)
}

\section{引数のマッチング}{
これらの演算子はその添字引数を標準的な仕方ではマッチングしないことを
注意すべきである：引数名は無視され位置のマッチングだけが使われる．
従って \code{m[j = 2, i = 1]} は \code{m[2, 1]} と同地であり，
 \code{m[1, 2]} と等しくはない．

このことはそれらに対して定義されたメソッドには当てはまらないかもしれない．
例えば \code{\link{[.data.frame}} で説明されている \code{data.frame}
メソッドに対しては正しくない．これはもし \code{i} または \code{j} 
が名前付きなら警告がだされ，その場合はドキュメント化されていない
動作をする．

混乱を避けるために，添字引数に名前を使わないようにしよう
(しかし \code{drop} と \code{exact} は名前を持たねばならない)．
}

\section{S4 メソッド}{
これらの演算子はまた暗黙のうちに S4 総称的であるが，プリミティブであるため，
S4 メソッドは S4 オブジェクトの \code{x} にだけ選択適用される．

%   not yet implemented
%   These operators are also implicit S4 generics, but the implementation
%   of the primitive functions will only dispatch S4 methods if one of the
%   arguments is an S4 object (it is no longer true that only the first
%   argument is checked).  Method signatures can include any formal
%   argument, but the primitive evaluation will only look for a method if
%   \code{\link{isS4}} would return \code{TRUE} for some argument.

\code{$} と \code{$<-} 演算子の暗黙の総称性は，
文法が \code{name} 引数としてシンボルや文字定数だけを認めるため，
それらのシグネチャ中に  \code{name} を持たない．
}

\section{文字添字}{
文字添字はある種の状況では部分設定されるオブジェクトの名前もしくは
次元名に部分的にマッチングされることが出来る
(しかし部分付値に対しては決して行われない)．
S (Becker \emph{et al} p.\sspace{}358)) とは異なり, \R は \code{[}
で取り出す際には決して部分マッチングを行わず，部分マッチングは既定では
 \code{[[} により使われない(引数 \code{exact} を見よ)．

従って既定の動作では \code{$} で再帰的オブジェクトから取り出す時(環境を除く)
だけ部分マッチングを使う．この場合ですら
\code{\link{options}(warnPartialMatchDollar = TRUE)} で警告を出すことが出来る．

空の (\code{""}) 引数も \code{NA} 引数もいかなる名前にもマッチしない．
空もしくは欠損した名前にすらである．
もしあるオブジェクトが名前や適当な次元名を持たなければ，
それらはすべて \code{""} とされ，従って何物にもマッチしない．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}

\seealso{
  名前へのマッチングについては \code{\link{names}}，そして 
  部分マッチングについては \code{\link{pmatch}}．

  \code{\link{list}}, \code{\link{array}}, \code{\link{matrix}}．

  データフレームと因子に対する操作の挙動に対する
  \code{\link{[.data.frame}} と \code{\link{[.factor}}．

  演算子の優先順序については \code{\link{Syntax}}， 
  添字操作の詳細はマニュアル\sQuote{R Language Definition}．


   null オブジェクトの添字操作は \code{\link{NULL}}．
}
%% Fixme: Link (to html in 'help.start()', pdf from 'ref manual',
%% 'info' from ESS, see \url{http://cran.R-project.org/manuals.html}.

\examples{
x <- 1:12
m <- matrix(1:6, nrow = 2, dimnames = list(c("a", "b"), LETTERS[1:3]))
li <- list(pi = pi, e = exp(1))
x[10]                  # x の10番目の要青
x <- x[-1]            # x の最初の要素を削除
m[1,]                  # 行列 m の最初の行
m[1, , drop = FALSE]  # 1 行の行列
m[,c(TRUE,FALSE,TRUE)] # 論理添字操作
m[cbind(c(1,2,1),3:1)] # 行列数値添字
ci <- cbind(c("a", "b", "a"), c("A", "C", "B"))
m[ci]                  # 行列文字添字
m <- m[,-1]        # m の最初の列を削除
li[[1]]                 # リスト li の最初の要素
y <- list(1, 2, a = 4, 5)
y[c(3, 4)]            # y の要素 3 と 4 を含むリスト
y$a                    # a という名前の y の要素

## 非整数添字は打ち切られる：
(i <- 3.999999999) # "4" is printed
(1:5)[i]  # 3

## 名前付きの原子ベクトル, "[" と "[[" を比較:
nx <- c(Abc = 123, pi = pi)
nx[1] ; nx["pi"]  # 名前を保存， "[[" は保存しない：
nx[[1]] ; nx[["pi"]]
\dontshow{
stopifnot(identical(names(nx[1]), "Abc"),
        identical(names(nx["pi"]), "pi"),
        is.null(names(nx[["Abc"]])), is.null(names(nx[[2]])))
}
## recursive indexing into lists
z <- list(a = list(b = 9, c = "hello"), d = 1:5)
unlist(z)
z[[c(1, 2)]]
z[[c(1, 2, 1)]]  # both "hello"
z[[c("a", "b")]] <- "new"
unlist(z)

## 環境に対して $ と [[ を比較
e1 <- new.env()
e1$a <- 10
e1[["a"]]
e1[["b"]] <- 20
e1$b
ls(e1)

## 部分マッチング - もしかすると警告あり：
stopifnot(identical(li$p, pi))
op <- options(warnPartialMatchDollar = TRUE)
stopifnot( identical(li$p, pi), #-- 警告
  inherits(tryCatch (li$p, warning = identity), "warning"))
## 警告オプションを反転
if(is.null(op[[1]])) op[[1]] <- FALSE; options(op)
}
\keyword{array}
\keyword{list}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Extract.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Copyright 2002-2012 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{Extract}
%\title{Extract or Replace Parts of an Object}
%\alias{Extract}
%\alias{Subscript}
%\alias{[}
%\alias{[.listof}
%\alias{[.simple.list}
%\alias{[.Dlist}
%\alias{[[}
%\alias{$}
%\alias{getElement}
%\alias{[<-}
%\alias{[[<-}
%\alias{$<-}
%\concept{delete}
%
%\description{
%  Operators acting on vectors, matrices, arrays and lists to extract or
%  replace parts.
%}
%
%\usage{
%x[i]
%x[i, j, \dots , drop = TRUE]
%x[[i, exact = TRUE]]
%x[[i, j, \dots, exact = TRUE]]
%x$name
%getElement(object, name)
%
%x[i] <- value
%x[i, j, \dots] <- value
%x[[i]] <- value
%x$i <- value
%}
%
%\arguments{
%  \item{x, object}{
%    object from which to extract element(s) or in which to replace element(s).
%  }
%  \item{i, j, \dots}{
%    indices specifying elements to extract or replace.  Indices are
%    \code{numeric} or \code{character} vectors or empty (missing) or
%    \code{NULL}.  Numeric values are coerced to integer as by
%    \code{\link{as.integer}} (and hence truncated towards zero).
%    Character vectors will be matched to the \code{\link{names}} of the
%    object (or for matrices/arrays, the \code{\link{dimnames}}):
%    see \sQuote{Character indices} below for further details.
%
%    For \code{[}-indexing only: \code{i}, \code{j}, \code{\dots} can be
%    logical vectors, indicating elements/slices to select.  Such vectors
%    are recycled if necessary to match the corresponding extent.
%    \code{i}, \code{j}, \code{\dots} can also be negative integers,
%    indicating elements/slices to leave out of the selection.
%
%    When indexing arrays by \code{[} a single argument \code{i} can be a
%    行列 with as many columns as there are dimensions of \code{x}; the
%    result is then a vector with elements corresponding to the sets of
%    indices in each row of \code{i}.
%
%    An index value of \code{NULL} is treated as if it were \code{integer(0)}.
%  }
%  \item{name}{
%    A literal character string or a \link{name} (possibly \link{backtick}
%    quoted).  For extraction, this is normally (see under
%    \sQuote{Environments}) partially matched to the \code{\link{names}}
%    of the object.
%  }
%  \item{drop}{For matrices and arrays.  If \code{TRUE} the result is
%    coerced to the lowest possible dimension (see the examples).  This
%    only works for extracting elements, not for the replacement.  See
%    \code{\link{drop}} for further details.
%  }
%  \item{exact}{Controls possible partial matching of \code{[[} when
%    extracting by a character vector (for most objects, but see under
%    \sQuote{Environments}).  The default is no partial matching.  Value
%    \code{NA} allows partial matching but issues a warning when it
%    occurs.  Value \code{FALSE} allows partial matching without any
%    warning.}
%  \item{value}{typically an array-like \R object of a similar class as
%    \code{x}.}
%}
%
%\details{
%  These operators are generic.  You can write methods to handle indexing
%  of specific classes of objects, see \link{InternalMethods} as well as
%  \code{\link{[.data.frame}} and \code{\link{[.factor}}.  The
%  descriptions here apply only to the default methods.  Note that
%  separate methods are required for the replacement functions
%  \code{[<-}, \code{[[<-} and \code{$<-} for use when indexing occurs on
%  the assignment side of an expression.
%
%  The most important distinction between \code{[}, \code{[[} and
%  \code{$} is that the \code{[} can select more than one element whereas
%  the other two select a single element.
%
%  The default methods work somewhat differently for atomic vectors,
%  matrices/arrays and for recursive (list-like, see
%  \code{\link{is.recursive}}) objects.  \code{$} is only valid for
%  recursive objects, and is only discussed in the section below on
%  recursive objects.
%
%  Subsetting (except by an empty index) will drop all attributes except
%  \code{names}, \code{dim} and \code{dimnames}.
%
%  Indexing can occur on the right-hand-side of an expression for
%  extraction, or on the left-hand-side for replacement.  When an index
%  expression appears on the left side of an assignment (known as
%  \emph{subassignment}) then that part of \code{x} is set to the value
%  of the right hand side of the assignment.  In this case no partial
%  matching of character indices is done, and the left-hand-side is
%  coerced as needed to accept the values.  For vectors, the answer will
%  be of the higher of the types of \code{x} and \code{value} in the
%  hierarchy raw < logical < integer < double < complex < character <
%  list < expression.  Attributes are preserved (although \code{names},
%  \code{dim} and \code{dimnames} will be adjusted suitably).
%  Subassignment is done sequentially, so if an index is specified more
%  than once the latest assigned value for an index will result.
%
%  It is an error to apply any of these operators to an object which is
%  not subsettable (e.g., a function).
%}
%
%\section{Atomic vectors}{
%  The usual form of indexing is \code{[}.  \code{[[} can be used to
%  select a single element \emph{dropping} \code{\link{names}}, whereas
%  \code{[} keeps them, e.g., in \code{c(abc = 123)[1]}.
%
%  The index object \code{i} can be numeric, logical, character or empty.
%  Indexing by factors is allowed and is equivalent to indexing by the
%  numeric codes (see \code{\link{factor}}) and not by the character
%  values which are printed (for which use \code{[as.character(i)]}).
%
%  An empty index selects all values: this is most often used to replace
%  all the entries but keep the \code{\link{attributes}}.
%}
%
%\section{Matrices and arrays}{
%  Matrices and arrays are vectors with a dimension attribute and so all
%  the vector forms of indexing can be used with a single index.  The
%  result will be an unnamed vector unless \code{x} is one-dimensional
%  when it will be a one-dimensional array.
%
%  The most common form of indexing a \eqn{k}-dimensional array is to
%  specify \eqn{k} indices to \code{[}.  As for vector indexing, the
%  indices can be numeric, logical, character, empty or even factor.
%  An empty index (a comma separated blank) indicates that all entries in
%  that dimension are selected.
%  The argument \code{drop} applies to this form of indexing.
%
%  A third form of indexing is via a numeric 行列 with the one column
%  for each dimension: each row of the index 行列 then selects a single
%  element of the array, and the result is a vector.  Negative indices are
%  not allowed in the index 行列.  \code{NA} and zero values are allowed:
%  rows of an index 行列 containing a zero are ignored, whereas rows
%  containing an \code{NA} produce an \code{NA} in the result.
%
%  Indexing via a character 行列 with one column per dimensions is also
%  supported if the array has dimension names.  As with numeric 行列
%  indexing, each row of the index 行列 selects a single element of the
%  array.  Indices are matched against the appropriate dimension names.
%  \code{NA} is allowed and will produce an \code{NA} in the result.
%  Unmatched indices as well as the empty string (\code{""}) are not
%  allowed and will result in an error.
%
%  A vector obtained by 行列 indexing will be unnamed unless \code{x}
%  is one-dimensional when the row names (if any) will be indexed to
%  provide names for the result.
%}
%
%\section{Recursive (list-like) objects}{
%  Indexing by \code{[} is similar to atomic vectors and selects a list
%  of the specified element(s).
%
%  Both \code{[[} and \code{$} select a single element of the list.  The
%  main difference is that \code{$} does not allow computed indices,
%  whereas \code{[[} does.  \code{x$name} is equivalent to
%  \code{x[["name", exact = FALSE]]}.  Also, the partial matching
%  behavior of \code{[[} can be controlled using the \code{exact} argument.
%
%  \code{getElement(x, name)} is a version of \code{x[[name, exact = TRUE]]}
%  which for formally classed (S4) objects returns \code{\link{slot}(x, name)},
%  hence providing access to even more general list-like objects.
%
%  \code{[} and \code{[[} are sometimes applied to other recursive
%  objects such as \link{call}s and \link{expression}s.  Pairlists are
%  coerced to lists for extraction by \code{[}, but all three operators
%  can be used for replacement.
%
%  \code{[[} can be applied recursively to lists, so that if the single
%  index \code{i} is a vector of length \code{p}, \code{alist[[i]]} is
%  equivalent to \code{alist[[i1]]\dots[[ip]]} providing all but the
%  final indexing results in a list.
%
%  Note that in all three kinds of replacement, a value of \code{NULL}
%  deletes the corresponding item of the list.  To set entries to
%  \code{NULL}, you need \code{x[i] <- list(NULL)}.
%
%  When \code{$<-} is applied to a \code{NULL} \code{x}, it first coerces
%  \code{x} to \code{list()}.  This is what also happens with \code{[[<-}
%  if the replacement value \code{value} is of length greater than one:
%  if \code{value} has length 1 or 0, \code{x} is first coerced to a
%  zero-length vector of the type of \code{value}.
%}
%
%\section{Environments}{
%  Both \code{$} and \code{[[} can be applied to environments.  Only
%  character indices are allowed and no partial matching is done.  The
%  semantics of these operations are those of \code{get(i, env = x,
%    inherits = FALSE)}.  If no match is found then \code{NULL} is
%  returned.  The replacement versions, \code{$<-} and \code{[[<-}, can
%  also be used.  Again, only character arguments are allowed.  The
%  semantics in this case are those of \code{assign(i, value, env = x,
%    inherits = FALSE)}.  Such an assignment will either create a new
%  binding or change the existing binding in \code{x}.
%}
%
%\section{NAs in indexing}{
%  When extracting, a numerical, logical or character \code{NA} index picks
%  an unknown element and so returns \code{NA} in the corresponding
%  element of a logical, integer, numeric, complex or character result,
%  and \code{NULL} for a list.  (It returns \code{00} for a raw result.)
%
%  When replacing (that is using indexing on the lhs of an
%  assignment) \code{NA} does not select any element to be replaced.  As
%  there is ambiguity as to whether an element of the rhs should
%  be used or not, this is only allowed if the rhs value is of length one
%  (so the two interpretations would have the same outcome).
%  (The documented behaviour of S was that an \code{NA} replacement index
%  \sQuote{goes nowhere} but uses up an element of \code{value}:
%  Becker \emph{et al} p.\sspace{}359.  However, that has not been true of
%  other implementations.)
%}
%
%\section{Argument matching}{
%  Note that these operations do not match their index arguments in the
%  standard way: argument names are ignored and positional matching only is
%  used.  So \code{m[j = 2, i = 1]} is equivalent to \code{m[2, 1]} and
%  \strong{not} to \code{m[1, 2]}.
%
%  This may not be true for methods defined for them; for example it is
%  not true for the \code{data.frame} methods described in
%  \code{\link{[.data.frame}} which warn if \code{i} or \code{j}
%  is named and have undocumented behaviour in that case.
%
%  To avoid confusion, do not name index arguments (but \code{drop} and
%  \code{exact} must be named).
%}
%
%\section{S4 methods}{
%  These operators are also implicit S4 generics, but as primitives, S4
%  methods will be dispatched only on S4 objects \code{x}.
%
%%   not yet implemented
%%   These operators are also implicit S4 generics, but the implementation
%%   of the primitive functions will only dispatch S4 methods if one of the
%%   arguments is an S4 object (it is no longer true that only the first
%%   argument is checked).  Method signatures can include any formal
%%   argument, but the primitive evaluation will only look for a method if
%%   \code{\link{isS4}} would return \code{TRUE} for some argument.
%
%  The implicit generics for the \code{$} and \code{$<-} operators do not
%  have \code{name} in their signature because the grammar only allows
%  symbols or string constants for the \code{name} argument.
%}
%
%\section{Character indices}{
%  Character indices can in some circumstances be partially matched (see
%  \code{\link{pmatch}}) to the names or dimnames of the object being
%  subsetted (but never for subassignment).  Unlike S (Becker \emph{et
%  al} p.\sspace{}358)), \R never uses partial matching when extracting by
%  \code{[}, and partial matching is not by default used by \code{[[}
%  (see argument \code{exact}).
%
%  Thus the default behaviour is to use partial matching only when
%  extracting from recursive objects (except environments) by \code{$}.
%  Even in that case, warnings can be switched on by
%  \code{\link{options}(warnPartialMatchDollar = TRUE)}.
%
%  Neither empty (\code{""}) nor \code{NA} indices match any names, not
%  even empty nor missing names.  If any object has no names or
%  appropriate dimnames, they are taken as all \code{""} and so match
%  nothing.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%
%\seealso{
%  \code{\link{names}} for details of matching to names, and
%  \code{\link{pmatch}} for partial matching.
%
%  \code{\link{list}}, \code{\link{array}}, \code{\link{matrix}}.
%
%  \code{\link{[.data.frame}} and \code{\link{[.factor}} for the
%  behaviour when applied to data.frame and factors.
%
%  \code{\link{Syntax}} for operator precedence, and the
%  \sQuote{R Language Definition} manual about indexing details.
%
%
%  \code{\link{NULL}} for details of indexing null objects.
%}
%%% Fixme: Link (to html in 'help.start()', pdf from 'ref manual',
%%% 'info' from ESS, see \url{http://cran.R-project.org/manuals.html}.
%
%\examples{
%x <- 1:12
%m <- matrix(1:6, nrow = 2, dimnames = list(c("a", "b"), LETTERS[1:3]))
%li <- list(pi = pi, e = exp(1))
%x[10]                 # the tenth element of x
%x <- x[-1]            # delete the 1st element of x
%m[1,]                 # the first row of matrix m
%m[1, , drop = FALSE]  # is a 1-row matrix
%m[,c(TRUE,FALSE,TRUE)]# logical indexing
%m[cbind(c(1,2,1),3:1)]# matrix numeric index
%ci <- cbind(c("a", "b", "a"), c("A", "C", "B"))
%m[ci]                 # matrix character index
%m <- m[,-1]           # delete the first column of m
%li[[1]]               # the first element of list li
%y <- list(1, 2, a = 4, 5)
%y[c(3, 4)]            # a list containing elements 3 and 4 of y
%y$a                   # the element of y named a
%
%## non-integer indices are truncated:
%(i <- 3.999999999) # "4" is printed
%(1:5)[i]  # 3
%
%## named atomic vectors, compare "[" and "[[" :
%nx <- c(Abc = 123, pi = pi)
%nx[1] ; nx["pi"] # keeps names, whereas "[[" does not:
%nx[[1]] ; nx[["pi"]]
%\dontshow{
%stopifnot(identical(names(nx[1]), "Abc"),
%        identical(names(nx["pi"]), "pi"),
%        is.null(names(nx[["Abc"]])), is.null(names(nx[[2]])))
%}
%## recursive indexing into lists
%z <- list(a = list(b = 9, c = "hello"), d = 1:5)
%unlist(z)
%z[[c(1, 2)]]
%z[[c(1, 2, 1)]]  # both "hello"
%z[[c("a", "b")]] <- "new"
%unlist(z)
%
%## check $ and [[ for environments
%e1 <- new.env()
%e1$a <- 10
%e1[["a"]]
%e1[["b"]] <- 20
%e1$b
%ls(e1)
%
%## partial matching - possibly with warning :
%stopifnot(identical(li$p, pi))
%op <- options(warnPartialMatchDollar = TRUE)
%stopifnot( identical(li$p, pi), #-- a warning
%  inherits(tryCatch (li$p, warning = identity), "warning"))
%## revert the warning option:
%if(is.null(op[[1]])) op[[1]] <- FALSE; options(op)
%}
%\keyword{array}
%\keyword{list}
%
\encoding{UTF8}
