% File src/library/base/man/Extremes.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{Extremes}
\alias{max}
\alias{min}
\alias{pmax}
\alias{pmin}
\alias{pmax.int}
\alias{pmin.int}
\title{Maxima and Minima}
\description{
入力値の(並列)最大値と最小値を返す.
}
\usage{
max(\dots, na.rm = FALSE)
min(\dots, na.rm = FALSE)

pmax(\dots, na.rm = FALSE)
pmin(\dots, na.rm = FALSE)

pmax.int(\dots, na.rm = FALSE)
pmin.int(\dots, na.rm = FALSE)
}
\arguments{
  \item{\dots}{数値もしくは文字列変数(ノートを見よ)．}
  \item{na.rm}{欠損値を取り除くかどうかを指示する論理値．}
}
\details{
\code{max} と \code{min} は引数に現れるすべての値の最大値と最小値を返す．
もしすべてが整数か論理値なら \code{\link{integer}} を，
もしすべてが数値なら \code{\link{double}} を,
それ以外は文字列を返す．

もし \code{na.rm} が \code{FALSE} ならば，引数中の \code{NA} 値は
\code{NA} 値を返す．さもなければ \code{NA} 値は無視される．

数値的空集合の最大値と最小値は(この順序で) \code{+Inf} と 
\code{-Inf} となり，\emph{推移性}を保証する．例えば 
\code{min(x1, min(x2)) == min(x1, x2)}． 数値の \code{x} に対しては
\code{length(x) == 0} (要求されたなら欠損値を除いた後で)
であれば \code{max(x) == -Inf} と \code{min(x) == +Inf} となる．
しかしながら，\code{pmax} と \code{pmin} は，たとえ \code{na.rm = TRUE}
でも．もしすべての並列要素が \code{NA} であっても \code{NA} を返す．

\code{pmax} と \code{pmin} は引数として一つもしくは複数のベクトル(または行列)
を取り，\sQuote{並列}最大値(もしくは最小値)からなる一つのベクトルを返す．
結果の最初の要素はすべての引数の最初の要素の最大(小)値，
2番目の要素はすべての引数の2番目の要素の最大(小)値，云々．
(長さがゼロでない)短い入力は必要に応じてリサイクルされる．
\code{\link{names}} や \code{\link{dim}}) といった属性(\code{\link{attributes} 参照}
は(可能ならば)最初の引数からコピーされる．

\code{pmax.int} と \code{pmin.int} はすべての引数が原子的ベクトルでクラスが
無いときにだけ使われるより高速の内部バージョンである：
すべての属性は捨て去られる．(すべてのバージョンは比較するための順序を
持たないバイトベクトルと
複素数ベクトルに対して失敗することを注意しよう．)

\code{max} と \code{min} は総称的関数である：それらに対するメソッドを個別
にかグループ総称的
 \code{\link[=S3groupGeneric]{Summary}} 経由で書くことが出来る．
 これが上手く動作するためには，引数 \code{\dots} は名前無しでなければ
 ならず，選択適用は最初の引数に対してである．

定義から \code{NA} を含む数値ベクトルの min/max は \code{NaN} である．
例外は，たとえ \code{NaN} が更に含まれていても，\code{NA} を含む任意の
ベクトルの min/max は \code{NA} になる．
欠損値が何であろうと最大値は \code{Inf} になるが，
 \code{max(NA, Inf) == NA} であることを注意しよう．

文字列バージョンは辞書式順序でソートされる．
そしてこれは使用中のロケールの照合列に依存する： \sQuote{\link{Comparison}} に
対するヘルプが詳細を与える．
空の文字列ベクトルの max/min は文字 \code{NA} であると
定義されている．(\code{""} は最小の文字要素であるから最大は \code{""}
とすべきと考えることもできるが，最小に対する候補が無い．)
}
\value{
\code{min} と \code{max} に対しては長さ1のベクトル．
\code{pmin} または \code{pmax} に対しては入力ベクトルの最長長さの
ベクトル，もしくは入力の一方が長さゼロならば長さはゼロになる．

結果の方は階層 integer < double < character で最高になる
入力のそれになる．

数値入力だけがありすべてが空(可能な \code{NA} の除去後)ならば，
\code{min} と \code{max} に対する結果は倍精度実数
(\code{Inf} または \code{-Inf})となる．
}
\section{S4 メソッド}{
\code{max} と \code{min} は S4
 \code{\link[=S4groupGeneric]{Summary}} グループ総称的である．
それらに対するメソッドはシグネチャ \code{x, \dots, na.rm} を使わなければならない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\note{
\sQuote{数値}引数は整数，数値，論理値(整数に強制変換)型ベクトルである．
歴史的な理由から \code{NULL} は \code{integer(0)} と同値とされる．% PR#1283

\code{pmax} と \code{pmin} はまた適当な比較メソッドを持つクラス 
\code{is.na} と \code{rep} (引数のリサイクルが必要なとき)とともに使うことが出来る．
}
\seealso{
\emph{arg min} に対して，\code{\link{range}} (min と max 双方) と 
 \code{\link{which.min}} (\code{which.max})，
つまり極値が生じる位置．

プロットの注釈中の \code{min} には \sQuote{\link{plotmath}}．
}
\examples{
require(stats); require(graphics)
min(5:1, pi) #-> 一つの数
pmin(5:1, pi) #->  5つの数

x <- sort(rnorm(100));  cH <- 1.35
pmin(cH, quantile(x)) # 名前無し
pmin(quantile(x), cH) # 名前を持つ
plot(x, pmin(cH, pmax(-cH, x)), type = "b", main =  "Huber's function")

cut01 <- function(x) pmax(pmin(x, 1), 0)
curve(      x^2 - 1/4, -1.4, 1.5, col = 2)
curve(cut01(x^2 - 1/4), col = "blue", add = TRUE, n = 500)
## pmax(), pmin() は*最初の*引数の属性を保つ
D <- diag(x = (3:1)/4) ; n0 <- numeric()
stopifnot(identical(D,  cut01(D) ),
          identical(n0, cut01(n0)),
          identical(n0, cut01(NULL)),
          identical(n0, pmax(3:1, n0, 2)),
          identical(n0, pmax(n0, 4)))
}
\keyword{univar}
\keyword{arith}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Extremes.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Extremes}
%\alias{max}
%\alias{min}
%\alias{pmax}
%\alias{pmin}
%\alias{pmax.int}
%\alias{pmin.int}
%\title{Maxima and Minima}
%\description{
%  Returns the (parallel) maxima and minima of the input values.
%}
%\usage{
%max(\dots, na.rm = FALSE)
%min(\dots, na.rm = FALSE)
%
%pmax(\dots, na.rm = FALSE)
%pmin(\dots, na.rm = FALSE)
%
%pmax.int(\dots, na.rm = FALSE)
%pmin.int(\dots, na.rm = FALSE)
%}
%\arguments{
%  \item{\dots}{numeric or character arguments (see Note).}
%  \item{na.rm}{a logical indicating whether missing values should be
%    removed.}
%}
%\details{
%  \code{max} and \code{min} return the maximum or minimum of \emph{all}
%  the  values present in their arguments, as \code{\link{integer}} if
%  all are \code{logical} or \code{integer}, as \code{\link{double}} if
%  all are numeric, and character otherwise.
%
%  If \code{na.rm} is \code{FALSE} an \code{NA} value in any of the
%  arguments will cause a value of \code{NA} to be returned, otherwise
%  \code{NA} values are ignored.
%
%  The minimum and maximum of a numeric empty set are \code{+Inf} and
%  \code{-Inf} (in this order!) which ensures \emph{transitivity}, e.g.,
%  \code{min(x1, min(x2)) == min(x1, x2)}.  For numeric \code{x}
%  \code{max(x) == -Inf} and \code{min(x) == +Inf}
%  whenever \code{length(x) == 0} (after removing missing values if
%  requested).  However, \code{pmax} and \code{pmin} return
%  \code{NA} if all the parallel elements are \code{NA} even for
%  \code{na.rm = TRUE}.
%
%  \code{pmax} and \code{pmin} take one or more vectors (or matrices) as
%  arguments and return a single vector giving the \sQuote{parallel}
%  maxima (or minima) of the vectors.  The first element of the result is
%  the maximum (minimum) of the first elements of all the arguments, the
%  second element of the result is the maximum (minimum) of the second
%  elements of all the arguments and so on.  Shorter inputs (of non-zero
%  length) are recycled if necessary.  Attributes (see
%  \code{\link{attributes}}: such as \code{\link{names}} or
%  \code{\link{dim}}) are copied from the first argument (if applicable).
%
%  \code{pmax.int} and \code{pmin.int} are faster internal versions only
%  used when all arguments are atomic vectors and there are no classes:
%  they drop all attributes.  (Note that all versions fail for raw and
%  complex vectors since these have no ordering.)
%
%  \code{max} and \code{min} are generic functions: methods can be
%  defined for them individually or via the
%  \code{\link[=S3groupGeneric]{Summary}} group generic.  For this to
%  work properly, the arguments \code{\dots} should be unnamed, and
%  dispatch is on the first argument.
%
%  By definition the min/max of a numeric vector containing an \code{NaN}
%  is \code{NaN}, except that the min/max of any vector containing an
%  \code{NA} is \code{NA} even if it also contains an \code{NaN}.
%  Note that \code{max(NA, Inf) == NA} even though the maximum would be
%  \code{Inf} whatever the missing value actually is.
%
%  Character versions are sorted lexicographically, and this depends on
%  the collating sequence of the locale in use: the help for
%  \sQuote{\link{Comparison}} gives details.  The max/min of an empty
%  character vector is defined to be character \code{NA}.  (One could
%  argue that as \code{""} is the smallest character element, the maximum
%  should be \code{""}, but there is no obvious candidate for the
%  minimum.)
%}
%\value{
%  For \code{min} or \code{max}, a length-one vector.  For \code{pmin} or
%  \code{pmax}, a vector of length the longest of the input vectors, or
%  length zero if one of the inputs had zero length.
%
%  The type of the result will be that of the highest of the inputs in
%  the hierarchy integer < double < character.
%
%  For \code{min} and \code{max} if there are only numeric inputs and all
%  are empty (after possible removal of \code{NA}s), the result is double
%  (\code{Inf} or \code{-Inf}).
%}
%\section{S4 methods}{
%  \code{max} and \code{min} are part of the S4
%  \code{\link[=S4groupGeneric]{Summary}} group generic.  Methods
%  for them must use the signature \code{x, \dots, na.rm}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\note{
%  \sQuote{Numeric} arguments are vectors of type integer and numeric,
%  and logical (coerced to integer).  For historical reasons, \code{NULL}
%  is accepted as equivalent to \code{integer(0)}.% PR#1283
%
%  \code{pmax} and \code{pmin} will also work on classed objects with
%  appropriate methods for comparison, \code{is.na} and \code{rep} (if
%  recycling of arguments is needed).
%}
%\seealso{
%  \code{\link{range}} (\emph{both} min and max) and
%  \code{\link{which.min}} (\code{which.max}) for the \emph{arg min},
%  i.e., the location where an extreme value occurs.
%
%  \sQuote{\link{plotmath}} for the use of \code{min} in plot annotation.
%}
%\examples{
%require(stats); require(graphics)
% min(5:1, pi) #-> one number
%pmin(5:1, pi) #->  5  numbers
%
%x <- sort(rnorm(100));  cH <- 1.35
%pmin(cH, quantile(x)) # no names
%pmin(quantile(x), cH) # has names
%plot(x, pmin(cH, pmax(-cH, x)), type = "b", main =  "Huber's function")
%
%cut01 <- function(x) pmax(pmin(x, 1), 0)
%curve(      x^2 - 1/4, -1.4, 1.5, col = 2)
%curve(cut01(x^2 - 1/4), col = "blue", add = TRUE, n = 500)
%## pmax(), pmin() preserve attributes of *first* argument
%D <- diag(x = (3:1)/4) ; n0 <- numeric()
%stopifnot(identical(D,  cut01(D) ),
%          identical(n0, cut01(n0)),
%          identical(n0, cut01(NULL)),
%          identical(n0, pmax(3:1, n0, 2)),
%          identical(n0, pmax(n0, 4)))
%}
%\keyword{univar}
%\keyword{arith}
%
\encoding{UTF8}
