% File src/library/base/man/all.equal.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{all.equal}
\title{Test if Two Objects are (Nearly) Equal}
\alias{all.equal}
\alias{all.equal.default}
\alias{all.equal.numeric}
\alias{all.equal.character}
\alias{all.equal.environment}
\alias{all.equal.envRefClass}
\alias{all.equal.factor}
\alias{all.equal.formula}
\alias{all.equal.list}
\alias{all.equal.language}
\alias{all.equal.POSIXt}
\alias{all.equal.raw}
\alias{attr.all.equal}
\concept{numerical equality}
\concept{approximately equal}
\concept{equality testing}
\usage{
all.equal(target, current, \dots)

\method{all.equal}{numeric}(target, current,
          tolerance = .Machine$double.eps ^ 0.5, scale = NULL,
          \dots, check.attributes = TRUE)

\method{all.equal}{list}(target, current, \dots,
          check.attributes = TRUE, use.names = TRUE)

\method{all.equal}{environment}(target, current, all.names=TRUE, \dots)

\method{all.equal}{POSIXt}(target, current, \dots, tolerance = 1e-3, scale)


attr.all.equal(target, current, \dots,
               check.attributes = TRUE, check.names = TRUE)
}
\arguments{
  \item{target}{\R オブジェクト．}
  \item{current}{他の \R オブジェクトで \code{target} と比較される．}
  \item{\dots}{異なったメソッドに対する追加引数．特に数値比較に対する次の二つ：}
  \item{tolerance}{数値 \eqn{\ge} 0. \code{tolerance} 以下の差異は報告されない．既定値は
    \code{1.5e-8} に近い．}
  \item{scale}{数値スカラr > 0 (もしくは \code{NULL}). \sQuote{詳細}を見よ．}
  \item{check.attributes}{\code{target} と \code{current} の属性
(名前以外の)を比較すべきかどうかを指示する論理値．}
  \item{use.names}{logical indicating if \code{\link{list}} comparison
\code{\link{list}} の比較で異なった成分を整数添字ではなく名前で報告するかどうかを
指示する論理値．これは \code{\dots} の後に来るためその名前を完全に指定する必要があることを
注意する．}
  \item{all.names}{\dQuote{隠し}オブジェクトが環境中でも比較されるべきかどうかを指示する
 \code{\link{ls}} に引き渡される論理値．}
  \item{check.names}{\code{target} と \code{current} の \code{\link{names}(.)} を比較すべきかどうかを
指示する論理値．}
}
\description{
    \code{all.equal(x, y)} は \R オブジェクト \code{x} と \code{y} が
\sQuote{ほぼ等しいか} をテストし比較するユーティリティである．もしそれらが等しくなければ
比較は更にある程度行われ，差異の報告がされる．
\code{all.equal} を \code{if} 節で使わないこと---もし適当なら \code{isTRUE(all.equal(....))} か 
  \code{\link{identical}} を使う．
}
\details{
  \code{all.equal} は総称的関数で， \code{target} 引数に関してメソッドを
選択適用する．利用可能なメソッドについては \code{\link{methods}("all.equal")} を
使うが，既定のメソッドもある種の選択適用を行う．例えばバイト型のターゲットに対しては
raw メソッドを使う．

 \code{\dots} に続く引数は(未省略の)名前で指定しなければならないことを思い出そう．
それらの幾つかは \R 3.1.0 以前では \code{\dots} の前にあった．
\code{\dots} 中に名前無しの引数を渡すことは，異なったメソッドで異なった引数にマッチするので，
勧められない．

\code{scale = NULL} (既定) に対する数値比較は，ゼロに近くなければ，典型的に
\emph{相対差}スケールで行われる．
最初に二つの数値ベクトルの平均絶対誤差が計算される．
もしこれが \code{tolerance} より小さいか有限でなければ絶対誤差が使われる．
さもなければ \code{target} 値による相対誤差スケールが使われる．
(これらの比較は \code{target} が \code{\link{NA}}でなく \code{current}
と異なる時だけ計算されることを注意する．)

もし \code{scale} が正なら，絶対比較は \code{scale} によるスケーリング(除算)の
後で行われる．

複素数値の \code{target} に対しては差のモジュラス (\code{\link{Mod}}) が
使われる：\code{all.equal.numeric} が呼び出されるので引数 
 \code{tolerance} と \code{scale} が利用できる．

\code{\link{list}} メソッドは \code{target} と \code{current} の成分を再帰的に比較する．
双方が\dQuote{リスト風}である限りすべての他の引数が引き渡される．
つまり \code{\link{is.vector}} か \code{\link{is.list}} が実行される．

\code{\link{environment}} メソッドは \code{list} メソッド経由で実行され，
また参照クラスに対しても使われる(特定の \code{all.equal} メソッドが定義されていない限り)．

date-time クラスに対するメソッドは既定で
  \code{tolerance = 0.001} 秒の許容度を許し，\code{scale} を無視する．

  \code{attr.all.equal} は属性の比較に対して用いられ，
\code{NULL} か \code{character} ベクトルを返す．
}
\value{
  \code{TRUE} (\code{attr.all.equal} に対しては \code{NULL}) か 
  \code{\link{mode}} \code{"character"} のベクトルで，
  \code{target} と \code{current} 間の違いを説明する．  
}
\references{
  Chambers, J. M. (1998)
  \emph{Programming with Data. A Guide to the S Language}.
  Springer (\code{=} に関して).
}
\seealso{正確な一致性のテストには \code{\link{identical}}, \code{\link{isTRUE}},
  \code{\link{==}}，そして \code{\link{all}}．
}
\examples{
all.equal(pi, 355/113)
# 十分正確ではない(既定の許容度) > 相対誤差

d45 <- pi*(1/4 + 1:10)
stopifnot(
all.equal(tan(d45), rep(1, 10)))          # TRUE, しかし
all      (tan(d45) == rep(1, 10))         # FALSE, 正確に一致しないから
all.equal(tan(d45), rep(1, 10), tolerance = 0)  # 違いを見るには

## 上級: 環境の同等性
ae <- all.equal(as.environment("package:stats"),
                asNamespace("stats"))
stopifnot(is.character(ae), length(ae) > 10,
          ##  R <= 3.1.1 では不正確に "等しいと見做される" とされた
          all.equal(asNamespace("stats"), asNamespace("stats")))
}
\keyword{programming}% is.*
\keyword{utilities}
\keyword{logic}
\keyword{arith}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/all.equal.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{all.equal}
%\title{Test if Two Objects are (Nearly) Equal}
%\alias{all.equal}
%\alias{all.equal.default}
%\alias{all.equal.numeric}
%\alias{all.equal.character}
%\alias{all.equal.environment}
%\alias{all.equal.envRefClass}
%\alias{all.equal.factor}
%\alias{all.equal.formula}
%\alias{all.equal.list}
%\alias{all.equal.language}
%\alias{all.equal.POSIXt}
%\alias{all.equal.raw}
%\alias{attr.all.equal}
%\concept{numerical equality}
%\concept{approximately equal}
%\concept{equality testing}
%\usage{
%all.equal(target, current, \dots)
%
%\method{all.equal}{numeric}(target, current,
%          tolerance = .Machine$double.eps ^ 0.5, scale = NULL,
%          \dots, check.attributes = TRUE)
%
%\method{all.equal}{list}(target, current, \dots,
%          check.attributes = TRUE, use.names = TRUE)
%
%\method{all.equal}{environment}(target, current, all.names=TRUE, \dots)
%
%\method{all.equal}{POSIXt}(target, current, \dots, tolerance = 1e-3, scale)
%
%
%attr.all.equal(target, current, \dots,
%               check.attributes = TRUE, check.names = TRUE)
%}
%\arguments{
%  \item{target}{\R object.}
%  \item{current}{other \R object, to be compared with \code{target}.}
%  \item{\dots}{Further arguments for different methods, notably the
%    following two, for numerical comparison:}
%  \item{tolerance}{numeric \eqn{\ge} 0.  Differences smaller than
%    \code{tolerance} are not reported.  The default value is close to
%    \code{1.5e-8}.}
%  \item{scale}{numeric scalar > 0 (or \code{NULL}). See \sQuote{Details}.}
%  \item{check.attributes}{logical indicating if the
%    \code{\link{attributes}} of \code{target} and \code{current}
%    (other than the names) should be compared.}
%  \item{use.names}{logical indicating if \code{\link{list}} comparison
%    should report differing components by name (if matching) instead of
%    integer index.  Note that this comes after \code{\dots} and so must
%    be specified by its full name.}
%  \item{all.names}{logical passed to \code{\link{ls}} indicating if
%    \dQuote{hidden} objects should also be considered in the environments.}
%  \item{check.names}{logical indicating if the \code{\link{names}(.)}
%    of \code{target} and \code{current} should be compared.}
%}
%\description{
%    \code{all.equal(x, y)} is a utility to compare \R objects \code{x}
%    and \code{y} testing \sQuote{near equality}.  If they are different,
%    comparison is still made to some extent, and a report of the
%    differences is returned.    Do not use \code{all.equal} directly in
%    \code{if} expressions---either use \code{isTRUE(all.equal(....))} or
%    \code{\link{identical}} if appropriate.
%}
%\details{
%  \code{all.equal} is a generic function, dispatching methods on the
%  \code{target} argument.  To see the available methods, use
%  \code{\link{methods}("all.equal")}, but note that the default method
%  also does some dispatching, e.g.\sspace{}using the raw method for logical
%  targets.
%
%  Remember that arguments which follow \code{\dots} must be specified by
%  (unabbreviated) name: some of them were before \code{\dots} prior to
%  \R 3.1.0.  It is inadvisable to pass unnamed arguments in \code{\dots}
%  as these will match different arguments in different methods.
%
%  Numerical comparisons for \code{scale = NULL} (the default) are
%  typically on \emph{relative difference} scale unless the target values
%  are close to zero:  First, the mean absolute difference of the two
%  numerical vectors is computed.  If this is smaller than
%  \code{tolerance} or not finite, absolute differences are used,
%  otherwise relative differences scaled by the mean absolute
%  \code{target} value.
%  (Note that these comparisons are computed only for those vector elements
%  where \code{target} is not \code{\link{NA}} and differs from \code{current}.)
%
%  If \code{scale} is positive, absolute comparisons are made after
%  scaling (dividing) by \code{scale}.
%
%  For complex \code{target}, the modulus (\code{\link{Mod}}) of the
%  difference is used: \code{all.equal.numeric} is called so arguments
%  \code{tolerance} and \code{scale} are available.
%
%  The \code{\link{list}} method compares components of
%  \code{target} and \code{current} recursively, passing all other
%  arguments, as long as both are \dQuote{list-like}, i.e., fulfill
%  either \code{\link{is.vector}} or \code{\link{is.list}}.
%
%  The \code{\link{environment}} method works via the \code{list} method,
%  and is also used for reference classes (unless a specific
%  \code{all.equal} method is defined).
%
%  The methods for the date-time classes by default allow a tolerance of
%  \code{tolerance = 0.001} seconds, and ignore \code{scale}.
%
%  \code{attr.all.equal} is used for comparing
%  \code{\link{attributes}}, returning \code{NULL} or a
%  \code{character} vector.
%}
%\value{
%  Either \code{TRUE} (\code{NULL} for \code{attr.all.equal}) or a vector
%  of \code{\link{mode}} \code{"character"} describing the differences
%  between \code{target} and \code{current}.
%}
%\references{
%  Chambers, J. M. (1998)
%  \emph{Programming with Data. A Guide to the S Language}.
%  Springer (for \code{=}).
%}
%\seealso{\code{\link{identical}}, \code{\link{isTRUE}}, \code{\link{==}}, and
%  \code{\link{all}} for exact equality testing.
%}
%\examples{
%all.equal(pi, 355/113)
%# not precise enough (default tol) > relative error
%
%d45 <- pi*(1/4 + 1:10)
%stopifnot(
%all.equal(tan(d45), rep(1, 10)))          # TRUE, but
%all      (tan(d45) == rep(1, 10))         # FALSE, since not exactly
%all.equal(tan(d45), rep(1, 10), tolerance = 0)  # to see difference
%
%## advanced: equality of environments
%ae <- all.equal(as.environment("package:stats"),
%                asNamespace("stats"))
%stopifnot(is.character(ae), length(ae) > 10,
%          ## were incorrectly "considered equal" in R <= 3.1.1
%          all.equal(asNamespace("stats"), asNamespace("stats")))
%}
%\keyword{programming}% is.*
%\keyword{utilities}
%\keyword{logic}
%\keyword{arith}
%
\encoding{UTF8}
