% File src/library/base/man/as.Date.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{as.Date}
\alias{format.Date}
\alias{as.character.Date}
\alias{as.Date}
\alias{as.Date.character}
\alias{as.Date.default}
\alias{as.Date.factor}
\alias{as.Date.POSIXct}
\alias{as.Date.POSIXlt}
\alias{as.Date.date}
\alias{as.Date.dates}
\alias{as.Date.numeric}

\title{Date Conversion Functions to and from Character}
\description{
 暦日を表すクラス \code{"Date"} のオブジェクトと文字列表現間を変換する関数．
}
\usage{
as.Date(x, \dots)
\method{as.Date}{character}(x, format, \dots)
\method{as.Date}{numeric}(x, origin, \dots)
\method{as.Date}{POSIXct}(x, tz = "UTC", \dots)

\method{format}{Date}(x, \dots)

\method{as.character}{Date}(x, \dots)
}
\arguments{
  \item{x}{変換されるべきオブジェクト．}
  \item{format}{文字列．もし指定されないと最初の \code{NA} 要素に対して
  \code{"\%Y-\%m-\%d"} それから \code{"\%Y/\%m/\%d"} が試みられ，
どちらも失敗すればエラーになる．さもなければ，
処理は \code{\link{strptime}} 経由でなされる．}
  \item{origin}{日付オブジェクトもしくはそうしたオブジェクトに
  \code{as.Date(origin, \dots)} で変換できるもの．}
  \item{tz}{タイムゾーン名．}
  \item{\dots}{メソッドに/から引き渡される追加引数，
  \code{as.character} と \code{as.Date} メソッドに \code{format} を含む．
  }
}
\details{
  通常のリサイクル規則が \code{x} と \code{format} に適用され，
結果の長さはベクトルのそれの長い方になる．

  文字列から/へのロケール固有の変換が適当で可能なら使われる．
これは時刻と日付の名前に影響する．

\code{as.Date} メソッドは文字列，因子，論理 \code{NA} そしてクラス
 \code{"\link{POSIXlt}"} と \code{"\link{POSIXct}"} のオブジェクトを受け付ける．
(後者は日付に指定されたタイムゾーン，既定値 UTC，における時刻の表現中の真夜中
以降の時間を無視して
変換される．またクラス \code{"date"} (パッケージ 
 \pkg{\link[date:as.date]{date}} から)と \code{"dates"}
 (パッケージ \pkg{\link[chron]{chron}} から)のオブジェクトも同様である．
文字列は可能な限り指定された書式に対して処理される：任意の後に続く文字は
無視される．

  \code{as.Date} は数値データ(ある起源からの日数)が，
  \code{origin} が提供されている時だけである．

  \code{format} と \code{as.character} メソッドは日付の小数部分を無視する．
}
\value{
  \code{format} と \code{as.character} メソッドは日付を表す文字列を返す．
  日付の \code{NA} は \code{NA_character_} として返される．

  \code{as.Date} メソッドはクラス \code{"\link{Date}"} のオブジェクトを返す．
}
\note{
  既定の書式は ISO 8601 国際標準に従い，日付は \code{"2001-02-03"} の
ように表される．

もし日付文字列が日付を完全には特定しない場合，帰ってくる答えはシステム依存である
可能性がある．最も普通の挙動は欠損した年月日が現在のものと仮定することである．
もしこれが日付を不正確に特定するならば，信頼できる実装ではエラーを与え，日付は
 \code{NA} になる．残念ながら幾つかの普通の実装(\samp{glibc} のような)は
信頼できず意図された意味を推測する．

  1CE (1AD とも呼ばれる)以前の年は恐らく正確には処理されないであろう．
}
\section{他のシステムからの変換}{
  殆どのシステムは日付を内部的にある原点からの日数で記録するが，これは
次のような問題をはらんでいる
  \itemize{
    \item 原点は0日か1日か?  \sQuote{例}が示すように，
    Excel はその二つの日付システムで両方の選択を扱っている．
    \item もし原点が極端に過去ならば，デザイナは暦日システムに対する
無知をさらけ出すかもしれない．例えば，Excel の設計者は1900年が閏年だと考えていた
(昔の DOS の表計算ソフトからコピーされたと言われている)．Matlab の設計者は 
カレンダーを指定せず，存在しない \sQuote{January 0, 0000} という日付(そうした日付は
無い)を選択した．(そうした年は ISO 8601:2004 で使われた \sQuote{Gregorian} カレンダー
では存在するが，これは1582年以前については関係者間の合意の下で情報の交換用に使われるべきだと
述べてある．)
  }
  唯一の安全な手順は既知の日付に対して他のシステムをチェックすることである：
インターネット上の報告(R-help を含む)はよりしばしば正しいよりは間違いである．
}
\references{
  International Organization for Standardization (2004, 1988, 1997,
  \dots)
  \emph{ISO 8601. Data elements and interchange formats --
    Information interchange -- Representation of dates and times.}
  オンラインで入手できるバージョンのリンクとしては(執筆時) 
  \url{http://www.qsl.net/g1smd/isopdf.htm} を見よ．
}
\seealso{
  日付クラスの詳細は \link{Date}；
  ロケールの問い合わせと設定は \code{\link{locales}}．

  これらの書式を指定する方法を見るにはシステムの \code{strftime} と \code{strptime} の
ヘルプページ．Windows では \code{strptime} に対するヘルプページが無い：
  \samp{glibc} に基づくコードが用いられており(修正と共に)，従って
ここで説明されたすべての書式がサポートされているが，任意のロケールにおける別種の数の表示も
年号もサポートされない．
}
\examples{\donttest{
## 日にちのロケール固有版
format(Sys.Date(), "\%a \%b \%d")}

## 日付け情報をを形式 'ddmmmyyyy' で読み込む
## これはあるロケールでは NA を与える：コマンドラインで C ロケールを
## 設定すればほとんどのシステムで上手く行く．
## lct <- Sys.getlocale("LC_TIME"); Sys.setlocale("LC_TIME", "C")
x <- c("1jan1960", "2jan1960", "31mar1960", "30jul1960")
z <- as.Date(x, "\%d\%b\%Y")
## Sys.setlocale("LC_TIME", lct)
z

## 日付け/時刻情報を書式 'm/d/y' で読み込む
dates <- c("02/27/92", "02/27/92", "01/14/92", "02/28/92", "02/01/92")
as.Date(dates, "\%m/\%d/\%y")

## 1900-01-01 以来の日数(1989年のある日)
as.Date(32768, origin = "1900-01-01")
## Excel は 1900-01-01 を第一日 (Windows の既定) または
## 1904-01-01 を第0日 (Mac の既定)としていると言われる，しかしこれは Excel が
## 1900 年を不正確に閏年としているため混乱している．
## 従って Windows Excel では日付は (1901年以降)
as.Date(35981, origin = "1899-12-30") # 1998-07-05
## Mac Excel では
as.Date(34519, origin = "1904-01-01") # 1998-07-05
## (これらの値は http://support.microsoft.com/kb/214330 から)

## 実験では Matlab の日付け原点は我々のより719529日早い，
## (存在しない 0000-01-01 を初日としている)
## 従って Matlab の734373日は次のように移入できる
as.Date(734373, origin = "1970-01-01") - 719529 # 2010-08-23
## (以下からの値 http://www.mathworks.de/de/help/matlab/matlab_prog/
##                     represent-date-and-times-in-MATLAB.html)
## タイムゾーン効果
z <- ISOdate(2010, 04, 13, c(0,12)) # UTC の真夜中と真昼
as.Date(z) # UTC で
\donttest{## これらのタイムゾーン名はありふれている
as.Date(z, tz = "NZ")
as.Date(z, tz = "HST") # ハワイ}
}
\keyword{utilities}
\keyword{chron}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/as.Date.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{as.Date}
%\alias{format.Date}
%\alias{as.character.Date}
%\alias{as.Date}
%\alias{as.Date.character}
%\alias{as.Date.default}
%\alias{as.Date.factor}
%\alias{as.Date.POSIXct}
%\alias{as.Date.POSIXlt}
%\alias{as.Date.date}
%\alias{as.Date.dates}
%\alias{as.Date.numeric}
%
%\title{Date Conversion Functions to and from Character}
%\description{
%  Functions to convert between character representations and objects of
%  class \code{"Date"} representing calendar dates.
%}
%\usage{
%as.Date(x, \dots)
%\method{as.Date}{character}(x, format, \dots)
%\method{as.Date}{numeric}(x, origin, \dots)
%\method{as.Date}{POSIXct}(x, tz = "UTC", \dots)
%
%\method{format}{Date}(x, \dots)
%
%\method{as.character}{Date}(x, \dots)
%}
%\arguments{
%  \item{x}{An object to be converted.}
%  \item{format}{A character string.  If not specified, it will try
%    \code{"\%Y-\%m-\%d"} then \code{"\%Y/\%m/\%d"} on the first
%    non-\code{NA} element, and give an error if neither works.
%    Otherwise, the processing is via \code{\link{strptime}}}
%  \item{origin}{a Date object, or something which can be coerced by
%    \code{as.Date(origin, \dots)} to such an object.}
%  \item{tz}{a time zone name.}
%  \item{\dots}{Further arguments to be passed from or to other methods,
%    including \code{format} for \code{as.character} and \code{as.Date}
%    methods.}
%}
%\details{
%  The usual vector re-cycling rules are applied to \code{x} and
%  \code{format} so the answer will be of length that of the longer of the
%  vectors.
%
%  Locale-specific conversions to and from character strings are used
%  where appropriate and available.  This affects the names of the days
%  and months.
%
%  The \code{as.Date} methods accept character strings, factors, logical
%  \code{NA} and objects of classes \code{"\link{POSIXlt}"} and
%  \code{"\link{POSIXct}"}.  (The last is converted to days by ignoring
%  the time after midnight in the representation of the time in specified
%  time zone, default UTC.)  Also objects of class \code{"date"} (from
%  package \pkg{\link[date:as.date]{date}}) and \code{"dates"} (from
%  package \pkg{\link[chron]{chron}}).  Character strings are processed
%  as far as necessary for the format specified: any trailing characters
%  are ignored.
%
%  \code{as.Date} will accept numeric data (the number of days since an
%  epoch), but \emph{only} if \code{origin} is supplied.
%
%  The \code{format} and \code{as.character} methods ignore any
%  fractional part of the date.
%}
%\value{
%  The \code{format} and \code{as.character} methods return a character vector
%  representing the date.  \code{NA} dates are returned as \code{NA_character_}.
%
%  The \code{as.Date} methods return an object of class \code{"\link{Date}"}.
%}
%\note{
%  The default formats follow the rules of the ISO 8601 international
%  standard which expresses a day as \code{"2001-02-03"}.
%
%  If the date string does not specify the date completely, the returned
%  answer may be system-specific.  The most common behaviour is to assume
%  that a missing year, month or day is the current one.  If it specifies
%  a date incorrectly, reliable implementations will give an error and
%  the date is reported as \code{NA}.  Unfortunately some common
%  implementations (such as \samp{glibc}) are unreliable and guess at the
%  intended meaning.
%
%  Years before 1CE (aka 1AD) will probably not be handled correctly.
%}
%\section{Conversion from other Systems}{
%  Most systems record dates internally as the number of days since some
%  origin, but this is fraught with problems, including
%  \itemize{
%    \item Is the origin day 0 or day 1?  As the \sQuote{Examples} show,
%    Excel manages to use both choices for its two date systems.
%    \item If the origin is far enough back, the designers may show their
%    ignorance of calendar systems.  For example, Excel's designer
%    thought 1900 was a leap year (claiming to copy the error from
%    earlier DOS spreadsheets), and Matlab's designer chose the
%    non-existent date of \sQuote{January 0, 0000} (there is no such day),
%    not specifying the calendar.  (There is such a year in the
%    \sQuote{Gregorian} calendar as used in ISO 8601:2004, but that does say
%    that it is only to be used for years before 1582 with the agreement
%    of the parties in information exchange.)
%  }
%  The only safe procedure is to check the other systems values for known
%  dates: reports on the Internet (including R-help) are more often wrong
%  than right.
%}
%\references{
%  International Organization for Standardization (2004, 1988, 1997,
%  \dots)
%  \emph{ISO 8601. Data elements and interchange formats --
%    Information interchange -- Representation of dates and times.}
%  For links to versions available on-line see (at the time of writing)
%  \url{http://www.qsl.net/g1smd/isopdf.htm}.
%}
%\seealso{
%  \link{Date} for details of the date class;
%  \code{\link{locales}} to query or set a locale.
%
%  Your system's help pages on \code{strftime} and \code{strptime} to see
%  how to specify their formats.  Windows users will find no help page
%  for \code{strptime}: code based on \samp{glibc} is used (with
%  corrections), so all the format specifiers described here are
%  supported, but with no alternative number representation nor era
%  available in any locale.
%}
%\examples{\donttest{
%## locale-specific version of the date
%format(Sys.Date(), "\%a \%b \%d")}
%
%## read in date info in format 'ddmmmyyyy'
%## This will give NA(s) in some locales; setting the C locale
%## as in the commented lines will overcome this on most systems.
%## lct <- Sys.getlocale("LC_TIME"); Sys.setlocale("LC_TIME", "C")
%x <- c("1jan1960", "2jan1960", "31mar1960", "30jul1960")
%z <- as.Date(x, "\%d\%b\%Y")
%## Sys.setlocale("LC_TIME", lct)
%z
%
%## read in date/time info in format 'm/d/y'
%dates <- c("02/27/92", "02/27/92", "01/14/92", "02/28/92", "02/01/92")
%as.Date(dates, "\%m/\%d/\%y")
%
%## date given as number of days since 1900-01-01 (a date in 1989)
%as.Date(32768, origin = "1900-01-01")
%## Excel is said to use 1900-01-01 as day 1 (Windows default) or
%## 1904-01-01 as day 0 (Mac default), but this is complicated by Excel
%## incorrectly treating 1900 as a leap year.
%## So for dates (post-1901) from Windows Excel
%as.Date(35981, origin = "1899-12-30") # 1998-07-05
%## and Mac Excel
%as.Date(34519, origin = "1904-01-01") # 1998-07-05
%## (these values come from http://support.microsoft.com/kb/214330)
%
%## Experiment shows that Matlab's origin is 719529 days before ours,
%## (it takes the non-existent 0000-01-01 as day 1)
%## so Matlab day 734373 can be imported as
%as.Date(734373, origin = "1970-01-01") - 719529 # 2010-08-23
%## (value from 
%## http://www.mathworks.de/de/help/matlab/matlab_prog/represent-date-and-times-in-MATLAB.html)
%
%## Time zone effect
%z <- ISOdate(2010, 04, 13, c(0,12)) # midnight and midday UTC
%as.Date(z) # in UTC
%\donttest{## these time zone names are common
%as.Date(z, tz = "NZ")
%as.Date(z, tz = "HST") # Hawaii}
%}
%\keyword{utilities}
%\keyword{chron}
%
\encoding{UTF8}
