% File src/library/base/man/character.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{character}
\alias{character}
\alias{as.character}
\alias{as.character.default}
\alias{as.character.factor}
\alias{is.character}
\title{Character Vectors}
\description{
  型 \code{"character"} のオブジェクトを作る，検査する．
}
\usage{
character(length = 0)
as.character(x, \dots)
is.character(x)
}
\arguments{
  \item{length}{希望の長さを指定する非負整数．
    倍精度実数は整数に変換される：引数の長さが1以外はエラーになる．}
  \item{x}{強制変換されたりテストされるオブジェクト．}
  \item{\dots}{他のメソッドに/から引き渡される追加引数．}
}
\details{
  \code{as.character} と \code{is.character} は総称的である：
  オブジェクトの特定のクラスを処理するメソッドをを書くことが出来る，
  \link{InternalMethods} を見よ．更に，\code{as.character} に対して
  既定メソッドは \code{\link{as.vector}} を呼び出すので，選択適用は最初
  \code{as.character} に対するもので，それから \code{as.vector} に対する
  メソッドである．

  \code{as.character} は実数と複素数を有効桁数 15 桁で表示する
  (技術的にはコンパイラの ISO C 定数 \code{DBL_DIG} で，
  これは C99 標準によれば IEC60559 算術をサポートする計算機では 15 になる).
  これは結果のすべての数字が信頼できる(表現によるエラーの結果ではない)
  ことを保証するが，文字列への変換と逆変換は数値を変える可能性がある．
  もし数値を可能な最大の精度で文字列に変換したければ \code{\link{format}} を使う．
}
\value{
  \code{character} は指定された長さの文字列ベクトルを作る．
  ベクトルの要素はすべて \code{""} に等しい．

  \code{as.character} はその引数を文字列型に強制変換しようと
  試みる； \code{\link{as.vector}} と同じように名前を含む属性を剥ぎ取る．
  リストと対リスト(呼び出しのような言語オブジェクトを含む)に対しては，
  これは要素を個別に逆構文解析するが，長さが1の文字列ベクトルは最初の要素を
  取り出す．

  \code{is.character} はその引数が文字列型か否かで \code{TRUE} または
  \code{FALSE} を返す．
}
\note{
  \code{as.character} は言語オブジェクト中の行を500文字で分割し，
  新行を挿入する．バージョン 2.15.0 以前では行は切り詰められていた．
}
\seealso{
  \code{\link{options}}: オプション \code{scipen} は数の変換に影響する．
  
  文字列の結合と分割については \code{\link{paste}}, \code{\link{substr}}
  そして \code{\link{strsplit}}．
  文字列の翻訳と大・小文字の変換に対しては \code{\link{chartr}}．
  そして文字列のマッチングと代入については \code{\link{sub}}, \code{\link{grep}} 等．
  \code{help.search(keyword = "character")} はより多くのリンクを与えることを
  注意する．

  言語オブジェクトに対しては \code{\link{deparse}} は普通 
  \code{as.character} よりも好ましい．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
form <- y ~ a + b + c
as.character(form)  ## 長さ 3
deparse(form)       ## 入力と似る

a0 <- 11/999          # 循環小数
(a1 <- as.character(a0))
format(a0, digits = 16) # もう一つ桁を示す
a2 <- as.numeric(a1)
a2 - a0               # 普通約 -1e-17
as.character(a2)      # 普通 a1 と異なる
print(c(a0, a2), digits = 16)
}
\keyword{character}
\keyword{classes}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/character.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{character}
%\alias{character}
%\alias{as.character}
%\alias{as.character.default}
%\alias{as.character.factor}
%\alias{is.character}
%\title{Character Vectors}
%\description{
%  Create or test for objects of type \code{"character"}.
%}
%\usage{
%character(length = 0)
%as.character(x, \dots)
%is.character(x)
%}
%\arguments{
%  \item{length}{A non-negative integer specifying the desired length.
%    Double values will be coerced to integer:
%    supplying an argument of length other than one is an error.}
%  \item{x}{object to be coerced or tested.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\details{
%  \code{as.character} and \code{is.character} are generic: you can
%  write methods to handle specific classes of objects,
%  see \link{InternalMethods}.  Further, for \code{as.character} the
%  default method calls \code{\link{as.vector}}, so dispatch is first on
%  methods for \code{as.character} and then for methods for \code{as.vector}.
%
%  \code{as.character} represents real and complex numbers to 15 significant
%  digits (technically the compiler's setting of the ISO C constant
%  \code{DBL_DIG}, which will be 15 on machines supporting IEC60559
%  arithmetic according to the C99 standard).  This ensures that all the
%  digits in the result will be reliable (and not the result of
%  representation error), but does mean that conversion to character and
%  back to numeric may change the number.  If you want to convert numbers
%  to character with the maximum possible precision, use
%  \code{\link{format}}.
%}
%\value{
%  \code{character} creates a character vector of the specified length.
%  The elements of the vector are all equal to \code{""}.
%
%  \code{as.character} attempts to coerce its argument to character type;
%  like \code{\link{as.vector}} it strips attributes including names.
%  For lists and pairlists (including \link{language objects} such as
%  calls) it deparses the elements individually, except that it extracts
%  the first element of length-one character vectors.
%
%  \code{is.character} returns \code{TRUE} or \code{FALSE} depending on
%  whether its argument is of character type or not.
%}
%\note{
%  \code{as.character} breaks lines in language objects at 500
%  characters, and inserts newlines.  Prior to 2.15.0 lines were
%  truncated.
%}
%\seealso{
%  \code{\link{options}}: option \code{scipen} affects the conversion of
%  numbers.
%  
%  \code{\link{paste}}, \code{\link{substr}} and \code{\link{strsplit}}
%  for character concatenation and splitting,
%  \code{\link{chartr}} for character translation and casefolding (e.g.,
%  upper to lower case) and \code{\link{sub}}, \code{\link{grep}} etc for
%  string matching and substitutions.  Note that
%  \code{help.search(keyword = "character")} gives even more links.
%
%  \code{\link{deparse}}, which is normally preferable to
%  \code{as.character} for \link{language objects}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%form <- y ~ a + b + c
%as.character(form)  ## length 3
%deparse(form)       ## like the input
%
%a0 <- 11/999          # has a repeating decimal representation
%(a1 <- as.character(a0))
%format(a0, digits = 16) # shows one more digit
%a2 <- as.numeric(a1)
%a2 - a0               # normally around -1e-17
%as.character(a2)      # normally different from a1
%print(c(a0, a2), digits = 16)
%}
%\keyword{character}
%\keyword{classes}
%
\encoding{UTF8}
