% File src/library/base/man/deparse.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{deparse}
\alias{deparse}
\title{Expression Deparsing}
\description{
  未評価の表現式を文字列に変換する．
}
\usage{
deparse(expr, width.cutoff = 60L,
        backtick = mode(expr) \%in\%
            c("call", "expression", "(", "function"),
        control = c("keepInteger", "showAttributes", "keepNA"),
        nlines = -1L)
}
\arguments{
  \item{expr}{任意の \R 表現式．}
  \item{width.cutoff}{\eqn{[20, 500]} 中の整数で，
    行分割が試みられるカットオフ(バイト単位)を決める．}
  \item{backtick}{標準的な構文に従わないシンボル名をバックチックで
    囲むかどうかを指定する論理値．}
  \item{control}{逆構文解析のオプションの文字列ベクトル．
    \code{\link{.deparseOpts}} を見よ．}
  \item{nlines}{整数：作られる行の最大値．
    負の値は制限なし．}
}
\details{
  この関数は未評価の表現式(ここで \sQuote{表現式}
  とは \code{\link{expression}} で使われるモード
  \code{"expression"} のベクトルという厳密な概念よりも広い意味で
  使われている)を文字列に変換する(一種の \code{\link{parse}} の逆)．

  これの典型的な使用法はデータセットとプロットに対する内容が分かるラベルを作ることである．
  下の例はこの機能の簡単な使用例を示す．
  これは関数 \code{myplot} への実際の引数の文字列バージョンである
  プロットに対するラベルを作るため関数 \code{deparse} と \code{substitute}
  を使う．

  オプション \code{backtick} に対する既定動作は単一のシンボルではなく
  複合表現式のみを引用化することである．これは既存コードを分断する
  ことを避けるための折衷案である．

  \code{control = "all"} の使用は \code{deparse()} を
  \code{parse()} の逆操作に最も近くする．しかしながら，このオプションを
  使ってすらすべてのオブジェクトが逆構文解析可能なわけではなく，
  もし関数はそれが求められていることが不可能と認識すると警告がでる．

  数値と複素数値ベクトルは有効桁数15桁を用いて変換される：
  より詳細は \code{\link{as.character}} を見よ．

  \code{width.cutoff} は行の長さの下限である：
  一行の逆構文解析は最低 \code{width.cutoff} バイトが出力されるまで進行し，そして
  例えば \code{arg = value} といった表現は行をまたがって分割されない．
}
\note{
  ソース属性が実際の関数定義と食い違うリスクを避けるため，
  関数のソース属性は属性として逆解析されない．

  内部構造の逆構文解析は正確でないかもしれない：例えば
  \code{\link{recordPlot}} で記録されたグラフィックスディスプレイの
  リストは逆解析されることを意図しておらず，
  呼び出し \code{.Internal} はプリミティブ呼び出しとされる．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{substitute}},
  \code{\link{parse}},
  \code{\link{expression}}.

  バックチックを含む引用化の決まりについては \code{Quotes}．
}
\examples{
require(stats); require(graphics)

deparse(args(lm))
deparse(args(lm), width = 500)
myplot <-
function(x, y) {
    plot(x, y, xlab = deparse(substitute(x)),
        ylab = deparse(substitute(y)))
}
e <- quote(`foo bar`)
deparse(e)
deparse(e, backtick = TRUE)
e <- quote(`foo bar`+1)
deparse(e)
deparse(e, control = "all")
}
\keyword{programming}
\keyword{manip}
\keyword{data}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/deparse.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{deparse}
%\alias{deparse}
%\title{Expression Deparsing}
%\description{
%  Turn unevaluated expressions into character strings.
%}
%\usage{
%deparse(expr, width.cutoff = 60L,
%        backtick = mode(expr) \%in\%
%            c("call", "expression", "(", "function"),
%        control = c("keepInteger", "showAttributes", "keepNA"),
%        nlines = -1L)
%}
%\arguments{
%  \item{expr}{any \R expression.}
%  \item{width.cutoff}{integer in \eqn{[20, 500]} determining the cutoff
%    (in bytes) at which line-breaking is tried.}
%  \item{backtick}{logical indicating whether symbolic names should be
%    enclosed in backticks if they do not follow the standard syntax.}
%  \item{control}{character vector of deparsing options.  See
%    \code{\link{.deparseOpts}}.}
%  \item{nlines}{integer: the maximum number of lines to produce.
%    Negative values indicate no limit.}
%}
%\details{
%  This function turns unevaluated expressions (where \sQuote{expression}
%  is taken in a wider sense than the strict concept of a vector of mode
%  \code{"expression"} used in \code{\link{expression}}) into character
%  strings (a kind of inverse to \code{\link{parse}}).
%
%  A typical use of this is to create informative labels for data sets
%  and plots.  The example shows a simple use of this facility.  It uses
%  the functions \code{deparse} and \code{substitute} to create labels
%  for a plot which are character string versions of the actual arguments
%  to the function \code{myplot}.
%
%  The default for the \code{backtick} option is not to quote single
%  symbols but only composite expressions.  This is a compromise to
%  avoid breaking existing code.
%
%  Using \code{control = "all"} comes closest to making \code{deparse()}
%  an inverse of \code{parse()}.  However, not all objects are
%  deparse-able even with this option and a warning will be issued if the
%  function recognizes that it is being asked to do the impossible.
%
%  Numeric and complex vectors are converted using 15 significant digits:
%  see \code{\link{as.character}} for more details.
%
%  \code{width.cutoff} is a lower bound for the line lengths: deparsing a
%  line proceeds until at least \code{width.cutoff} \emph{bytes} have
%  been output and e.g.\sspace{}\code{arg = value} expressions will not be split
%  across lines.
%}
%\note{
%  To avoid the risk of a source attribute out of sync with the actual
%  function definition, the source attribute of a function will never
%  be deparsed as an attribute.
%
%  Deparsing internal structures may not be accurate: for example the
%  graphics display list recorded by \code{\link{recordPlot}} is not
%  intended to be deparsed and \code{.Internal} calls will be shown as
%  primitive calls.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{substitute}},
%  \code{\link{parse}},
%  \code{\link{expression}}.
%
%  \code{Quotes} for quoting conventions, including backticks.
%}
%\examples{
%require(stats); require(graphics)
%
%deparse(args(lm))
%deparse(args(lm), width = 500)
%myplot <-
%function(x, y) {
%    plot(x, y, xlab = deparse(substitute(x)),
%        ylab = deparse(substitute(y)))
%}
%e <- quote(`foo bar`)
%deparse(e)
%deparse(e, backtick = TRUE)
%e <- quote(`foo bar`+1)
%deparse(e)
%deparse(e, control = "all")
%}
%\keyword{programming}
%\keyword{manip}
%\keyword{data}
%
\encoding{UTF8}
