% File src/library/base/man/environment.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{environment}
\alias{environment}
\alias{environment<-}
\alias{.GlobalEnv}
\alias{globalenv}
\alias{emptyenv}
\alias{baseenv}
\alias{is.environment}
\alias{new.env}
\alias{parent.env}
\alias{parent.env<-}
\alias{.BaseNamespaceEnv}
\alias{environmentName}
\alias{env.profile}
\alias{enclosure}

\title{Environment Access}
\description{
  環境を得る，設定する．検査する，そして作成する．
}
\usage{
environment(fun = NULL)
environment(fun) <- value

is.environment(x)

.GlobalEnv
globalenv()
.BaseNamespaceEnv

emptyenv()
baseenv()

new.env(hash = TRUE, parent = parent.frame(), size = 29L)

parent.env(env)
parent.env(env) <- value

environmentName(env)

env.profile(env)
}
\arguments{
  \item{fun}{関数，公式，又は既定である \code{NULL}．}
  \item{value}{関数を関連させる環境．}
  \item{x}{任意の \R オブジェクト．}
  \item{hash}{論理値．もし \code{TRUE} なら環境はハッシュテーブルを使う．}
  \item{parent}{作られた環境の囲み環境として使われる環境．}
  \item{env}{環境}
  \item{size}{ハッシュされた環境の初期サイズを指定する整数．
    もし \code{size} が \code{NA} かゼロならば内部的な既定値が使われる．
    この引数はもし \code{hash} が \code{FALSE} なら無視される．}
}
\value{
  もし \code{fun} が関数か公式であれば \code{environment(fun)}
  はその関数や公式に関連する環境を返す．
  もし \code{fun} が \code{NULL} なら現在の評価環境が返される．

  置き換え形式は関数や公式 \code{fun} の環境を \code{value} で与えられるものに設定する．

  \code{is.environment(obj)} は
  \code{obj} が \code{environment} である時，そしてその時だけ
  \code{TRUE} を返す．

  \code{new.env} は親環境を囲み環境に持つ(既定)新しい(空の)環境を返す．

  \code{parent.env} はその引数の囲み環境を返す．

  \code{parent.env<-} はその最初の引数の囲み環境を返す．

  \code{environmentName} は文字列を返す．これは環境をプリントするときに
  使われる．又はそれが名前無しの環境なら \code{""} を返す．

  \code{env.profile} は次のような成分を持つリストを返す：
  \code{size} はハッシュテーブル中に保管できるチェインの数，
  \code{nchains} はテーブル中の空でないチェインの数(\code{HASHPRI} により報告されるような)，
  そして \code{counts} は各チェインの長さを与える整数ベクトル
  (空のチェインに対してはゼロ)．この関数は
  ハッシュされた環境のパフォーマンスを吟味することを意図している．
  \code{env} がハッシュされていない環境ならば \code{NULL} が返される．
}

\details{
  環境は名前付きオブジェクトの集まりであるフレームと囲み環境への
  ポインターからなる．最も普通の例は関数呼び出しへの局所的な変数の
  フレームである；その囲み環境は関数が定義された環境である
  (その後変更されていない限り)．囲み環境は親環境とは区別される：後者
  (\code{\link{parent.frame}} が返す)は関数を呼び出した環境を指す．
  混乱しやすいので，環境との関連で \sQuote{親} という言葉は使わないほうが
  良い(関数 \code{parent.env} が存在するものの)．

  \code{\link{get}} や \code{\link{exists}} が既定の  \code{inherits = TRUE}
  で環境を探す時，それらはフレーム中の変数を探す，それから囲みフレームを探す云々．

  大局的環境 \code{.GlobalEnv} はよりしばしばユーザの作業空間と呼ばれ，
  検索パス上の最初の項目になる．それは \code{globalenv()} によってもアクセスできる．
  検索パス上では各項目の囲み環境は次の項目になる．

  オブジェクト \code{.BaseNamespaceEnv} は基本パッケージに対する名前空間環境
  である．基本パッケージの環境自体は \code{baseenv()} で得られる．

  任意の環境から \code{parent.env} を呼び出し囲み環境のチェインを遡って行くと，
  ついには空環境 \code{emptyenv()} に至る．この中には何も付値できない．

  置き換え関数 \code{parent.env<-} は非常に危険で，
  内部 C コードによる仮定を損傷することで環境を壊滅的に変更する可能性がある．
  これは将来廃止されるかもしれない．

  置き換え形式 \code{environment}, \code{is.environment},
  \code{baseenv}, \code{emptyenv} そして \code{globalenv} は
  プリミティブな関数である．

  基本，大局的，そして空環境と言ったシステム環境は
  パッケージ，名前空間そして \code{attach()} により生成されるような
  名前を持つ．他の環境は \code{"name"} 属性を与えることで名前を付けることが出来るが，
  環境は通例ではないコピー構文を持つので注意深く行う必要がある．
}
\seealso{
  ハッシュを使うかどうかによるパフォーマンスの違いについては
  \url{https://en.wikipedia.org/wiki/Hash_table} を見よ．

  \code{\link{eval}}, \code{\link{get}},
  そして \code{\link{exists}} の \code{envir} 引数．

  \code{\link{ls}} は環境中のオブジェクトを眺めるのに使うことが出来る．
  従って \code{\link{ls.str}} は概観するのに有益かもしれない．

  \code{\link{sys.source}} は環境に何かを配置するのに使うことが出来る．
}
\examples{
f <- function() "top level function"

##-- 次の三つは同じものを与える：
environment()
environment(f)
.GlobalEnv

ls(envir = environment(stats::approxfun(1:2, 1:2, method = "const")))

is.environment(.GlobalEnv) # TRUE

e1 <- new.env(parent = baseenv())  # これは囲みパッケージ package:base を持つ．
e2 <- new.env(parent = e1)
assign("a", 3, envir = e1)
ls(e1)
ls(e2)
exists("a", envir = e2)   # これは継承により成功する
exists("a", envir = e2, inherits = FALSE)
exists("+", envir = e2)   # これは継承により成功する

eh <- new.env(hash = TRUE, size = NA)
with(env.profile(eh), stopifnot(size == length(counts)))
}
\keyword{data}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/environment.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{environment}
%\alias{environment}
%\alias{environment<-}
%\alias{.GlobalEnv}
%\alias{globalenv}
%\alias{emptyenv}
%\alias{baseenv}
%\alias{is.environment}
%\alias{new.env}
%\alias{parent.env}
%\alias{parent.env<-}
%\alias{.BaseNamespaceEnv}
%\alias{environmentName}
%\alias{env.profile}
%\alias{enclosure}
%
%\title{Environment Access}
%\description{
%  Get, set, test for and create environments.
%}
%\usage{
%environment(fun = NULL)
%environment(fun) <- value
%
%is.environment(x)
%
%.GlobalEnv
%globalenv()
%.BaseNamespaceEnv
%
%emptyenv()
%baseenv()
%
%new.env(hash = TRUE, parent = parent.frame(), size = 29L)
%
%parent.env(env)
%parent.env(env) <- value
%
%environmentName(env)
%
%env.profile(env)
%}
%\arguments{
%  \item{fun}{a \code{\link{function}}, a \code{\link{formula}}, or
%    \code{NULL}, which is the default.}
%  \item{value}{an environment to associate with the function}
%  \item{x}{an arbitrary \R object.}
%  \item{hash}{a logical, if \code{TRUE} the environment will use a hash table.}
%  \item{parent}{an environment to be used as the enclosure of the
%    environment created.}
%  \item{env}{an environment}
%  \item{size}{an integer specifying the initial size for a hashed
%    environment.  An internal default value will be used if
%    \code{size} is \code{NA} or zero.  This argument is ignored if
%    \code{hash} is \code{FALSE}.}
%}
%\value{
%  If \code{fun} is a function or a formula then \code{environment(fun)}
%  returns the environment associated with that function or formula.
%  If \code{fun} is \code{NULL} then the current evaluation environment is
%  returned.
%
%  The replacement form sets the environment of the function or formula
%  \code{fun} to the \code{value} given.
%
%  \code{is.environment(obj)} returns \code{TRUE} if and only if
%  \code{obj} is an \code{environment}.
%
%  \code{new.env} returns a new (empty) environment with (by default)
%  enclosure the parent frame.
%
%  \code{parent.env} returns the enclosing environment of its argument.
%
%  \code{parent.env<-} sets the enclosing environment of its first
%  argument.
%
%  \code{environmentName} returns a character string, that given when
%  the environment is printed or \code{""} if it is not a named environment.
%
%  \code{env.profile} returns a list with the following components:
%  \code{size} the number of chains that can be stored in the hash table,
%  \code{nchains} the number of non-empty chains in the table (as
%  reported by \code{HASHPRI}), and \code{counts} an integer vector
%  giving the length of each chain (zero for empty chains).  This
%  function is intended to assess the performance of hashed environments.
%  When \code{env} is a non-hashed environment, \code{NULL} is returned.
%}
%
%\details{
%  Environments consist of a \emph{frame}, or collection of named
%  objects, and a pointer to an \emph{enclosing environment}.  The most
%  common example is the frame of variables local to a function call; its
%  \emph{enclosure} is the environment where the function was defined
%  (unless changed subsequently).  The enclosing environment is
%  distinguished from the \emph{parent frame}: the latter (returned by
%  \code{\link{parent.frame}}) refers to the environment of the caller of
%  a function.  Since confusion is so easy, it is best never to use
%  \sQuote{parent} in connection with an environment (despite the
%  presence of the function \code{parent.env}).
%
%  When \code{\link{get}} or \code{\link{exists}} search an environment
%  with the default \code{inherits = TRUE}, they look for the variable
%  in the frame, then in the enclosing frame, and so on.
%
%  The global environment \code{.GlobalEnv}, more often known as the
%  user's workspace, is the first item on the search path.  It can also
%  be accessed by \code{globalenv()}.  On the search path, each item's
%  enclosure is the next item.
%
%  The object \code{.BaseNamespaceEnv} is the namespace environment for
%  the base package.  The environment of the base package itself is
%  available as \code{baseenv()}.
%
%  If one follows the chain of enclosures found by repeatedly calling
%  \code{parent.env} from any environment, eventually one reaches the
%  empty environment \code{emptyenv()}, into which nothing may
%  be assigned.
%
%  The replacement function \code{parent.env<-} is extremely dangerous as
%  it can be used to destructively change environments in ways that
%  violate assumptions made by the internal C code.  It may be removed
%  in the near future.
%
%  The replacement form of \code{environment}, \code{is.environment},
%  \code{baseenv}, \code{emptyenv} and \code{globalenv} are
%  \link{primitive} functions.
%
%  System environments, such as the base, global and empty environments,
%  have names as do the package and namespace environments and those
%  generated by \code{attach()}.  Other environments can be named by
%  giving a \code{"name"} attribute, but this needs to be done with care
%  as environments have unusual copying semantics.
%}
%\seealso{
%  For the performance implications of hashing or not, see
%  \url{https://en.wikipedia.org/wiki/Hash_table}.
%
%  The \code{envir} argument of \code{\link{eval}}, \code{\link{get}},
%  and \code{\link{exists}}.
%
%  \code{\link{ls}} may be used to view the objects in an environment,
%  and hence \code{\link{ls.str}} may be useful for an overview.
%
%  \code{\link{sys.source}} can be used to populate an environment.
%}
%\examples{
%f <- function() "top level function"
%
%##-- all three give the same:
%environment()
%environment(f)
%.GlobalEnv
%
%ls(envir = environment(stats::approxfun(1:2, 1:2, method = "const")))
%
%is.environment(.GlobalEnv) # TRUE
%
%e1 <- new.env(parent = baseenv())  # this one has enclosure package:base.
%e2 <- new.env(parent = e1)
%assign("a", 3, envir = e1)
%ls(e1)
%ls(e2)
%exists("a", envir = e2)   # this succeeds by inheritance
%exists("a", envir = e2, inherits = FALSE)
%exists("+", envir = e2)   # this succeeds by inheritance
%
%eh <- new.env(hash = TRUE, size = NA)
%with(env.profile(eh), stopifnot(size == length(counts)))
%}
%\keyword{data}
%\keyword{programming}
%
\encoding{UTF8}
