% File src/library/base/man/identical.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2001-2014 R Core Team
% Distributed under GPL 2 or later

\name{identical}
\alias{identical}
\title{Test Objects for Exact Equality}
\description{
  二つのオブジェクトが\emph{正確に}等しいかどうかを検査する安全で信頼できる方法．
  等しい場合 \code{TRUE} を返し，他のすべてのケースでは \code{FALSE} を返す．
}
\usage{
identical(x, y, num.eq = TRUE, single.NA = TRUE, attrib.as.set = TRUE,
          ignore.bytecode = TRUE, ignore.environment = FALSE)
}
\arguments{
  \item{x, y}{任意の \R オブジェクト．}
  \item{num.eq}{数(\code{\link{double}} と
    \code{\link{complex}} で \code{\link{NA}} で無い)は
    \code{\link{==}} (\sQuote{等号}) を使って比較するか，それとも
    ビット毎に比較するかを指示する論理値．
    後者(非既定値)は \code{-0} と \code{+0} を区別する．}
  \item{single.NA}{概念的に丁度一つの数値の 
    \code{\link{NA}} と一つの \code{\link{NaN}} があるかどうかを指示する
    論理値；\code{single.NA = FALSE} はビットパターンを区別する．}
  \item{attrib.as.set}{\code{x} と \code{y} の属性が
    \emph{順序が無い}タグ付き対リスト
    (\dQuote{集合})と見做すかどうかを指示する論理値；これは現在また S4 オブジェクトの 
    \code{\link{slot}} にも適用される．
    \code{attrib.as.set = FALSE} と置くのはあまりにも厳格かもしれない．}
  \item{ignore.bytecode}{クロージャを比較する際バイトコードが無視されるべきかどうか
    を指示する論理値．}
  \item{ignore.environment}{クロージャを比較する際それらの環境が無視されるべきかどうか
    を指示する論理値．}
}
\details{
  \code{identical} の呼び出しは \code{if} 文と \code{while} 文
  また \code{&&} や \code{||} を用いる論理表現式中で正確な同等性を
  テストする手段である．これらすべての応用では単一の論理値が得られることが
  保証されなければならない．

  ユーザはしばしばこうした状況で \code{==} や \code{!=} のような比較演算子を
  使う．これは自然に見えるが，これはこれらの演算子が \R でデザインされたものではない．
  これらは引数に似たオブジェクトを返す．
  もし \code{x} と \code{y} が同じ長さであることを期待していたが実は一方が
  そうでなかったとすると，ただ一つの \code{FALSE} が得られない．同様に，
  もし一方の引数が \code{NA} ならば結果もまた \code{NA} になる．どちらのケースでも
  表現 \code{if(x == y)....} は期待したようには動作しない．

  関数 \code{all.equal} もまたこのような方法で同等性をテストするのに
  使われるが，しかし少し異なったことを意図している：それは数値的な結果での
  僅かな違いを認める．

  \code{identical} 中の計算はまた信頼が置け，そして普通速い．
  それらは決してエラーにならない．\code{identical} を破綻させる既知の唯一の
  方法は C レベルで不正なポインターを与えメモリフォールトを起こすことである．
  それは普通不等性を素早く見出す．
  二つの大きくて複雑なオブジェクトの同等性のチェックは，もしオブジェクトが
  等しいかほとんど等しくて完全に独立なコピーを表す場合には
  より時間がかかる可能性がある．殆どのアプリケーションに対しては計算コストは
  無視可能であろう．

  既定であるが，もし \code{single.NA} が真なら \code{identical} は
  \code{\link{NaN}} を \code{\link{NA_real_}} とは異なると見做すが，
  すべての \code{NaN} は等しい(そして同じ型のすべての \code{NA} は等しい)．

  文字列は，もしそれらが異なったマーク付きエンコーディングにあっても
  UTF-8 に翻訳された時に一致すれば同等と見做される．

  既定であるが，もし \code{attrib.as.set} が真なら属性の比較は
  それらを集合として眺める(ベクトルとしてではないので並び方はテストされない)．

  もし \code{ignore.bytecode} が真(既定)ならば，バイトコンパイルされた関数のコード
  (\code{\link{cmpfun}} を見よ)は比較では無視される．
  もしこれが偽ならば，関数はそれらが同じコンパイルコードのコピーである
  (もしくはどちらもコンパイルされていない)時だけ
  等しいと比較される．二つの異なったコンパイル結果が等しいかどうかをチェック
  するためには \code{\link{disassemble}()} の結果を比較すべきであろう．

  クラス \code{"POSIXlt"} の日付時刻に対して \code{identical} を使いたいとは
  恐らく思わないであろう：異なったタイムゾーン中の異なった時間が同じ時間を
  表し得，タイムゾーンが複数の名前をもつだけでなく，
  成分の幾つかはオプションである．

  \code{identical(x, y, FALSE, FALSE, FALSE, FALSE)} は正確な同等性を
  気難しくテストする．
}
\value{
  単一の論理値 \code{TRUE} 又は \code{FALSE} で決して \code{NA} にならず，
  一つ以外の値にも決してならない．
}
\author{John Chambers and R Core}

\references{
  Chambers, J. M. (1998)
  \emph{Programming with Data.  A Guide to the S Language}.
  Springer.
}
\seealso{
  二つのオブジェクトが如何に異なるかの説明には \code{\link{all.equal}}；
  要素ごとの比較を生成する演算子については \link{Comparison}．
  \code{\link{isTRUE}} は \code{identical} に基づく簡単なラッパである．
}
\examples{
identical(1, NULL) ## FALSE -- これを == を使って試みないこと
identical(1, 1.)   ## R では TRUE(双方は倍精度実数として保管されている)
identical(1, as.integer(1)) ## FALSE, 異なった型で保管されている

x <- 1.0; y <- 0.99999999999
## 数値的なぼやけを認めてオブジェクトの同等性をテストするには：
(E <- all.equal(x, y))
isTRUE(E) # これは単に次を使うことを単純に定義している
identical(TRUE, E)
## もし all.equal がオブジェクトが異なると考えると，それは
## 文字列を返し，そして上の表現は FALSE と評価される

## 普通ではない R オブジェクトに対しても：
identical(.GlobalEnv, environment())

### ------- 気難しいフラグ : -----------------------------

## 悪名高い例：
identical(0., -0.) # TRUE, つまり差が見つけられない
identical(0., -0., num.eq = FALSE)
## 同様：
identical(NaN, -NaN) # TRUE
identical(NaN, -NaN, single.NA = FALSE) # ビットレベルで差異
## 関数に対して：
f <- function(x) x
f
g <- compiler::cmpfun(f)
g
identical(f, g)
identical(f, g, ignore.bytecode = FALSE)
\dontshow{
m0 <- m <- structure(cbind(I = 1, a = 1:3), foo = "bar", class = "matrix")
attributes(m0) <- rev(attributes(m))
names(attributes(m0)) # 'dim' は最初に残る，興味深いことに...

stopifnot(identical(0, -0),     !identical(0, -0, num.eq = FALSE),
          identical(NaN, -NaN), !identical(NaN, -NaN, single.NA = FALSE),
          identical(m, m0),     !identical(m, m0, attrib.as.set = FALSE) )
}
}
\keyword{ programming }
\keyword{ logic }
\keyword{ iteration }
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/identical.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2001-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{identical}
%\alias{identical}
%\title{Test Objects for Exact Equality}
%\description{
%  The safe and reliable way to test two objects for being
%  \emph{exactly} equal.  It returns \code{TRUE} in this case,
%  \code{FALSE} in every other case.
%}
%\usage{
%identical(x, y, num.eq = TRUE, single.NA = TRUE, attrib.as.set = TRUE,
%          ignore.bytecode = TRUE, ignore.environment = FALSE)
%}
%\arguments{
%  \item{x, y}{any \R objects.}
%  \item{num.eq}{logical indicating if (\code{\link{double}} and
%    \code{\link{complex}} non-\code{\link{NA}}) numbers should be
%    compared using \code{\link{==}} (\sQuote{equal}), or by bitwise
%    comparison.  The latter (non-default) differentiates between
%    \code{-0} and \code{+0}.}
%  \item{single.NA}{logical indicating if there is conceptually just one numeric
%    \code{\link{NA}} and one \code{\link{NaN}};  \code{single.NA = FALSE}
%    differentiates bit patterns.}
%  \item{attrib.as.set}{logical indicating if \code{\link{attributes}} of
%    \code{x} and \code{y} should be treated as \emph{unordered} tagged
%    pairlists (\dQuote{sets}); this currently also applies to
%    \code{\link{slot}}s of S4 objects.  It may well be too strict to set
%    \code{attrib.as.set = FALSE}.}
%  \item{ignore.bytecode}{logical indicating if byte code should be
%    ignored when comparing \link{closure}s.}
%  \item{ignore.environment}{logical indicating if their environments
%    should be ignored when comparing \link{closure}s.}
%}
%\details{
%  A call to \code{identical} is the way to test exact equality in
%  \code{if} and \code{while} statements, as well as in logical
%  expressions that use \code{&&} or \code{||}.  In all these
%  applications you need to be assured of getting a single logical
%  value.
%
%  Users often use the comparison operators, such as \code{==} or
%  \code{!=}, in these situations.  It looks natural, but it is not what
%  these operators are designed to do in \R.  They return an object like
%  the arguments.  If you expected \code{x} and \code{y} to be of length
%  1, but it happened that one of them was not, you will \emph{not} get a
%  single \code{FALSE}.  Similarly, if one of the arguments is \code{NA},
%  the result is also \code{NA}.  In either case, the expression
%  \code{if(x == y)....} won't work as expected.
%
%  The function \code{all.equal} is also sometimes used to test equality
%  this way, but was intended for something different:  it allows for
%  small differences in numeric results.
%
%  The computations in \code{identical} are also reliable and usually
%  fast.  There should never be an error.  The only known way to kill
%  \code{identical} is by having an invalid pointer at the C level,
%  generating a memory fault.  It will usually find inequality quickly.
%  Checking equality for two large, complicated objects can take longer
%  if the objects are identical or nearly so, but represent completely
%  independent copies.  For most applications, however, the computational cost
%  should be negligible.
%
%  If \code{single.NA} is true, as by default, \code{identical} sees
%  \code{\link{NaN}} as different from \code{\link{NA_real_}}, but all
%  \code{NaN}s are equal (and all \code{NA} of the same type are equal).
%
%  Character strings are regarded as identical if they are in different
%  marked encodings but would agree when translated to UTF-8.
%
%  If \code{attrib.as.set} is true, as by default, comparison of
%  attributes view them as a set (and not a vector, so order is not
%  tested).
%
%  If \code{ignore.bytecode} is true (the default), the compiled
%  bytecode of a function (see \code{\link{cmpfun}}) will be ignored in
%  the comparison.  If it is false, functions will compare equal only if
%  they are copies of the same compiled object (or both are
%  uncompiled).  To check whether two different compiles are equal, you
%  should compare the results of \code{\link{disassemble}()}.
%
%  You almost never want to use \code{identical} on datetimes of class
%  \code{"POSIXlt"}: not only can different times in the different
%  time zones represent the same time and time zones have multiple names,
%  but several of the components are optional.
%
%  Note that \code{identical(x, y, FALSE, FALSE, FALSE, FALSE)} pickily
%  tests for exact equality.
%}
%\value{
%  A single logical value, \code{TRUE} or \code{FALSE}, never \code{NA}
%  and never anything other than a single value.
%}
%\author{John Chambers and R Core}
%
%\references{
%  Chambers, J. M. (1998)
%  \emph{Programming with Data.  A Guide to the S Language}.
%  Springer.
%}
%\seealso{
%  \code{\link{all.equal}} for descriptions of how two objects differ;
%  \link{Comparison} for operators that generate elementwise comparisons.
%  \code{\link{isTRUE}} is a simple wrapper based on \code{identical}.
%}
%\examples{
%identical(1, NULL) ## FALSE -- don't try this with ==
%identical(1, 1.)   ## TRUE in R (both are stored as doubles)
%identical(1, as.integer(1)) ## FALSE, stored as different types
%
%x <- 1.0; y <- 0.99999999999
%## how to test for object equality allowing for numeric fuzz :
%(E <- all.equal(x, y))
%isTRUE(E) # which is simply defined to just use
%identical(TRUE, E)
%## If all.equal thinks the objects are different, it returns a
%## character string, and the above expression evaluates to FALSE
%
%## even for unusual R objects :
%identical(.GlobalEnv, environment())
%
%### ------- Pickyness Flags : -----------------------------
%
%## the infamous example:
%identical(0., -0.) # TRUE, i.e. not differentiated
%identical(0., -0., num.eq = FALSE)
%## similar:
%identical(NaN, -NaN) # TRUE
%identical(NaN, -NaN, single.NA = FALSE) # differ on bit-level
%## for functions:
%f <- function(x) x
%f
%g <- compiler::cmpfun(f)
%g
%identical(f, g)
%identical(f, g, ignore.bytecode = FALSE)
%\dontshow{
%m0 <- m <- structure(cbind(I = 1, a = 1:3), foo = "bar", class = "matrix")
%attributes(m0) <- rev(attributes(m))
%names(attributes(m0)) # 'dim' remains first, interestingly...
%
%stopifnot(identical(0, -0),     !identical(0, -0, num.eq = FALSE),
%          identical(NaN, -NaN), !identical(NaN, -NaN, single.NA = FALSE),
%          identical(m, m0),     !identical(m, m0, attrib.as.set = FALSE) )
%}
%}
%\keyword{ programming }
%\keyword{ logic }
%\keyword{ iteration }
%
\encoding{UTF8}
