% File src/library/base/man/ls.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{ls}
\alias{ls}
\alias{objects}
\title{List Objects}
\usage{
ls(name, pos = -1L, envir = as.environment(pos),
   all.names = FALSE, pattern, sorted = TRUE)
objects(name, pos= -1L, envir = as.environment(pos),
        all.names = FALSE, pattern, sorted = TRUE)
}
\arguments{
  \item{name}{利用可能なオブジェクトのリスティングに於いてどの環境を使うか．
    既定は\emph{現在の}環境．過去との互換性から \code{name} と
    名付けられているが，この引数は環境を任意の型式で指定できる，
    \sQuote{詳細}節を見よ．}
  \item{pos}{環境を検索リスト中の位置として指定する \code{name} への
    別の引数．主に過去との互換性ためにここにある．}
  \item{envir}{環境を指定する \code{name} への
    別の引数．主に過去との互換性ためにここにある．}
  \item{all.names}{論理値．もし \code{TRUE} なら，全てのオブジェクトの名前が
    返される．もし \code{FALSE} なら \samp{.} で始まる名前は除外される．}
  \item{pattern}{オプションの正規表現．
    \code{pattern} にマッチするオブジェクトだけが返される．
    \code{\link{glob2rx}} はワイルドカードパターンを正規表現に変換するのに使える．}
  \item{sorted}{結果の文字列をアルファベット順にソートするかどうかを指示する
    論理値．これは \code{ls()} がほとんどの時間を費やす部分になる
    可能性があることを注意する．}
}
\description{
  \code{ls} と \code{objects} は指定された環境中のオブジェクトの名前を与える
  文字列ベクトルを返す．トップレベルのプロンプトに対して引数無しで
  使われると \code{ls} はユーザが定義したデータセットと関数を示す．
  関数内部で引数無しで使われると関数の局所引数の名前を返す：
  これは \code{browser} との関連で有用である．
}
\details{
  \code{name} 引数はそこからオブジェクト名が取り出される環境を
  幾つかの方法の一つで指定できる：
  整数として(検索リスト中の位置)；
  検索リスト中の要素の名前の文字列；
  もしくは現在アクティブな関数呼び出しにアクセスする明示的な
  \code{\link{environment}} (\code{\link{sys.frame}} の使用を含む)．
  既定では \code{ls} 又は \code{objects} への呼び出しの環境が
  使われる．\code{pos} と \code{envir} 引数は環境を指定する別の方法であるが，
  主に過去への互換性のためにここにある．

  \code{sorted = TRUE} に対する文字列の\emph{順序}はロケール依存である，
  \code{\link{Sys.getlocale}} を見よ．もし \code{sorted = FALSE} ならば
  順序は任意，もし環境がハッシュされていればオブジェクトが挿入された順序，等．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  ワイルドカードパターンを正規表現に変換するには \code{\link{glob2rx}}．

  \code{\link{str}} に基づく長いリスティングには \code{\link{ls.str}}；
  検索パス全体からオブジェクトを見つけるには \code{\link{apropos}} (又は \code{\link{find}})；
  \sQuote{正規表現}に関するより詳細は \code{\link{grep}}；
  オブジェクト指向プログラミングに対しては \code{\link{class}}, \code{\link{methods}} 等．
}
\examples{
.Ob <- 1
ls(pattern = "O")
ls(pattern= "O", all.names = TRUE)    # 同様に ".[foo]" を示す

# myfunc 内部には変数が定義されていないので空のリストを示す
myfunc <- function() {ls()}
myfunc()

# myfunc 内部で局所変数を定義
myfunc <- function() {y <- 1; ls()}
myfunc()                # "y" を示す
}
\keyword{environment}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/ls.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ls}
%\alias{ls}
%\alias{objects}
%\title{List Objects}
%\usage{
%ls(name, pos = -1L, envir = as.environment(pos),
%   all.names = FALSE, pattern, sorted = TRUE)
%objects(name, pos= -1L, envir = as.environment(pos),
%        all.names = FALSE, pattern, sorted = TRUE)
%}
%\arguments{
%  \item{name}{which environment to use in listing the available objects.
%    Defaults to the \emph{current} environment.  Although called
%    \code{name} for back compatibility, in fact this argument can
%    specify the environment in any form; see the \sQuote{Details} section.}
%  \item{pos}{an alternative argument to \code{name} for specifying the
%    environment as a position in the search list.  Mostly there for
%    back compatibility.}
%  \item{envir}{an alternative argument to \code{name} for specifying the
%    environment.  Mostly there for back compatibility.}
%  \item{all.names}{a logical value.  If \code{TRUE}, all
%    object names are returned.  If \code{FALSE}, names which begin with a
%    \samp{.} are omitted.}
%  \item{pattern}{an optional \link{regular expression}.  Only names
%    matching \code{pattern} are returned.  \code{\link{glob2rx}} can be
%    used to convert wildcard patterns to regular expressions.}
%  \item{sorted}{logical indicating if the resulting
%    \code{\link{character}} should be sorted alphabetically.  Note that
%    this is part of \code{ls()} may take most of the time.}
%}
%\description{
%  \code{ls} and \code{objects} return a vector of character strings
%  giving the names of the objects in the specified environment.  When
%  invoked with no argument at the top level prompt, \code{ls} shows what
%  data sets and functions a user has defined.  When invoked with no
%  argument inside a function, \code{ls} returns the names of the
%  function's local variables: this is useful in conjunction with
%  \code{browser}.
%}
%\details{
%  The \code{name} argument can specify the  environment from which
%  object names are taken in one of several forms:
%  as an integer (the position in the \code{\link{search}} list); as
%  the character string name of an element in the search list; or as an
%  explicit \code{\link{environment}} (including using
%  \code{\link{sys.frame}} to access the currently active function calls).
%  By default, the environment of the call to \code{ls} or \code{objects}
%  is used. The \code{pos} and \code{envir} arguments are an alternative
%  way to specify an environment, but are primarily there for back
%  compatibility.
%
%  Note that the \emph{order} of strings for \code{sorted = TRUE} is
%  locale dependent, see \code{\link{Sys.getlocale}}.  If \code{sorted =
%    FALSE} the order is arbitrary, depending if the environment is
%  hashed, the order of insertion of objects, \dots.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{glob2rx}} for converting wildcard patterns to regular
%  expressions.
%
%  \code{\link{ls.str}} for a long listing based on \code{\link{str}}.
%  \code{\link{apropos}} (or \code{\link{find}})
%  for finding objects in the whole search path;
%  \code{\link{grep}} for more details on \sQuote{regular expressions};
%  \code{\link{class}}, \code{\link{methods}}, etc., for
%  object-oriented programming.
%}
%\examples{
%.Ob <- 1
%ls(pattern = "O")
%ls(pattern= "O", all.names = TRUE)    # also shows ".[foo]"
%
%# shows an empty list because inside myfunc no variables are defined
%myfunc <- function() {ls()}
%myfunc()
%
%# define a local variable inside myfunc
%myfunc <- function() {y <- 1; ls()}
%myfunc()                # shows "y"
%}
%\keyword{environment}
%
\encoding{UTF8}
