% File src/library/base/man/memCompress.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-11 R Core Team
% Distributed under GPL 2 or later

\name{memCompress}
\alias{memCompress}
\alias{memDecompress}
\concept{gzip}
\concept{bzip2}
\concept{lzma}
\title{In-memory Compression and Decompression}
\description{
  バイトベクトルのメモリ内部での圧縮と解凍．
}
\usage{
memCompress(from, type = c("gzip", "bzip2", "xz", "none"))

memDecompress(from,
              type = c("unknown", "gzip", "bzip2", "xz", "none"),
              asChar = FALSE)
}
\arguments{
  \item{from}{バイトベクトル．\code{memCompress} に対しては文字列ベクトルは
    \code{"\n"} で分離されてバイトベクトルに変換される．}
  \item{type}{文字列，圧縮のタイプ．恐らく一つの文字に簡略化可能で，
    既定値は候補者の最初．}
  \item{asChar}{論理値：結果を文字列に変換するか?}
}

\details{
  \code{type = "none"} は入力を未変更で渡すが，
  \code{type} が変数の時は有用かもしれない．

  \code{type = "unknown"} は適用される圧縮のタイプ(もしあれば)を検出しようと試みる：
  これは \command{bzip2} に対しては常に成功し，そして
  適当なヘッダがあれば他の形式に対しても成功する．
  これは \command{gzip} プログラムによりファイル
  (そして \code{\link{gzfile}} で書かれるファイル)に加えられる
  \sQuote{マジック}ヘッダー(\code{"\x1f\x8b"})を自動検出するが，
  \code{memCompress} はそうしたヘッダを加えない．

  \command{bzip2} 圧縮は常にヘッダ (\code{"BZh"}) を加える．

  \code{type = "xz"} による圧縮はファイルを 
  \command{xz -9e} (\sQuote{マジック}ヘッダーを含め)で
  圧縮するのと同等である：解凍はバージョン 4.999 の \command{xz} と
  \command{lzma} のある種のバージョンで圧縮された任意のファイルに
  対処出来るはずである．現在処理できない他のバージョン，
  特に\sQuote{バイト}ストリーム，もある．

  全ての圧縮タイプは入力を展開出来る：\code{"gzip"} と
  \code{"bzip"} に対しては最大の展開が知られており，従って
  \code{memCompress} は常に十分な空間を確保できる．
  \code{"xz"} に対しては出力が大きすぎると圧縮が失敗する
  可能性がある(しかしまずありそうもない)．
}

\value{
  バイトベクトルか文字列(もし \code{asChar = TRUE} なら)．
}

\seealso{
  \link{connections}.

  データ圧縮の背景については \url{https://en.wikipedia.org/wiki/Data_compression},
  \url{http://zlib.net/},
  \url{https://en.wikipedia.org/wiki/Gzip}, \url{http://www.bzip.org/},
  \url{https://en.wikipedia.org/wiki/Bzip2}, \url{http://tukaani.org/xz/}
  そして使われる特定のスキームに関する参考文献は
  \url{https://en.wikipedia.org/wiki/Xz}．
}

\examples{
txt <- readLines(file.path(R.home("doc"), "COPYING"))
sum(nchar(txt))
txt.gz <- memCompress(txt, "g")
length(txt.gz)
txt2 <- strsplit(memDecompress(txt.gz, "g", asChar = TRUE), "\n")[[1]]
stopifnot(identical(txt, txt2))
txt.bz2 <- memCompress(txt, "b")
length(txt.bz2)
## bzip2 を自動検出できる:
txt3 <- strsplit(memDecompress(txt.bz2, asChar = TRUE), "\n")[[1]]
stopifnot(identical(txt, txt3))

## xz 圧縮は大きなオブジェクトに対してだけ価値がある
txt.xz <- memCompress(txt, "x")
length(txt.xz)
txt3 <- strsplit(memDecompress(txt.xz, asChar = TRUE), "\n")[[1]]
stopifnot(identical(txt, txt3))
}

\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/memCompress.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-11 R Core Team
%% Distributed under GPL 2 or later
%
%\name{memCompress}
%\alias{memCompress}
%\alias{memDecompress}
%\concept{gzip}
%\concept{bzip2}
%\concept{lzma}
%\title{In-memory Compression and Decompression}
%\description{
%  In-memory compression or decompression for raw vectors.
%}
%\usage{
%memCompress(from, type = c("gzip", "bzip2", "xz", "none"))
%
%memDecompress(from,
%              type = c("unknown", "gzip", "bzip2", "xz", "none"),
%              asChar = FALSE)
%}
%\arguments{
%  \item{from}{A raw vector.  For \code{memCompress} a character vector
%    will be converted to a raw vector with character strings separated
%    by \code{"\n"}.}
%  \item{type}{character string, the type of compression.  May be
%    abbreviated to a single letter, defaults to the first of the alternatives.}
%  \item{asChar}{logical: should the result be converted to a character
%    string?}
%}
%
%\details{
%  \code{type = "none"} passes the input through unchanged, but may be
%  useful if \code{type} is a variable.
%
%  \code{type = "unknown"} attempts to detect the type of compression
%  applied (if any): this will always succeed for \command{bzip2}
%  compression, and will succeed for other forms if there is a suitable
%  header.  It will auto-detect the \sQuote{magic} header
%  (\code{"\x1f\x8b"}) added to files by the \command{gzip} program (and
%  to files written by \code{\link{gzfile}}), but \code{memCompress} does
%  not add such a header.
%
%  \command{bzip2} compression always adds a header (\code{"BZh"}).
%
%  Compressing with \code{type = "xz"} is equivalent to compressing a
%  file with \command{xz -9e} (including adding the \sQuote{magic}
%  header): decompression should cope with the contents of any file
%  compressed with \command{xz} version 4.999 and some versions of
%  \command{lzma}.  There are other versions, in particular \sQuote{raw}
%  streams, that are not currently handled.
%
%  All the types of compression can expand the input: for \code{"gzip"}
%  and \code{"bzip"} the maximum expansion is known and so
%  \code{memCompress} can always allocate sufficient space.  For
%  \code{"xz"} it is possible (but extremely unlikely) that compression
%  will fail if the output would have been too large.
%}
%
%\value{
%  A raw vector or a character string (if \code{asChar = TRUE}).
%}
%
%\seealso{
%  \link{connections}.
%
%  \url{https://en.wikipedia.org/wiki/Data_compression} for background on
%  data compression, \url{http://zlib.net/},
%  \url{https://en.wikipedia.org/wiki/Gzip}, \url{http://www.bzip.org/},
%  \url{https://en.wikipedia.org/wiki/Bzip2}, \url{http://tukaani.org/xz/}
%  and \url{https://en.wikipedia.org/wiki/Xz} for references about the
%  particular schemes used.
%}
%
%\examples{
%txt <- readLines(file.path(R.home("doc"), "COPYING"))
%sum(nchar(txt))
%txt.gz <- memCompress(txt, "g")
%length(txt.gz)
%txt2 <- strsplit(memDecompress(txt.gz, "g", asChar = TRUE), "\n")[[1]]
%stopifnot(identical(txt, txt2))
%txt.bz2 <- memCompress(txt, "b")
%length(txt.bz2)
%## can auto-detect bzip2:
%txt3 <- strsplit(memDecompress(txt.bz2, asChar = TRUE), "\n")[[1]]
%stopifnot(identical(txt, txt3))
%
%## xz compression is only worthwhile for large objects
%txt.xz <- memCompress(txt, "x")
%length(txt.xz)
%txt3 <- strsplit(memDecompress(txt.xz, asChar = TRUE), "\n")[[1]]
%stopifnot(identical(txt, txt3))
%}
%
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
