% File src/library/base/man/noquote.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{noquote}
\alias{noquote}
\alias{print.noquote}
\alias{as.matrix.noquote}
\alias{c.noquote}
\alias{[.noquote}
\title{Class for \sQuote{no quote} Printing of Character Strings}
\description{
  文字列を引用符なしにプリントする．
}
\usage{
noquote(obj)

\method{print}{noquote}(x, \dots)

\method{c}{noquote}(\dots, recursive = FALSE)
}
\arguments{
  \item{obj}{任意の \R オブジェクト，典型的には
    文字列ベクトル．}
  \item{x}{クラス \code{"noquote"} のオブジェクト．}
  \item{\dots}{\code{\link{print}} のような次のメソッドに渡されるオプション．}
  \item{recursive}{総称的な \code{\link{c}} 関数との互換性のため．}
}
\details{
  \code{noquote} はその引数をクラス \code{"noquote"} のオブジェクトとして
  返す．\code{c()} に対するメソッドと，部分抽出でクラス属性が失われないことを
  保証する添字メソッド (\code{"[.noquote"}) がある．
  プリントメソッド (\code{print.noquote}) は文字列を引用符無しでプリントする
  (\code{"\dots"})．

  これらの関数はユーティリティとして，また
  (S3)クラスとオブジェクト指向プログラミングの例として存在する．
}
\author{Martin Maechler \email{maechler@stat.math.ethz.ch}}
\seealso{
  \code{\link{methods}}, \code{\link{class}}, \code{\link{print}}.
}
\examples{
letters
nql <- noquote(letters)
nql
nql[1:4] <- "oh"
nql[1:12]

cmp.logical <- function(log.v)
{
  ## 目的：論理値のコンパクトなプリント
  log.v <- as.logical(log.v)
  noquote(if(length(log.v) == 0)"()" else c(".","|")[1 + log.v])
}
cmp.logical(stats::runif(20) > 0.8)
}
\keyword{print}
\keyword{methods}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/noquote.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{noquote}
%\alias{noquote}
%\alias{print.noquote}
%\alias{as.matrix.noquote}
%\alias{c.noquote}
%\alias{[.noquote}
%\title{Class for \sQuote{no quote} Printing of Character Strings}
%\description{
%  Print character strings without quotes.
%}
%\usage{
%noquote(obj)
%
%\method{print}{noquote}(x, \dots)
%
%\method{c}{noquote}(\dots, recursive = FALSE)
%}
%\arguments{
%  \item{obj}{any \R object, typically a vector of
%    \code{\link{character}} strings.}
%  \item{x}{an object of class \code{"noquote"}.}
%  \item{\dots}{further options passed to next methods, such as \code{\link{print}}.}
%  \item{recursive}{for compatibility with the generic \code{\link{c}} function.}
%}
%\details{
%  \code{noquote} returns its argument as an object of class
%  \code{"noquote"}.  There is a method for \code{c()} and subscript
%  method (\code{"[.noquote"}) which ensures that the class is not lost
%  by subsetting.  The print method (\code{print.noquote}) prints
%  character strings \emph{without} quotes (\code{"\dots"}).
%
%  These functions exist both as utilities and as an example of using (S3)
%  \code{\link{class}} and object orientation.
%}
%\author{Martin Maechler \email{maechler@stat.math.ethz.ch}}
%\seealso{
%  \code{\link{methods}}, \code{\link{class}}, \code{\link{print}}.
%}
%\examples{
%letters
%nql <- noquote(letters)
%nql
%nql[1:4] <- "oh"
%nql[1:12]
%
%cmp.logical <- function(log.v)
%{
%  ## Purpose: compact printing of logicals
%  log.v <- as.logical(log.v)
%  noquote(if(length(log.v) == 0)"()" else c(".","|")[1 + log.v])
%}
%cmp.logical(stats::runif(20) > 0.8)
%}
%\keyword{print}
%\keyword{methods}
%\keyword{utilities}
%
\encoding{UTF8}
