% File src/library/base/man/ns-load.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{ns-load}
\title{Loading and Unloading Name Spaces}
%% Currently considered "main" help page on namespaces
%%                       --------------- -> \references{}, \seealso{}
\alias{attachNamespace}
\alias{loadNamespace}
\alias{requireNamespace}
\alias{loadedNamespaces}
\alias{unloadNamespace}
\alias{isNamespaceLoaded}

\description{
  名前空間をロード/アンロードする関数．
}
\usage{
attachNamespace(ns, pos = 2L, depends = NULL)
loadNamespace(package, lib.loc = NULL,
              keep.source = getOption("keep.source.pkgs"),
              partial = FALSE, versionCheck = NULL)
requireNamespace(package, ..., quietly = FALSE)
loadedNamespaces()
unloadNamespace(ns)
isNamespaceLoaded(name)
}
\arguments{
  \item{ns}{文字列または名前空間オブジェクト．}
  \item{pos}{付加する位置を指定する整数．}
  \item{depends}{\code{NULL} かパッケージ中の \code{.Depends} オブジェクト
    に記録される従属性の文字列ベクトル．}
  \item{package}{ロードするパッケージ/名前空間を指定する文字列．}
  \item{lib.loc}{ライブラリの検索パスを指定する文字列ベクトル．}
  \item{keep.source}{今はパッケージのインストールの途中を除いて無視される．
    より詳細は \code{\link{library}} のこの引数を参照．
  }
  \item{partial}{論理値：もし真ならロードしたコードの直後に停止．}
  \item{versionCheck}{\code{NULL} かバージョンの指定(成分
    \code{op} と \code{version} を持つリスト)．}
  \item{quietly}{論理値：進行とエラーのメッセージは抑制するか?}
  \item{name}{パッケージの文字列又は\sQuote{名前}．
    \code{\link{as.symbol}} を見よ．例えば \code{"stats"}．}
  \item{\dots}{\code{loadNamespace} に渡される追加引数．}
}
\details{
  関数 \code{loadNamespace} と \code{attachNamespace} は普通
  \code{\link{library}} が名前空間と必要な移入をロードするために
  使われた時暗黙のうちに使われる．しかしながらこれらの関数を直接
  呼び出すことが有用な場合もある．

  \code{loadNamespace} は指定された名前空間をロードし，それを内部的な
  データベースに登録する．既にその名前の一つでロードされている
  名前空間をロード要求は何の効果も持たない．
  引数は \code{\link{library}} の対応する引数と同じ意味を持ち，
  そのヘルプページは特定のインストール済みパッケージが選ばれるようになるかの詳細を
  説明する．ロード後に \code{loadNamespace} は
  \code{\link{.onLoad}} という名前のフック関数を名前空中の内部変数として
  探す(これは移出されてはならない)．部分的なロードが遅延ロードを持つ
  インストールをサポートするために使われる．

  \code{loadNamespace} はそれが検索パスにロードした名前空間を付加しない．
  \code{attachNamespace} は名前空間の移出値を含むフレームを
  検索パスに付加するのに使うことが出来る
  (しかしこれは \code{\link{library}} がほとんど常に行うことである)．
  フック関数 \code{\link{.onAttach}} は名前空間の移出が付加された
  後に実行される．

  \code{requireNamespace} は \code{loadNamespace} に対するラッパで，
  論理値を返す \code{\link{require}} の類似物である．

  \code{loadedNamespaces} はロードされた名前空間の名前の
  文字列ベクトルを返す．

  \code{isNamespaceLoaded(pkg)} は \code{pkg \%in\% loadedNamespaces()}
  と同値であるがより効率的である．

  \code{unloadNamespace} は名前空間のアンロードを強制することに使える．
  もし名前空間が付加されるとそれはまず除去され，その際もし移出されていれば名前空間
  中の \code{\link{.onDetach}} か \code{.Last.lib} 関数が実行される．
  もし名前空間が他のロードされた名前空間から移出されていればエラーが発生し，
  名前空間はアンロードされない．もし定義されていればフック関数
  \code{\link{.onUnload}} が内部レジストリから名前空間を除去する前に
  実行される．

  名前のアンロードと再ロードに関しては \code{\link{detach}} に
  対するヘルプのコメントを見よ．
}
\value{
  \code{attachNamespace} はそれが検索パスに加えたパッケージ環境を
  不可視で返す．

  \code{loadNamespace} は名前環境を返す，
  既にロードされているものか関数がロードを引き起こしたもの．

  \code{requireNamespace} はもし成功すれば \code{TRUE}，さもなければ
  \code{FALSE} を返す．

  \code{loadedNamespaces} は文字列ベクトルを返す．

  \code{unloadNamespace} は \code{NULL} を不可視で返す．
}
\seealso{
  \code{\link{getNamespace}}, \code{\link{asNamespace}},
  \code{\link{topenv}}, \code{\link{.onLoad}} (等);
  更に \code{\link{environment}}．
}
\references{
  マニュアル \sQuote{Writing R Extensions} の節 \dQuote{Package namespaces}．
}
\author{Luke Tierney and R-core}
\examples{
 (lns <- loadedNamespaces())
 statL <- isNamespaceLoaded("stats")% checks work also when it is *not* loaded
 stopifnot( identical(statL, "stats" \%in\% lns) )

 ## 文字列 "foo" とシンボル 'foo' はここでは互いに交換して使える：
 stopifnot( identical(isNamespaceLoaded(  "foo"   ), FALSE),
            identical(isNamespaceLoaded(quote(foo)), FALSE),
            identical(isNamespaceLoaded(quote(stats)), statL))
}
\keyword{data}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/ns-load.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ns-load}
%\title{Loading and Unloading Name Spaces}
%%% Currently considered "main" help page on namespaces
%%%                       --------------- -> \references{}, \seealso{}
%\alias{attachNamespace}
%\alias{loadNamespace}
%\alias{requireNamespace}
%\alias{loadedNamespaces}
%\alias{unloadNamespace}
%\alias{isNamespaceLoaded}
%
%\description{
%  Functions to load and unload name spaces.
%}
%\usage{
%attachNamespace(ns, pos = 2L, depends = NULL)
%loadNamespace(package, lib.loc = NULL,
%              keep.source = getOption("keep.source.pkgs"),
%              partial = FALSE, versionCheck = NULL)
%requireNamespace(package, ..., quietly = FALSE)
%loadedNamespaces()
%unloadNamespace(ns)
%isNamespaceLoaded(name)
%}
%\arguments{
%  \item{ns}{string or name space object.}
%  \item{pos}{integer specifying position to attach.}
%  \item{depends}{\code{NULL} or a character vector of dependencies to be
%    recorded in object \code{.Depends} in the package.}
%  \item{package}{string naming the package/name space to load.}
%  \item{lib.loc}{character vector specifying library search path.}
%  \item{keep.source}{Now ignored except during package installation.
%    For more details see this argument to \code{\link{library}}.
%  }
%  \item{partial}{logical; if true, stop just after loading code.}
%  \item{versionCheck}{\code{NULL} or a version specification (a list
%    with components \code{op} and \code{version})).}
%  \item{quietly}{logical: should progress and error messages be suppressed?}
%  \item{name}{string or \sQuote{name}, see \code{\link{as.symbol}},
%    of a package, e.g., \code{"stats"}.}
%  \item{\dots}{further arguments to be passed to \code{loadNamespace}.}
%}
%\details{
%  The functions \code{loadNamespace} and \code{attachNamespace} are
%  usually called implicitly when \code{\link{library}} is used to load a name
%  space and any imports needed.  However it may be useful at times to
%  call these functions directly.
%
%  \code{loadNamespace} loads the specified name space and registers it in
%  an internal data base.  A request to load a name space when one of that
%  name is already loaded has no effect.  The arguments have the same
%  meaning as the corresponding arguments to \code{\link{library}}, whose
%  help page explains the details of how a particular installed package
%  comes to be chosen.  After loading, \code{loadNamespace} looks for a
%  hook function named \code{\link{.onLoad}} as an internal variable in
%  the name space (it should not be exported).  Partial loading is used
%  to support installation with lazy-loading.
%
%  \code{loadNamespace} does not attach the name space it loads to the
%  search path.  \code{attachNamespace} can be used to attach a frame
%  containing the exported values of a name space to the search path (but
%  this is almost always done \emph{via} \code{\link{library}}).  The
%  hook function \code{\link{.onAttach}} is run after the name space
%  exports are attached.
%
%  \code{requireNamespace} is a wrapper for \code{loadNamespace}
%  analogous to \code{\link{require}} that returns a logical value.
%
%  \code{loadedNamespaces} returns a character vector of the names of
%  the loaded name spaces.
%
%  \code{isNamespaceLoaded(pkg)} is equivalent to but more efficient than
%  \code{pkg \%in\% loadedNamespaces()}.
%
%  \code{unloadNamespace} can be used to attempt to force a name space to
%  be unloaded.  If the name space is attached, it is first
%  \code{\link{detach}}ed, thereby running a \code{\link{.onDetach}} or
%  \code{.Last.lib} function in the name space if one is exported.  An
%  error is signaled and the name space is not unloaded if the name space
%  is imported by other loaded name spaces.  If defined, a hook function
%  \code{\link{.onUnload}} is run before removing the name space from the
%  internal registry.
%
%  See the comments in the help for \code{\link{detach}} about some
%  issues with unloading and reloading name spaces.
%}
%\value{
%  \code{attachNamespace} returns invisibly the package environment it
%  adds to the search path.
%
%  \code{loadNamespace} returns the name space environment, either one
%  already loaded or the one the function causes to be loaded.
%
%  \code{requireNamespace} returns \code{TRUE} if it succeeds or
%  \code{FALSE}.
%
%  \code{loadedNamespaces} returns a \code{\link{character}} vector.
%
%  \code{unloadNamespace} returns \code{NULL}, invisibly.
%}
%\seealso{
%  \code{\link{getNamespace}}, \code{\link{asNamespace}},
%  \code{\link{topenv}}, \code{\link{.onLoad}} (etc);
%  further \code{\link{environment}}.
%}
%\references{
%  The \sQuote{Writing R Extensions} manual, section \dQuote{Package namespaces}.
%}
%\author{Luke Tierney and R-core}
%\examples{
% (lns <- loadedNamespaces())
% statL <- isNamespaceLoaded("stats")% checks work also when it is *not* loaded
% stopifnot( identical(statL, "stats" \%in\% lns) )
%
% ## The string "foo" and the symbol 'foo' can be used interchangably here:
% stopifnot( identical(isNamespaceLoaded(  "foo"   ), FALSE),
%            identical(isNamespaceLoaded(quote(foo)), FALSE),
%            identical(isNamespaceLoaded(quote(stats)), statL))
%}
%\keyword{data}
%\keyword{utilities}
%
\encoding{UTF8}
