% File src/library/base/man/numeric.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{numeric}
\title{Numeric Vectors}
\alias{numeric}
\alias{as.numeric}
\alias{is.numeric}
\alias{is.numeric.Date}
\alias{is.numeric.POSIXt}
\description{
  型 \code{"numeric"} のオブジェクトを作る，検査する．
  \code{is.numeric} はオブジェクトが数値として解釈できるかどうか
  をテストするより一般的な検査．
}
\usage{
numeric(length = 0)
as.numeric(x, \dots)
is.numeric(x)
}
\arguments{
  \item{length}{希望の長さを指定する非負整数．
    倍精度値は整数に変換される：
    長さが1以外の引数を与えるとエラーになる．}
  \item{x}{変換又は検査されるオブジェクト．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\details{
  \code{numeric} は \code{\link{double}} (そして \code{real}) と同値である．
  これは各要素が \code{0} の指定された長さの倍精度実数値ベクトルを作る．

  \code{as.numeric} は総称的関数であるが，S3 メソッドは
  \code{\link{as.double}} に対して書かれるべきである．
  これは \code{as.double} と同一である．

  \code{is.numeric} は内部総称的なプリミティブ関数である：
  オブジェクトの個別のクラスを処理するメソッドを書くことが出来る，
  \link{InternalMethods} を見よ．これは \code{\link{is.double}} と
  同じではない．因子は既定メソッドで処理できる．
  そしてクラス \code{"\link{Date}"}, \code{"\link{POSIXt}"} そして
  \code{"\link{difftime}"} 用のメソッドがある(全て偽を返す)．
  \code{is.numeric} に対するメソッドは基礎クラスが
  \code{double} か \code{integer} の時，
  そして値が合理的に数値と見做せる時
  (例えば算術が可能で，比較が基礎型を使って出来る)だけ真を返すべきである，
}
\value{
  \code{numeric} と \code{as.numeric} に付いては \code{\link{double}} を見よ．

  \code{is.numeric} に対する既定メソッドは，もしその引数が
  \code{"numeric"} モード(\code{"double"} 型か \code{"integer"} 型)で，
  因子でない時だけ \code{TRUE} で，さもなければ \code{FALSE} である．
  つまり\cr
  \code{is.integer(x) || is.double(x)}，又は
  \code{(mode(x) == "numeric") && !is.factor(x)}．
}
\section{S4 メソッド}{
  \code{as.numeric} と \code{is.numeric} は内部的に S4 総称的で，
  従って \code{setMethod} を使ってそれらにメソッドを設定できる．

  \code{as.numeric} と \code{as.double} が同一であることを保証するために，
  S4 メソッドは \code{as.numeric} に対してだけ設定できる．
}
%% keep next the same in double.Rd & numeric.Rd
\section{名前に関するノート}{
  \R が浮動小数点数ベクトルに対して二つの名前，
  \code{\link{double}} と \code{\link{numeric}}
  (そして以前は \code{real} があった)を持つのは
  歴史的な混乱からである．

  \code{double} は型の名前である．
  \code{numeric} はモードの名前で，同時に暗黙のクラスでもある．
  S4 形式的クラスとしては \code{"numeric"} を使う．

  可能な混乱は \R が\sQuote{倍精度実数や整数}を意味するのに
  モード \code{"numeric"} を使うことである．
  これは S4 の用法と異なる．従って \code{is.numeric} はモードを検査し
  クラスを検査しない．しかし \code{as.numeric} (\code{as.double} と同一)
  はクラスの強制変換をする．
}
\seealso{
  \code{\link{double}}, \code{\link{integer}}, \code{\link{storage.mode}}.
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
as.numeric(c("-.1"," 2.7 ","B")) # (-0.1, 2.7, NA)  +  警告
as.numeric(factor(5:10))
}
\keyword{classes}
\keyword{attribute}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/numeric.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{numeric}
%\title{Numeric Vectors}
%\alias{numeric}
%\alias{as.numeric}
%\alias{is.numeric}
%\alias{is.numeric.Date}
%\alias{is.numeric.POSIXt}
%\description{
%  Creates or coerces objects of type \code{"numeric"}.
%  \code{is.numeric} is a more general test of an object being
%  interpretable as numbers.
%}
%\usage{
%numeric(length = 0)
%as.numeric(x, \dots)
%is.numeric(x)
%}
%\arguments{
%  \item{length}{A non-negative integer specifying the desired length.
%    Double values will be coerced to integer:
%    supplying an argument of length other than one is an error.}
%  \item{x}{object to be coerced or tested.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\details{
%  \code{numeric} is identical to \code{\link{double}} (and \code{real}).
%  It creates a double-precision vector of the specified length with each
%  element equal to \code{0}.
%
%  \code{as.numeric} is a generic function, but S3 methods must be
%  written for \code{\link{as.double}}.  It is identical to \code{as.double}.
%
%  \code{is.numeric} is an \link{internal generic} \code{primitive}
%  function: you can write methods to handle specific classes of objects,
%  see \link{InternalMethods}.  It is \strong{not} the same as
%  \code{\link{is.double}}.  Factors are handled by the default method,
%  and there are methods for classes \code{"\link{Date}"},
%  \code{"\link{POSIXt}"} and \code{"\link{difftime}"} (all of which
%  return false).  Methods for \code{is.numeric} should only return true
%  if the base type of the class is \code{double} or \code{integer}
%  \emph{and} values can reasonably be regarded as numeric
%  (e.g., arithmetic on them makes sense, and comparison should be done
%  via the base type).
%}
%\value{
%  for \code{numeric} and \code{as.numeric} see \code{\link{double}}.
%
%  The default method for \code{is.numeric} returns \code{TRUE}
%  if its argument is of \link{mode} \code{"numeric"}
%  (\link{type} \code{"double"} or type \code{"integer"}) and not a
%  factor, and \code{FALSE} otherwise.  That is,
%  \code{is.integer(x) || is.double(x)}, or
%  \code{(mode(x) == "numeric") && !is.factor(x)}.
%}
%\section{S4 methods}{
%  \code{as.numeric} and \code{is.numeric} are internally S4 generic and
%  so methods can be set for them \emph{via} \code{setMethod}.
%
%  To ensure that \code{as.numeric} and \code{as.double}
%  remain identical, S4 methods can only be set for \code{as.numeric}.
%}
%%% keep next the same in double.Rd & numeric.Rd
%\section{Note on names}{
%  It is a historical anomaly that \R has two names for its
%  floating-point vectors, \code{\link{double}} and \code{\link{numeric}}
%  (and formerly had \code{real}).
%
%  \code{double} is the name of the \link{type}.
%  \code{numeric} is the name of the \link{mode} and also of the implicit
%  \link{class}.  As an S4 formal class, use \code{"numeric"}.
%
%  The potential confusion is that \R has used \emph{\link{mode}}
%  \code{"numeric"} to mean \sQuote{double or integer}, which conflicts
%  with the S4 usage.  Thus \code{is.numeric} tests the mode, not the
%  class, but \code{as.numeric} (which is identical to \code{as.double})
%  coerces to the class.
%}
%\seealso{
%  \code{\link{double}}, \code{\link{integer}}, \code{\link{storage.mode}}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%as.numeric(c("-.1"," 2.7 ","B")) # (-0.1, 2.7, NA)  +  warning
%as.numeric(factor(5:10))
%}
%\keyword{classes}
%\keyword{attribute}
%
\encoding{UTF8}
