% File src/library/base/man/outer.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{outer}
\alias{outer}
\alias{\%o\%}
\title{Outer Product of Arrays}
\description{
  配列 \code{X} と \code{Y} の外積は次元 \code{c(dim(X), dim(Y))}
  の次の要素を持つ配列 \code{A} である．\cr
  \code{    A[c(arrayindex.x, arrayindex.y)]\cr
               = FUN(X[arrayindex.x], Y[arrayindex.y], \dots)}．
}
\usage{
outer(X, Y, FUN = "*", \dots)
X \%o\% Y
}

\arguments{
  \item{X, Y}{関数 \code{FUN} への最初と二番目の引数．普通ベクトルか配列．}
\item{FUN}{外積に使われる関数で，\code{\link{match.fun}} を
  使って探される(特別な場合 \code{"*"} を除き)．}
  \item{\dots}{\code{FUN} に渡されるオプションの引数．}
}
\details{
  \code{X} と \code{Y} は \code{FUN} に対して相応しい引数でなければ
  ならない．\code{FUN} が呼び出される前に各々は \code{\link{rep}}
  により長さが \code{X} と \code{Y} の長さの積になるように拡大される．

  \code{FUN} はこれら二つの拡大ベクトルを引数として(\code{\dots} 中の引数込みで)
  呼び出される．
  これはベクトル化された関数(又は素の名前)でなければならず，
  少なくとも二つの引数を持ち，最初(そして二番目)と同じ長さの
  値を返すことが期待されている．

  もし存在すれば \code{X} と \code{Y} の[次元]名が
  答にコピーされ，\code{X} と \code{Y} の次元が連結された次元
  (またはもし次元が存在しなければ長さ)が与えられる．

  \code{FUN = "*"} は
  \code{as.vector(X) \%*\% t(as.vector(Y))} の特殊例として処理され，
  数値ベクトルと配列だけを意図している．

  \code{\%o\%} は \code{outer(x, y, "*")} に対する二項演算子のラッパである．
}
\author{Jonathan Rougier}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  通常の行列とベクトルの積については \code{\link{\%*\%}}：
  \code{outer} を用いた \code{\link{kronecker}}；
  非ベクトル化関数をベクトル化するには \code{\link{Vectorize}}．
}
\examples{
x <- 1:9; names(x) <- x
# 積と巾乗表
x \%o\% x
y <- 2:8; names(y) <- paste(y,":", sep = "")
outer(y, x, "^")

outer(month.abb, 1999:2003, FUN = "paste")

## 三元乗積表：
x \%o\% x \%o\% y[1:3]
}
\keyword{array}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/outer.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{outer}
%\alias{outer}
%\alias{\%o\%}
%\title{Outer Product of Arrays}
%\description{
%  The outer product of the arrays \code{X} and \code{Y} is the array
%  \code{A} with dimension \code{c(dim(X), dim(Y))} where element
%  \code{A[c(arrayindex.x, arrayindex.y)]
%    = FUN(X[arrayindex.x], Y[arrayindex.y], \dots)}.
%}
%\usage{
%outer(X, Y, FUN = "*", \dots)
%X \%o\% Y
%}
%
%\arguments{
%  \item{X, Y}{First and second arguments for function \code{FUN}.
%    Typically a vector or array.}
%  \item{FUN}{a function to use on the outer products, found \emph{via}
%    \code{\link{match.fun}} (except for the special case \code{"*"}).}
%  \item{\dots}{optional arguments to be passed to \code{FUN}.}
%}
%\details{
%  \code{X} and \code{Y} must be suitable arguments for \code{FUN}.  Each
%  will be extended by \code{\link{rep}} to length the products of the
%  lengths of \code{X} and \code{Y} before \code{FUN} is called.
%
%  \code{FUN} is called with these two extended vectors as arguments
%  (plus any arguments in \code{\dots}).  It must be a vectorized
%  function (or the name of one) expecting at least two arguments and
%  returning a value with the same length as the first (and the second).
%
%  Where they exist, the [dim]names of \code{X} and \code{Y} will be
%  copied to the answer, and a dimension assigned which is the
%  concatenation of the dimensions of \code{X} and \code{Y} (or lengths
%  if dimensions do not exist).
%
%  \code{FUN = "*"} is handled as a special case \emph{via}
%  \code{as.vector(X) \%*\% t(as.vector(Y))}, and is intended only for
%  numeric vectors and arrays.
%
%  \code{\%o\%} is binary operator providing a wrapper for
%  \code{outer(x, y, "*")}.
%}
%\author{Jonathan Rougier}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{\%*\%}} for usual (\emph{inner}) matrix vector
%  multiplication;
%  \code{\link{kronecker}} which is based on \code{outer};
%  \code{\link{Vectorize}} for vectorizing a non-vectorized function.
%}
%\examples{
%x <- 1:9; names(x) <- x
%# Multiplication & Power Tables
%x \%o\% x
%y <- 2:8; names(y) <- paste(y,":", sep = "")
%outer(y, x, "^")
%
%outer(month.abb, 1999:2003, FUN = "paste")
%
%## three way multiplication table:
%x \%o\% x \%o\% y[1:3]
%}
%\keyword{array}
%
\encoding{UTF8}
