% File src/library/base/man/parse.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{parse}
\alias{parse}
\title{Parse Expressions}
\description{
  \code{parse} は構文解析されたが未評価の表現式をリストとして返す．
}
\usage{
parse(file = "", n = NULL, text = NULL, prompt = "?",
      keep.source = getOption("keep.source"), srcfile,
      encoding = "unknown")
}
\arguments{
  \item{file}{そこから表現式を読み取るコネクション又はファイルや URL の名前を
    与える文字列．
    もし \code{file} が \code{""} で \code{text} が無いかまたは \code{NULL}
    ならば入力はコンソールから取られる．}
  \item{n}{整数(又は整数に変換される)．構文解析する表現式の最大数．
    もし \code{n} が \code{NULL} か負又は \code{NA} なら
    入力はその全体にわたって構文解析される．}
  \item{text}{文字列．構文解析されるテキスト．要素はファイルの一行である
    かのように扱われる．他の \R オブジェクトは可能なら文字列に
    変換される．}
  \item{prompt}{キーボードから構文解析するときにプリントされるプロンプト．
    \code{NULL} は \R のプロンプトを使うことを意味する，\code{getOption("prompt")}．}
  \item{keep.source}{論理値；もし \code{TRUE} ならソース参照情報を保つ．}
  \item{srcfile}{\code{NULL}，文字列，もしくは
    \code{\link{srcfile}} オブジェクト．\sQuote{詳細}節を見よ．}
  \item{encoding}{入力文字列に対して仮定されるエンコーディング．
    もし値が \code{"latin1"} か \code{"UTF-8"} ならそれが文字列を
    Latin-1 や UTF-8 であるとわかっているとマークされる：入力の
    再エンコーディングには使われない．
    後者を行うにはエンコーディングを \code{con} の一部分とするか，
    \code{\link{options}(encoding=)} 経由で行う：
    \code{\link{file}} の例を見よ．}
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
  
  Murdoch, D. (2010).  
  \href{http://journal.r-project.org/archive/2010-2/RJournal_2010-2_Murdoch.pdf}{Source 
  References}.  \emph{The R Journal} 2/2, 16-19.
}
\seealso{
  \code{\link{scan}}, \code{\link{source}}, \code{\link{eval}},
  \code{\link{deparse}}.

  ソース参照情報はデバッグ(例えば \sspace{}\code{\link{setBreakpoint}} を見よ)
  とプロファイリング(\code{\link{Rprof}} を見よ)に使うことが出来る．
  これは \code{\link{getSrcref}} や関連関数で調べることができる．
  より詳細な情報が \code{\link{getParseData}} を使って得られる．
}
\details{
  もし \code{text} が(変換後)ゼロより大きな長さを持てば，それが
  \code{file} に優先して使われる．

  \R の全てのバージョンは行末が LF (Unix で使われる)，
  CRLF (DOS/Windows で使われる)，または
  CR (古典的な Mac OS で使われる) で終わるコネクションからの
  入力を受け付ける．最終行は EOL マーカーを欠いた不完全行でも良い．

  入力がコンソールから取られるときは，\code{n = NULL} は
  \code{n = 1} に等しく，そして \code{n < 0} は EOF 文字
  まで読み取られる．
  (EOF 文字は Windows のフロントエンドでは Ctrl-Z である．)
  行長の上限はコンソールから読み取る場合は 4095 バイトである
  (これは下限を課すかもしれない：
  \sQuote{An Introduction to R} を見よ)．

  \code{srcfile} の既定値は次のように設定される．もし
  \code{keep.source} が \code{TRUE} で無ければ，\code{srcfile}
  の既定値は文字列で \code{"<text>"} か from \code{file} から
  導かれるものである．\code{keep.source} が \code{TRUE} なら，
  もし \code{text} が使われると，\code{srcfile} はテキストを含む
  \code{\link{srcfilecopy}} とされる．もし文字列が
  \code{file} に対して使われると，そのファイルを参照する \code{\link{srcfile}}
  オブジェクトが使われる．

  \code{srcfile} が文字列ならば，エラーメッセージは名前を含むが，
  ソース参照情報は結果に付け加えられない．
  \code{srcfile} が \code{\link{srcfile}} オブジェクトならば，
  ソース参照情報は保たれる．
}
\section{部分構文解析}{
  構文解析中に構文エラーが起きると，code{parse} は
  エラーを発生する．部分構文解析データはもしそれが
  \code{\link{srcfile}} オブジェクトならば
  \code{srcfile} 引数中に保管され，そして
  \code{text} 引数がテキストを提供するために使われる．
  他の場合はエラーが起きた時失われる．
  
  部分構文解析データは \code{srcfile} オブジェクトに適用された
  \code{\link{getParseData}} を使って回収することが出来る．
  構文解析は不完全であるから，それは典型的に
  存在しない \code{"parent"} 項目への参照を含む．
}
\value{
  型 \code{"\link{expression}"} のオブジェクトで，もし非負整数として指定されれば
  最大 \code{n} 個の要素を持つ．

  もし \code{srcfile} が \code{NULL} で無ければ \code{"srcref"} 属性が
  各要素に対応する \code{\link{srcref}} 記録のリストを含む結果に付加され，
  \code{srcfile} のコピーを含む \code{"srcfile"} 属性が付加され，
  構文解析されたテキスト全てに対応する \code{\link{srcref}} を含む
  \code{"srcfile"} 属性が付加される．
  詳細な構文解析情報が \code{"srcfile"} 属性中に保管され，
  \code{\link{getParseData}} で回収できる．

  構文解析のエラー(不完全な表現式を含む)はエラーを起こす．

  結果中の文字列は，もし \code{encoding} が \code{"latin1"} か \code{"UTF-8"}
  であるか，またもし全てが Latin-1 か UTF-8 ロケール中の既知のエンコードを持つ
  要素を持つ \code{text} が与えられると，宣言されたエンコーディングを持つ
  ようになる．
}

\examples{
cat("x <- c(1, 4)\n  x ^ 3 -10 ; outer(1:7, 5:9)\n", file = "xyz.Rdmped")
# ファイル "xyz.Rdmped" からの三つの文を構文解析する
parse(file = "xyz.Rdmped", n = 3)
unlink("xyz.Rdmped")

# 構文エラーになる部分構文解析
txt <- "
x <- 1
an error
"
sf <- srcfile("txt")
try(parse(text = txt, srcfile = sf))
getParseData(sf)
}
\keyword{file}
\keyword{programming}
\keyword{connection}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/parse.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{parse}
%\alias{parse}
%\title{Parse Expressions}
%\description{
%  \code{parse} returns the parsed but unevaluated expressions in a
%  list.
%}
%\usage{
%parse(file = "", n = NULL, text = NULL, prompt = "?",
%      keep.source = getOption("keep.source"), srcfile,
%      encoding = "unknown")
%}
%\arguments{
%  \item{file}{a \link{connection}, or a character string giving the name of a
%    file or a URL to read the expressions from.
%    If \code{file} is \code{""} and \code{text} is missing or \code{NULL}
%    then input is taken from the console.}
%  \item{n}{integer (or coerced to integer).  The maximum number of
%    expressions to parse.  If \code{n} is \code{NULL} or negative or
%    \code{NA} the input is parsed in its entirety.}
%  \item{text}{character vector.  The text to parse.  Elements are treated
%    as if they were lines of a file.  Other \R objects will be coerced
%    to character if possible.}
%  \item{prompt}{the prompt to print when parsing from the keyboard.
%    \code{NULL} means to use \R's prompt, \code{getOption("prompt")}.}
%  \item{keep.source}{a logical value; if \code{TRUE}, keep 
%    source reference information.}
%  \item{srcfile}{\code{NULL}, a character vector, or a
%    \code{\link{srcfile}} object.  See the \sQuote{Details} section.}
%  \item{encoding}{encoding to be assumed for input strings.  If the
%    value is \code{"latin1"} or \code{"UTF-8"} it is used to mark
%    character strings as known to be in Latin-1 or UTF-8: it is not used
%    to re-encode the input.  To do the latter, specify the encoding as
%    part of the connection \code{con} or \emph{via}
%    \code{\link{options}(encoding=)}: see the example under
%    \code{\link{file}}.}
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%  
%  Murdoch, D. (2010).  
%  \href{http://journal.r-project.org/archive/2010-2/RJournal_2010-2_Murdoch.pdf}{Source 
%  References}.  \emph{The R Journal} 2/2, 16-19.
%}
%\seealso{
%  \code{\link{scan}}, \code{\link{source}}, \code{\link{eval}},
%  \code{\link{deparse}}.
%
%  The source reference information can be used for debugging (see
%  e.g.\sspace{}\code{\link{setBreakpoint}}) and profiling (see
%  \code{\link{Rprof}}). It can be examined by \code{\link{getSrcref}}
%  and related functions.  More detailed information is available through
%  \code{\link{getParseData}}.
%}
%\details{
%  If \code{text} has length greater than zero (after coercion) it is used in
%  preference to \code{file}.
%
%  All versions of \R accept input from a connection with end of line
%  marked by LF (as used on Unix), CRLF (as used on DOS/Windows)
%  or CR (as used on classic Mac OS).  The final line can be incomplete,
%  that is missing the final EOL marker.
%
%  When input is taken from the console, \code{n = NULL} is equivalent to
%  \code{n = 1}, and \code{n < 0} will read until an EOF character is
%  read.  (The EOF character is Ctrl-Z for the Windows front-ends.)  The
%  line-length limit is 4095 bytes when reading from the console (which
%  may impose a lower limit: see \sQuote{An Introduction to R}).
%
%  The default for \code{srcfile} is set as follows.  If
%  \code{keep.source} is not \code{TRUE}, \code{srcfile}
%  defaults to a character string, either \code{"<text>"} or one
%  derived from \code{file}.  When \code{keep.source} is
%  \code{TRUE}, if \code{text} is used, \code{srcfile} will be set to a
%  \code{\link{srcfilecopy}} containing the text.  If a character
%  string is used for \code{file}, a \code{\link{srcfile}} object
%  referring to that file will be used.
%
%  When \code{srcfile} is a character string, error messages will
%  include the name, but source reference information will not be added
%  to the result.  When \code{srcfile} is a \code{\link{srcfile}}
%  object, source reference information will be retained. 
%}
%\section{Partial parsing}{
%  When a syntax error occurs during parsing, \code{parse} 
%  signals an error.  The partial parse data will be stored in the
%  \code{srcfile} argument if it is a \code{\link{srcfile}} object
%  and the \code{text} argument was used to supply the text.  In other
%  cases it will be lost when the error is triggered.
%  
%  The partial parse data can be retrieved using
%  \code{\link{getParseData}} applied to the \code{srcfile} object.
%  Because parsing was incomplete, it will typically include references
%  to \code{"parent"} entries that are not present.  
%}
%\value{
%  An object of type \code{"\link{expression}"}, with up to \code{n}
%  elements if specified as a non-negative integer.
%
%  When \code{srcfile} is non-\code{NULL}, a \code{"srcref"} attribute
%  will be attached to the result containing a list of
%  \code{\link{srcref}} records corresponding to each element, a
%  \code{"srcfile"} attribute will be attached containing a copy of
%  \code{srcfile}, and a \code{"wholeSrcref"} attribute will be
%  attached containing a \code{\link{srcref}} record corresponding to
%  all of the parsed text. Detailed parse information will be stored in
%  the \code{"srcfile"} attribute, to be retrieved by
%  \code{\link{getParseData}}.
%
%  A syntax error (including an incomplete expression) will throw an error.
%
%  Character strings in the result will have a declared encoding if
%  \code{encoding} is \code{"latin1"} or \code{"UTF-8"}, or if
%  \code{text} is supplied with every element of known encoding in a
%  Latin-1 or UTF-8 locale.
%}
%
%\examples{
%cat("x <- c(1, 4)\n  x ^ 3 -10 ; outer(1:7, 5:9)\n", file = "xyz.Rdmped")
%# parse 3 statements from the file "xyz.Rdmped"
%parse(file = "xyz.Rdmped", n = 3)
%unlink("xyz.Rdmped")
%
%# A partial parse with a syntax error
%txt <- "
%x <- 1
%an error
%"
%sf <- srcfile("txt")
%try(parse(text = txt, srcfile = sf))
%getParseData(sf)
%}
%\keyword{file}
%\keyword{programming}
%\keyword{connection}
%
\encoding{UTF8}
