% File src/library/base/man/rapply.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{rapply}
\alias{rapply}
\title{Recursively Apply a Function to a List}
\description{
  \code{rapply} は \code{\link{lapply}} の再帰的バージョンである．
}
\usage{
rapply(object, f, classes = "ANY", deflt = NULL,
       how = c("unlist", "replace", "list"), ...)
}
\arguments{
  \item{object}{リスト．}
  \item{f}{引数が一つの関数．}
  \item{classes}{クラス名の文字列ベクトル，又は
    全てのクラスにマッチする \code{"ANY"}．}
  \item{deflt}{既定の結果(\code{how = "replace"} ならば使われない)．}
  \item{how}{三つの可能性に部分マッチする文字列：\sQuote{詳細}を見よ．}
  \item{\dots}{\code{f} の呼び出しに渡される追加引数．}
}
\details{
  この関数は二つの基本モードを持つ．もし \code{how = "replace"} ならば
  それ自体はリストではなく \code{classes} に含まれるクラスを持つ
  各リスト要素は，その要素に \code{f} を適用した結果で置き換えられる．

  もしモードが \code{how = "list"} か \code{how = "unlist"} ならばリストは
  コピーされ，そのリストでない要素が \code{classes} に含まれるクラスを持てば
  要素に \code{f} を適用した結果で置き換えられ，
  他の全ては \code{deflt} で置き換えられる．最後に，
  もし \code{how = "unlist"} ならば結果に対して \code{unlist(recursive = TRUE)}
  が呼び出される．

  構文は詳細で \code{\link{lapply}} と異なる：特に
  引数は C コードを呼び出す前に評価される．
}
\value{
  もし \code{how = "unlist"} ならベクトルで，さもなければ
  \code{object} と類似したリスト．
}
\seealso{
  \code{\link{lapply}}, \code{\link{dendrapply}}.
}
\references{
  Chambers, J. A. (1998)
  \emph{Programming with Data}.
  Springer.\cr
  (そこでは \code{rapply} は簡単にしか説明されていない．)
}
\examples{
X <- list(list(a = pi, b = list(c = 1:1)), d = "a test")
rapply(X, function(x) x, how = "replace")
rapply(X, sqrt, classes = "numeric", how = "replace")
rapply(X, nchar, classes = "character",
       deflt = as.integer(NA), how = "list")
rapply(X, nchar, classes = "character",
       deflt = as.integer(NA), how = "unlist")
rapply(X, nchar, classes = "character", how = "unlist")
rapply(X, log, classes = "numeric", how = "replace", base = 2)
}
\keyword{iteration}
\keyword{list}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/rapply.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{rapply}
%\alias{rapply}
%\title{Recursively Apply a Function to a List}
%\description{
%  \code{rapply} is a recursive version of \code{\link{lapply}}.
%}
%\usage{
%rapply(object, f, classes = "ANY", deflt = NULL,
%       how = c("unlist", "replace", "list"), ...)
%}
%\arguments{
%  \item{object}{A list.}
%  \item{f}{A function of a single argument.}
%  \item{classes}{A character vector of \code{\link{class}} names, or
%    \code{"ANY"} to match any class.}
%  \item{deflt}{The default result (not used if \code{how = "replace"}).}
%  \item{how}{A character string partially matching the three possibilities given:
%    see \sQuote{Details}.}
%  \item{\dots}{additional arguments passed to the call to \code{f}.}
%}
%\details{
%  This function has two basic modes.  If \code{how = "replace"}, each
%  element of the list which is not itself a list and has a class
%  included in \code{classes} is replaced by the result of applying
%  \code{f} to the element.
%
%  If the mode is \code{how = "list"} or \code{how = "unlist"}, the list
%  is copied, all non-list elements which have a class included in
%  \code{classes} are replaced by the result of applying \code{f} to the
%  element and all others are replaced by \code{deflt}.  Finally, if
%  \code{how = "unlist"}, \code{unlist(recursive = TRUE)} is called on
%  the result.
%
%  The semantics differ in detail from \code{\link{lapply}}: in
%  particular the arguments are evaluated before calling the C code.
%}
%\value{
%  If \code{how = "unlist"}, a vector, otherwise a list of similar
%  structure to \code{object}.
%}
%\seealso{
%  \code{\link{lapply}}, \code{\link{dendrapply}}.
%}
%\references{
%  Chambers, J. A. (1998)
%  \emph{Programming with Data}.
%  Springer.\cr
%  (\code{rapply} is only described briefly there.)
%}
%\examples{
%X <- list(list(a = pi, b = list(c = 1:1)), d = "a test")
%rapply(X, function(x) x, how = "replace")
%rapply(X, sqrt, classes = "numeric", how = "replace")
%rapply(X, nchar, classes = "character",
%       deflt = as.integer(NA), how = "list")
%rapply(X, nchar, classes = "character",
%       deflt = as.integer(NA), how = "unlist")
%rapply(X, nchar, classes = "character", how = "unlist")
%rapply(X, log, classes = "numeric", how = "replace", base = 2)
%}
%\keyword{iteration}
%\keyword{list}
%
\encoding{UTF8}
