% File src/library/base/man/readBin.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{readBin}
\alias{readBin}
\alias{writeBin}
\title{Transfer Binary Data To and From Connections}
\description{
  コネクションかバイト型ベクトルからバイナリデータを読み取る，
  又は書き込む．
}
\usage{
readBin(con, what, n = 1L, size = NA_integer_, signed = TRUE,
        endian = .Platform$endian)

writeBin(object, con, size = NA_integer_,
         endian = .Platform$endian, useBytes = FALSE)
}
\arguments{
  \item{con}{コネクションオブジェクトか，ファイル又はバイト型ベクトルの
    名前を与える文字列．}
  \item{what}{そのモードが読み込まれるベクトルのモードを与えるオブジェクトか
    モードを指定する長さ1の文字列：
    \code{"numeric"}, \code{"double"},
    \code{"integer"}, \code{"int"}, \code{"logical"}, \code{"complex"},
    \code{"character"}, \code{"raw"} のどれか．}
  \item{n}{整数．読み取られる記録の(最大)数．
    過大評価して良いが，\code{n} 個の項目に対して予約される保管量が
    大きくなり過ぎないようにする．}
  \item{size}{整数．バイトストリーム中の要素毎のバイト量．
    既定 \code{NA_integer_} では自然なサイズを使う．
    サイズの変更はバイト型と複素数値ベクトルではサポートされていない．}
  \item{signed}{論理値．サイズ 1 と 2 に対してだけ使われ，
    ファイル上の量が符号付きか符号無しかを決める．}
  \item{endian}{ファイルに対するターゲットシステムのエンディアン
    (\code{"big"} か \code{"little"})．\code{"swap"} の使用は
    エンディアンの交換を強制する．}
  \item{object}{コネクションに書き込まれる \R オブジェクト．}
  \item{useBytes}{\code{\link{writeLines}} を見よ．}
}
\details{
  これらの関数はバイナリモードのコネクションと共に使われることを意図している．
  もし \code{con} が文字列なら，関数は関数呼び出しの間中開かれている
  バイナリモードコネクションを得るために \code{\link{file}} を呼び出す．

  もしコネクションが開かれると，それはその現在の位置から読み書きされる．
  もしそれがオープンされていないと，それは呼び出しの間中適当なモード
  (バイナリの読み書き)で開かれ，それから閉じられる．
  開かれたコネクションはバイナリモードで無ければならない．

  もし \code{readBin} がバイト型ベクトルの \code{con} とともに開かれると，
  ベクトル中のデータが入力として使われる．
  もし \code{writeBin} がバイト型ベクトルの \code{con} とともに開かれると，
  それは単にバイト型ベクトルが返されなければならないという指示である．

  もし \code{size} が指定されオブジェクトの自然なサイズでなければ，
  ベクトルの各要素は書き込まれるか読み込まれる前に適当な型に変換される．
  可能なサイズは整数か論理値に対して 1, 2, 4 そしてもしかすると 8 で，
  数値に対してはもしかすると 12/16 である．
  (変換はサイズ 1 か 2 の整数を読み込む時，
  \code{signed = FALSE} を除いて符号付き型として行われる．)
  サイズの変更は \code{NA} を保たない可能性が高く，
  拡張精度サイズはプラットフォームを跨ぐ可搬性を損なう可能性が高い．
  
  \code{readBin} と \code{writeBin} は C 風のゼロで終わる
  文字列を読み書きする．
  入力文字列は 10000 文字に制限される．
  \code{\link{readChar}} と \code{\link{writeChar}} は
  固定長の文字列の読み書きに使える．文字列が現在のロケールのエンコーディングで
  正当かどうかのチェックはされない．

  \R の欠損値と特殊値(\code{Inf}, \code{-Inf} そして
  \code{NaN})はマニュアル \sQuote{R Data Import/Export} 中で議論されている．

  \eqn{2^{31}-1}{2^31 - 1} バイトだけが一回の呼び出しで書き込める
  (そしてこれは 32 バイトのプラットフォームではバイト型ベクトルの最大
  キャパシティである．

  \sQuote{エンディアン}は \code{size > 1} に対して問題になり，
  可搬性のあるコードでは常に設定されなければならない
  (既定値は書き込みとそれからの読み込みが同じプラットフォーム上で
  行われる時だけ妥当である)．
}

\note{
  サイズ 8 の整数の読み書きは C タイプの \code{long} がサイズ 8 バイトか，
  C タイプの \code{long long} が存在しサイズが 8 バイトの時
  利用できる．

  \code{sizeof(long double)} (普通 12 か 16 バイト)の実数の
  読み書きは，そのタイプが利用でき \code{double} と異なる時だけ
  利用できる．

  もし \code{readBin(what = character())} が不正に C スタイルの文字列を
  含まないファイルに使われると，警告(普通多くの)が与えられる．
  ファイルやコネクションから，入力は長さ 10000 の部分に分割され，
  任意の最終部分は捨てられる．

  これらの関数をテキストモードのコネクションに対して使っても動作
  するかもしれないが，コネクションへのテキストモードのアクセスと
  混用してはならない．特にコネクションが \code{encoding} 引数と共に
  開かれている場合が該当する．
}

\value{
  \code{readBin} に対しては適当なモードで，長さが読み込む項目数の
  ベクトル(\code{n} 未満かもしれない)．

  \code{writeBin} に対してはバイト型ベクトル(もし \code{con} がバイト型ベクトルなら)
  又は不可視の \code{NULL}．
}
\seealso{
  マニュアル sQuote{R Data Import/Export}．

  固定長の文字列の読み書きには \code{readChar}．

  \code{\link{connections}}, \code{\link{readLines}},
  \code{\link{writeLines}}.

  \code{long}, \code{long long} そして \code{long double} の
  サイズについては \code{\link{.Machine}}． 
}
\examples{
zz <- file("testbin", "wb")
writeBin(1:10, zz)
writeBin(pi, zz, endian = "swap")
writeBin(pi, zz, size = 4)
writeBin(pi^2, zz, size = 4, endian = "swap")
writeBin(pi+3i, zz)
writeBin("A test of a connection", zz)
z <- paste("A very long string", 1:100, collapse = " + ")
writeBin(z, zz)
if(.Machine$sizeof.long == 8 || .Machine$sizeof.longlong == 8)
    writeBin(as.integer(5^(1:10)), zz, size = 8)
if((s <- .Machine$sizeof.longdouble) > 8)
    writeBin((pi/3)^(1:10), zz, size = s)
close(zz)

zz <- file("testbin", "rb")
readBin(zz, integer(), 4)
readBin(zz, integer(), 6)
readBin(zz, numeric(), 1, endian = "swap")
readBin(zz, numeric(), size = 4)
readBin(zz, numeric(), size = 4, endian = "swap")
readBin(zz, complex(), 1)
readBin(zz, character(), 1)
z2 <- readBin(zz, character(), 1)
if(.Machine$sizeof.long == 8 || .Machine$sizeof.longlong == 8)
    readBin(zz, integer(), 10,  size = 8)
if((s <- .Machine$sizeof.longdouble) > 8)
    readBin(zz, numeric(), 10, size = s)
close(zz)
unlink("testbin")
stopifnot(z2 == z)

## 符号付きと符号なし整数
zz <- file("testbin", "wb")
x <- as.integer(seq(0, 255, 32))
writeBin(x, zz, size = 1)
writeBin(x, zz, size = 1)
x <- as.integer(seq(0, 60000, 10000))
writeBin(x, zz, size = 2)
writeBin(x, zz, size = 2)
close(zz)
zz <- file("testbin", "rb")
readBin(zz, integer(), 8, size = 1)
readBin(zz, integer(), 8, size = 1, signed = FALSE)
readBin(zz, integer(), 7, size = 2)
readBin(zz, integer(), 7, size = 2, signed = FALSE)
close(zz)
unlink("testbin")

## バイト型の使用
z <- writeBin(pi^{1:5}, raw(), size = 4)
readBin(z, numeric(), 5, size = 4)
z <- writeBin(c("a", "test", "of", "character"), raw())
readBin(z, character(), 4)
}
\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/readBin.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{readBin}
%\alias{readBin}
%\alias{writeBin}
%\title{Transfer Binary Data To and From Connections}
%\description{
%  Read binary data from or write binary data to a connection or raw vector.
%}
%\usage{
%readBin(con, what, n = 1L, size = NA_integer_, signed = TRUE,
%        endian = .Platform$endian)
%
%writeBin(object, con, size = NA_integer_,
%         endian = .Platform$endian, useBytes = FALSE)
%}
%\arguments{
%  \item{con}{A \link{connection} object or a character string naming a file or
%    a raw vector.}
%  \item{what}{Either an object whose mode will give the mode of the
%    vector to be read, or a character vector of length one describing
%    the mode: one of \code{"numeric"}, \code{"double"},
%    \code{"integer"}, \code{"int"}, \code{"logical"}, \code{"complex"},
%    \code{"character"}, \code{"raw"}.}
%  \item{n}{integer.  The (maximal) number of records to be
%    read.  You can use an over-estimate here, but not too large as
%    storage is reserved for \code{n} items.}
%  \item{size}{integer.  The number of bytes per element in the byte
%    stream.  The default, \code{NA_integer_}, uses the natural size.
%    Size changing is not supported for raw and complex vectors.}
%  \item{signed}{logical.  Only used for integers of sizes 1 and 2,
%    when it determines if the quantity on file
%    should be regarded as a signed or unsigned integer.}
%  \item{endian}{The endian-ness (\code{"big"} or \code{"little"}) of the
%    target system for the file.  Using \code{"swap"} will force swapping
%    endian-ness.}
%  \item{object}{An \R object to be written to the connection.}
%  \item{useBytes}{See \code{\link{writeLines}}.}
%}
%\details{
%  These functions are intended to be used with binary-mode connections.
%  If \code{con} is a character string, the functions call
%  \code{\link{file}} to obtain a binary-mode file connection which is
%  opened for the duration of the function call.
%
%  If the connection is open it is read/written from its current
%  position.  If it is not open, it is opened for the duration of the
%  call in an appropriate mode (binary read or write) and then closed
%  again.  An open connection must be in binary mode.
%
%  If \code{readBin} is called with \code{con} a raw vector, the data in
%  the vector is used as input.  If \code{writeBin} is called with
%  \code{con} a raw vector, it is just an indication that a raw vector
%  should be returned.
%
%  If \code{size} is specified and not the natural size of the object,
%  each element of the vector is coerced to an appropriate type before
%  being written or as it is read.  Possible sizes are 1, 2, 4 and
%  possibly 8 for integer or logical vectors, and 4, 8 and possibly 12/16
%  for numeric vectors.  (Note that coercion occurs as signed types
%  except if \code{signed = FALSE} when reading integers of sizes 1 and 2.)
%  Changing sizes is unlikely to preserve \code{NA}s, and the extended
%  precision sizes are unlikely to be portable across platforms.
%
%  \code{readBin} and \code{writeBin} read and write C-style
%  zero-terminated character strings.  Input strings are limited to 10000
%  characters.  \code{\link{readChar}} and \code{\link{writeChar}} can
%  be used to read and write fixed-length strings.  No check is made that
%  the string is valid in the current locale's encoding.
%
%  Handling \R's missing and special (\code{Inf}, \code{-Inf} and
%  \code{NaN}) values is discussed in the \sQuote{R Data Import/Export} manual.
%
%  Only \eqn{2^{31}-1}{2^31 - 1} bytes can be written in a single
%  call (and that is the maximum capacity of a raw vector on 32-bit
%  platforms).
%
%  \sQuote{Endian-ness} is relevant for \code{size > 1}, and should
%  always be set for portable code (the default is only appropriate when
%  writing and then reading files on the same platform).
%}
%
%\note{
%  Integer read/writes of size 8 will be available if either C type
%  \code{long} is of size 8 bytes or C type \code{long long} exists and
%  is of size 8 bytes.
%
%  Real read/writes of size \code{sizeof(long double)} (usually 12 or 16
%  bytes) will be available only if that type is available and different
%  from \code{double}.
%
%  If \code{readBin(what = character())} is used incorrectly on a file
%  which does not contain C-style character strings, warnings (usually
%  many) are given.  From a file or connection, the input will be broken
%  into pieces of length 10000 with any final part being discarded.
%
%  Using these functions on a text-mode connection may work but should
%  not be mixed with text-mode access to the connection, especially if
%  the connection was opened with an \code{encoding} argument.
%}
%
%\value{
%  For \code{readBin}, a vector of appropriate mode and length the number of
%  items read (which might be less than \code{n}).
%
%  For \code{writeBin}, a raw vector (if \code{con} is a raw vector) or
%  invisibly \code{NULL}.
%}
%\seealso{
%  The \sQuote{R Data Import/Export} manual.
%
%  \code{readChar} to read/write fixed-length strings.
%
%  \code{\link{connections}}, \code{\link{readLines}},
%  \code{\link{writeLines}}.
%
%  \code{\link{.Machine}} for the sizes of \code{long}, \code{long long}
%  and \code{long double}.
%}
%\examples{
%zz <- file("testbin", "wb")
%writeBin(1:10, zz)
%writeBin(pi, zz, endian = "swap")
%writeBin(pi, zz, size = 4)
%writeBin(pi^2, zz, size = 4, endian = "swap")
%writeBin(pi+3i, zz)
%writeBin("A test of a connection", zz)
%z <- paste("A very long string", 1:100, collapse = " + ")
%writeBin(z, zz)
%if(.Machine$sizeof.long == 8 || .Machine$sizeof.longlong == 8)
%    writeBin(as.integer(5^(1:10)), zz, size = 8)
%if((s <- .Machine$sizeof.longdouble) > 8)
%    writeBin((pi/3)^(1:10), zz, size = s)
%close(zz)
%
%zz <- file("testbin", "rb")
%readBin(zz, integer(), 4)
%readBin(zz, integer(), 6)
%readBin(zz, numeric(), 1, endian = "swap")
%readBin(zz, numeric(), size = 4)
%readBin(zz, numeric(), size = 4, endian = "swap")
%readBin(zz, complex(), 1)
%readBin(zz, character(), 1)
%z2 <- readBin(zz, character(), 1)
%if(.Machine$sizeof.long == 8 || .Machine$sizeof.longlong == 8)
%    readBin(zz, integer(), 10,  size = 8)
%if((s <- .Machine$sizeof.longdouble) > 8)
%    readBin(zz, numeric(), 10, size = s)
%close(zz)
%unlink("testbin")
%stopifnot(z2 == z)
%
%## signed vs unsigned ints
%zz <- file("testbin", "wb")
%x <- as.integer(seq(0, 255, 32))
%writeBin(x, zz, size = 1)
%writeBin(x, zz, size = 1)
%x <- as.integer(seq(0, 60000, 10000))
%writeBin(x, zz, size = 2)
%writeBin(x, zz, size = 2)
%close(zz)
%zz <- file("testbin", "rb")
%readBin(zz, integer(), 8, size = 1)
%readBin(zz, integer(), 8, size = 1, signed = FALSE)
%readBin(zz, integer(), 7, size = 2)
%readBin(zz, integer(), 7, size = 2, signed = FALSE)
%close(zz)
%unlink("testbin")
%
%## use of raw
%z <- writeBin(pi^{1:5}, raw(), size = 4)
%readBin(z, numeric(), 5, size = 4)
%z <- writeBin(c("a", "test", "of", "character"), raw())
%readBin(z, character(), 4)
%}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
