% File src/library/base/man/readLines.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{readLines}
\alias{readLines}
\title{Read Text Lines from a Connection}
\description{
  コネクションからテキスト行の一部又は全部を読み取る．
}
\usage{
readLines(con = stdin(), n = -1L, ok = TRUE, warn = TRUE,
          encoding = "unknown", skipNul = FALSE)
}
\arguments{
  \item{con}{コネクションオブジェクト又は文字列．}
  \item{n}{整数．読み取る行数(の最大数)．負の値はコネクション上の入力の
    最後まで読み取ることを指示する．}
  \item{ok}{論理値．\code{n > 0} 行が読み取られる前にコネクションの
    最後に達してもOKか? もし偽ならエラーが生成される．}
  \item{warn}{論理値．テキストファイルが最後の EOL を欠いていたり，
    テキスト中に埋め込みの nul があれば警告する．}
  \item{encoding}{入力文字列に対して仮定されるエンコーディング．
    これは文字列がエンコーディング Latin-1 や UTF-8 を持つことが
    知られているとマークする：入力の再エンコーディングには使われない．
    後者を行うにはエンコーディングをコネクション \code{con} の一部として
    指定するか，又は \code{\link{options}(encoding=)} を使う：
    例を見よ．
#ifdef windows
    \sQuote{詳細}も見よ.    
#endif
  }
  \item{skipNul}{論理値：nul はスキップすべきか?}
}
\details{
  もし \code{con} が文字列ならば，関数は呼び出しの間中開かれているファイル
  コネクションを得るために \code{\link{file}} を呼び出す．
  これは圧縮ファイルでも良い．

  もしコネクションが開かれるとそれはその現在の位置から読み取られる．
  もしそれが開かれていないと呼び出しの間中 \code{"rt"} モードで開かれ，
  それからまた閉じられる．

  もし最終行が不完全(最終 EOL マーカーが無い)ならば，動作はコネクションが
  ブロックされているかどうかに依存する．ブロックされていないテキストモードの
  コネクションに対しては行は黙ってプッシュバックされる．
  他の全てのコネクションに対しては行は警告付きで受け入れられる．

  どのようなモードでコネクションが開かれようと，
  任意の LF, CRLF 又は CR は行の EOL マーカーとして受け入れられる．

  入力ストリーム中の埋め込み nul は現在読込中の行を停止し，
  警告が出る(\code{skipNul = TRUE} 又は \code{warn = FALSE} で
  無い限り)．
  
  もし \code{con} が既定の \code{encoding} 引数を持たない未だ開かれていない
  コネクションならば，テキストは UTF-8 に変換されそうしたものとして宣言される
  (そして \code{readLines} への \code{encoding} 引数は無視される)．
  例を見よ．
}
\value{
  読み込んだ行数の長さの文字列．

  結果の要素はもし
  \code{encoding} が \code{"latin1"} か \code{"UTF-8"} なら
  宣言されたエンコーディングを持つ．
}
\note{
  既定のコネクション \code{\link{stdin}} は
  \code{con = "stdin"} と異なるかもしれない：\code{\link{file}} を見よ．
}
\seealso{
  \code{\link{connections}}, \code{\link{writeLines}}, \code{\link{readBin}},
  \code{\link{scan}}}

\examples{
cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = "ex.data",
    sep = "\n")
readLines("ex.data", n = -1)
unlink("ex.data") # 後片付け

## ブロックの違い
cat("123\nabc", file = "test1")
readLines("test1") # 警告がでる行

con <- file("test1", "r", blocking = FALSE)
readLines(con) # 空
cat(" def\n", file = "test1", append = TRUE)
readLines(con) # 両方を得る
close(con)

unlink("test1") # 後片付け

\dontrun{
# 'Windows Unicode' ファイルを読む
A <- readLines(con <- file("Unicode.txt", encoding = "UCS-2LE"))
close(con)
unique(Encoding(A)) # UTF-8 である可能性が最も高い
}}
\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/readLines.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{readLines}
%\alias{readLines}
%\title{Read Text Lines from a Connection}
%\description{
%  Read some or all text lines from a connection.
%}
%\usage{
%readLines(con = stdin(), n = -1L, ok = TRUE, warn = TRUE,
%          encoding = "unknown", skipNul = FALSE)
%}
%\arguments{
%  \item{con}{a \link{connection} object or a character string.}
%  \item{n}{integer.  The (maximal) number of lines to
%    read.  Negative values indicate that one should read up to the end of
%    input on the connection.}
%  \item{ok}{logical.  Is it OK to reach the end of the connection before
%    \code{n > 0} lines are read?  If not, an error will be generated.}
%  \item{warn}{logical.  Warn if a text file is missing a final EOL or if
%    there are embedded nuls in the file.}
%  \item{encoding}{encoding to be assumed for input strings.  It is
%    used to mark character strings as known to be in
%    Latin-1 or UTF-8: it is not used to re-encode the input.  To do the
%    latter, specify the encoding as part of the connection \code{con} or
%    via \code{\link{options}(encoding=)}: see the examples.
%#ifdef windows
%    See also \sQuote{Details}.
%#endif
%  }
%  \item{skipNul}{logical: should nuls be skipped?}
%}
%\details{
%  If the \code{con} is a character string, the function calls
%  \code{\link{file}} to obtain a file connection which is opened for
%  the duration of the function call.  This can be a compressed file.
%
%  If the connection is open it is read from its current position.  If it
%  is not open, it is opened in \code{"rt"} mode for the duration of
%  the call and then closed again.
%
%  If the final line is incomplete (no final EOL marker) the behaviour
%  depends on whether the connection is blocking or not.  For a
%  non-blocking text-mode connection the incomplete line is pushed back,
%  silently.  For all other connections the line will be accepted, with a
%  warning.
%
%  Whatever mode the connection is opened in, any of LF, CRLF or CR will
%  be accepted as the EOL marker for a line.
%
%  Embedded nuls in the input stream will terminate the line currently
%  being read, with a warning (unless \code{skipNul = TRUE} or \code{warn
%    = FALSE)}).
%  
%  If \code{con} is a not-already-open \link{connection} with a non-default
%  \code{encoding} argument, the text is converted to UTF-8 and declared
%  as such (and the \code{encoding} argument to \code{readLines} is ignored).
%  See the examples.
%}
%\value{
%  A character vector of length the number of lines read.
%
%  The elements of the result have a declared encoding if \code{encoding} is
%  \code{"latin1"} or \code{"UTF-8"},
%}
%\note{
%  The default connection, \code{\link{stdin}}, may be different from
%  \code{con = "stdin"}: see \code{\link{file}}.
%}
%\seealso{
%  \code{\link{connections}}, \code{\link{writeLines}}, \code{\link{readBin}},
%  \code{\link{scan}}}
%
%\examples{
%cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = "ex.data",
%    sep = "\n")
%readLines("ex.data", n = -1)
%unlink("ex.data") # tidy up
%
%## difference in blocking
%cat("123\nabc", file = "test1")
%readLines("test1") # line with a warning
%
%con <- file("test1", "r", blocking = FALSE)
%readLines(con) # empty
%cat(" def\n", file = "test1", append = TRUE)
%readLines(con) # gets both
%close(con)
%
%unlink("test1") # tidy up
%
%\dontrun{
%# read a 'Windows Unicode' file
%A <- readLines(con <- file("Unicode.txt", encoding = "UCS-2LE"))
%close(con)
%unique(Encoding(A)) # will most likely be UTF-8
%}}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
