% File src/library/base/man/reg.finalizer.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{reg.finalizer}
\alias{reg.finalizer}
\alias{finalizer}
\title{Finalization of Objects}
\description{
  \R 関数をオブジェクトのガベージコレクション時や(オプションで)
  \R セッションの最後に呼び出されるように登録する．
}
\usage{
  reg.finalizer(e, f, onexit = FALSE)
}
\arguments{
  \item{e}{終末処理されるオブジェクト．
    環境か外部ポインターでなければならない．}
  \item{f}{終末処理時に呼び出される関数．終末処理されるオブジェクトである
    一つの引数を受け入れなければならない．}
  \item{onexit}{論理値：\R セッションの最後にオブジェクトが依然
    未収集であっても終末処理を実行するか?}
}
\details{
  この関数の主目的は，外部対象(例えば一時ファイル)を参照するオブジェクトが
  \R 内部から最早参照されなくなった時に，後片付け動作を行うことにある．
  これは付値の際に決してコピーされないオブジェクトに対してだけ意味を持つので，
  環境や外部ポインターだけに制限される．

  \emph{特に}これは \code{\link{.Last}} を操作すること無しに \R セッションの
  終わりにプログラムコードを実行する手段を提供する．
  パッケージ中では名前空間中のオブジェクトに対して終末処理，
  もしくはそれがセッション中で行われるのなら名前空間がアンロードされた直後に，
  を設定するのは良い考えである．
}
\value{
  \code{NULL}.
}
\note{
  \R のインタプリタは再入可能ではなく，終末処理は計算の途中で実行可能である．
  従って \code{f} から呼び出すと潜在的に安全でない関数が多数ある：
  問題を起こす一つの例は \code{\link{options}} である．
  \R 3.0.3 以来終末処理はガベージコレクション時に予定されているが，
  それ以降は相対的に安全なときにだけ実行される．
}
\seealso{
  ガベージコレクションとメモリ管理については \code{\link{gc}} と \code{\link{Memory}}．
}
\examples{
f <- function(e) print("cleaning....")
g <- function(x){ e <- environment(); reg.finalizer(e, f) }
g()
invisible(gc()) # クリーンアップを惹き起こす
}
\keyword{programming}
\keyword{environment}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/reg.finalizer.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{reg.finalizer}
%\alias{reg.finalizer}
%\alias{finalizer}
%\title{Finalization of Objects}
%\description{
%  Registers an \R function to be called upon garbage collection of
%  object or (optionally) at the end of an \R session.
%}
%\usage{
%  reg.finalizer(e, f, onexit = FALSE)
%}
%\arguments{
%  \item{e}{Object to finalize.  Must be an environment or an external pointer.}
%  \item{f}{Function to call on finalization. Must accept a single argument,
%    which will be the object to finalize.}
%  \item{onexit}{logical: should the finalizer be run if the object is
%    still uncollected at the end of the \R session?}
%}
%\details{
%  The main purpose of this function is to allow objects that refer to
%  external items (a temporary file, say) to perform cleanup actions when
%  they are no longer referenced from within \R.  This only makes sense
%  for objects that are never copied on assignment, hence the restriction
%  to environments and external pointers.
%
%  \emph{Inter alia}, it provides a way to program code to be run at
%  the end of an \R session without manipulating \code{\link{.Last}}.
%  For use in a package, it is often a good idea to set a finalizer on an
%  object in the namespace: then it will be called at the end of the
%  session, or soon after the namespace is unloaded if that is done
%  during the session.
%}
%\value{
%  \code{NULL}.
%}
%\note{
%  \R's interpreter is not re-entrant and the finalizer could be run in
%  the middle of a computation.  So there are many functions which it is
%  potentially unsafe to call from \code{f}: one example which caused
%  trouble is \code{\link{options}}.  As from \R 3.0.3 finalizers are
%  scheduled at garbage collection but only run at a relatively safe time
%  thereafter.
%}
%\seealso{
%  \code{\link{gc}} and \code{\link{Memory}} for garbage collection and
%  memory management.
%}
%\examples{
%f <- function(e) print("cleaning....")
%g <- function(x){ e <- environment(); reg.finalizer(e, f) }
%g()
%invisible(gc()) # trigger cleanup
%}
%\keyword{programming}
%\keyword{environment}
%
\encoding{UTF8}
