% File src/library/base/man/serialize.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{serialize}
\alias{serialize}
\alias{unserialize}
\title{Simple Serialization Interface}
\description{
  コネクションへのシリアル化の単純な低レベルインタフェイス．
}
\usage{
serialize(object, connection, ascii, xdr = TRUE,
          version = NULL, refhook = NULL)

unserialize(connection, refhook = NULL)
}
\arguments{
  \item{object}{シリアル化する \R オブジェクト．}
  \item{connection}{開かれたコネクション，又は(\code{serialize} に対して)
    \code{NULL} や (\code{unserialize} に対しては)バイト型ベクトル
    (\sQuote{詳細} を見よ)．}
  \item{ascii}{論理値．もし \code{TRUE} や \code{NA} ならアスキー表現が
    書き込まれる； さもなければ(既定)バイナリで書き込まれる．
    \code{\link{save}} に対するヘルプ中のコメントも見よ．}
  \item{xdr}{論理値：もしバイナリ表現が使われると，
    ビッグエンディアンなもの(XDR)を使うか?}
  \item{version}{使用する作業空間の書式．\code{NULL} は
    現在の既定書式 (2) を指定する．2 の前のバージョンはサポートされないので，
    これは最近のバージョンでは唯一関係する．}
  \item{refhook}{参照オブジェクトの処理のためのフック関数．}
}
\details{
  関数 \code{serialize} は \code{object} を指定されたコネクションに
  シリアル化する．もし \code{connection} が \code{NULL} ならば，
  \code{object} はバイト型ベクトルにシリアル化され，これは
  \code{serialize} の結果として返される．

  参照オブジェクトの共有はオブジェクトの内部に保存されているが
  \code{serialize} への別個の呼び出しを跨ってはされない．

  \code{unserialize} は(\code{serialize} で書き込まれた)オブジェクトを
  \code{connection} やバイト型ベクトルから読み込む．

  \code{refhook} 関数は非システム参照オブジェクト
  (全ての外部カウンターと弱参照，そして名前空間とパッケージ環境と
  \code{.GlobalEnv} 以外の全ての環境)の
  処理をカスタム化するために使うことが出来る.
  \code{serialize} に対するフック関数はそれが処理したい参照に対する
  文字列を返すべきである；さもなければそれは \code{NULL} を返すべきである．
  \code{unserialize} に対するフックは \code{serialize} に提供された
  文字列と共に呼び出され，そして適当なオブジェクトを返すべきである．

  テキストモードのコネクションに対しては，\code{ascii} の既定値は
  \code{TRUE} に設定される：アスキー表現だけがテキストモードのコネクション
  に書き込み可能で，\code{ascii = FALSE} を使用しようとすると
  エラーになる．

  書式は一つの行とそれに続くデータからなる：最初の行はただ一つの文字からなる：
  バイナリシリアル化には \code{X}，アスキーシリアル化には \code{A} で，
  新しい行が続く．(使用される書式は \code{\link{readRDS}} が使用するものと
  同じである．)

  \code{xdr = FALSE} のオプションは \R 2.15.0 で導入された．
  現在使われるほとんどすべてのシステムはリトルエンディアンであるため，
  これは一つのリトルエンディアンの計算機から別の計算機にデータを
  転送する際に両端でバイトシャッフルを避けるために使うことが出来る．
  システム依存であるが，これはシリアル化とアンシリアル化を最大3倍
  スピードアップ出来る．
}
\section{警告}{
  これらの関数は \R 2.4.0 以来安定したインタフェイスを提供してきた
  (\R 2.4.0 でシリアル化したオブジェクトの保存は文字からバイト型ベクトルに変換
  された)．しかしながら，シリアル化の書式は \R の将来のバージョンで変更される
  可能性があり，このインタフェイスは \R オブジェクトの長期保存に対しては
  使うべきではない．

  32 ビットプラットフォームではバイト型ベクトルは \eqn{2^{31} - 1}{2^31 - 1}
  バイトに制限されているが，\R オブジェクトはこれを超えることが可能で，
  それらのシリアル化は普通オブジェクトよりも大きくなる．
}
\value{
  \code{serialize} に対しては \code{NULL}．例外は \code{connection = NULL}
  の時で，その時は結果はバイトベクトルとして返される．

  \code{unserialize} に対しては \R オブジェクト．
}
\seealso{
  ファイルやコネクション用にオブジェクトをシリアル化するより便利な
  インタフェイスに付いては \code{\link{saveRDS}}．

  一つ又は複数の名前付きオブジェクトをシリアル化したり再生するには
  \code{\link{save}} と \code{\link{load}}．

  使われる書式の詳細についてはマニュアル \sQuote{R Internals}．
}
\examples{
x <- serialize(list(1,2,3), NULL)
unserialize(x)

## saveRDS に対する例も見よ
}
\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/serialize.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{serialize}
%\alias{serialize}
%\alias{unserialize}
%\title{Simple Serialization Interface}
%\description{
%  A simple low-level interface for serializing to connections.
%}
%\usage{
%serialize(object, connection, ascii, xdr = TRUE,
%          version = NULL, refhook = NULL)
%
%unserialize(connection, refhook = NULL)
%}
%\arguments{
%  \item{object}{\R object to serialize.}
%  \item{connection}{an open \link{connection} or (for \code{serialize})
%    \code{NULL} or (for \code{unserialize}) a raw vector
%    (see \sQuote{Details}).}
%  \item{ascii}{a logical.  If \code{TRUE} or \code{NA}, an ASCII
%    representation is written; otherwise (default) a binary one.
%    See also the comments in the help for \code{\link{save}}.}
%  \item{xdr}{a logical: if a binary representation is used, should a
%    big-endian one (XDR) be used?}
%  \item{version}{the workspace format version to use.  \code{NULL}
%    specifies the current default version (2).  Versions prior to 2 are not
%    supported, so this will only be relevant when there are later versions.}
%  \item{refhook}{a hook function for handling reference objects.}
%}
%\details{
%  The function \code{serialize} serializes \code{object} to the specified
%  connection.  If \code{connection} is \code{NULL} then \code{object} is
%  serialized to a raw vector, which is returned as the result of
%  \code{serialize}.
%
%  Sharing of reference objects is preserved within the object but not
%  across separate calls to \code{serialize}.
%
%  \code{unserialize} reads an object (as written by \code{serialize})
%  from \code{connection} or a raw vector.
%
%  The \code{refhook} functions can be used to customize handling of
%  non-system reference objects (all external pointers and weak
%  references, and all environments other than namespace and package
%  environments and \code{.GlobalEnv}).  The hook function for
%  \code{serialize} should return a character vector for references it
%  wants to handle; otherwise it should return \code{NULL}.  The hook for
%  \code{unserialize} will be called with character vectors supplied to
%  \code{serialize} and should return an appropriate object.
%
%  For a text-mode connection, the default value of \code{ascii} is set
%  to \code{TRUE}: only ASCII representations can be written to text-mode
%  connections and attempting to use \code{ascii = FALSE} will throw an
%  error.
%
%  The format consists of a single line followed by the data: the first
%  line contains a single character: \code{X} for binary serialization
%  and \code{A} for ASCII serialization, followed by a new line.  (The
%  format used is identical to that used by \code{\link{readRDS}}.)
%
%  The option of \code{xdr = FALSE} was introduced in \R 2.15.0.  As
%  almost all systems in current use are little-endian, this can be used
%  to avoid byte-shuffling at both ends when transferring data from one
%  little-endian machine to another.  Depending on the system, this can
%  speed up serialization and unserialization by a factor of up to 3x.
%}
%\section{Warning}{
%  These functions have provided a stable interface since \R 2.4.0 (when
%  the storage of serialized objects was changed from character to raw
%  vectors).  However, the serialization format may change in future
%  versions of \R, so this interface should not be used for long-term
%  storage of \R objects.
%
%  On 32-bit platforms a raw vector is limited to \eqn{2^{31} - 1}{2^31 -
%  1} bytes, but \R objects can exceed this and their serializations will
%  normally be larger than the objects.
%}
%\value{
%  For \code{serialize}, \code{NULL} unless \code{connection = NULL}, when
%  the result is returned in a raw vector.
%
%  For \code{unserialize} an \R object.
%}
%\seealso{
%  \code{\link{saveRDS}} for a more convenient interface to serialize an
%  object to a file or connection.
%
%  \code{\link{save}} and \code{\link{load}} to serialize and restore one
%  or more named objects.
%
%  The \sQuote{R Internals} manual for details of the format used.
%}
%\examples{
%x <- serialize(list(1,2,3), NULL)
%unserialize(x)
%
%## see also the examples for saveRDS
%}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
