% File src/library/base/man/tapply.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{tapply}
\alias{tapply}
\title{Apply a Function Over a Ragged Array}
\description{
  関数を不揃いの配列の各セルに適用する，つまりある因子の水準のユニークな組み合わせ
  で与えられる(空でない)値のグループ毎．
}
\usage{
tapply(X, INDEX, FUN = NULL, \dots, simplify = TRUE)
}
\arguments{
  \item{X}{原子的なオブジェクトで，典型的にはベクトル．}
  \item{INDEX}{一つ又は複数の因子で，各々は \code{X} と同じ長さ．
    要素は \code{\link{as.factor}} で因子に変換される．}
  \item{FUN}{適用される関数もしくは \code{NULL}．
    \code{+}, \code{\%*\%} 等の関数に対しては，関数名は逆引用化又は引用化
    されなければならない．もし \code{FUN} が \code{NULL} なら，tapply
    は \code{tapply} が普通生成する多元配列の添字操作に使えるベクトルを返す．}
  \item{\dots}{\code{FUN} へのオプション引数：ノート節．}
  \item{simplify}{もし \code{FALSE} なら \code{tapply} は常に
    モード \code{"list"} の配列を返す．
    もし \code{TRUE} (既定)なら，\code{FUN} が常にスカラーを返すならば
    \code{tapply} はスカラーモードの配列を返す．}
}
\value{
  もし \code{FUN} が \code{NULL} で無ければ，それは \code{\link{match.fun}} に
  渡され，従ってそれは関数でも関数名を与えるシンボルや文字列でも良い．

  \code{FUN} があれば，\code{tapply} はその中に何らかのデータがある各セル
  に対して \code{FUN} を呼び出す．もし \code{FUN} がそうした各セルに対して
  単一の原子的な値を返し(例えば関数 \code{mean} 又は \code{var})
  そして \code{simplify} が \code{TRUE} ならば，\code{tapply} は
  値を含む多元配列を返す．そして空のセルに対しては \code{NA} を
  返す．配列は \code{INDEX} が持つ成分と同じ数の次元を持つ；
  一つの次元中の水準の数は対応する \code{INDEX} の対応する成分中の
  水準の数(\code{nlevels()}) である．
  もし返り値がクラスを持てば(例えばクラス \code{"\link{Date}"} のオブジェクト)
  クラスは捨て去られる．

  S とは逆に \code{simplify = TRUE} は常に配列，もしかすると 1 次元，を返す
  ことを注意する．

  もし \code{FUN} が単一の原子的な値を返さなければ \code{tapply}
  はモード \code{\link{list}} の配列を返し，
  その成分は \code{FUN} への個別の呼び出しの値である，つまり
  結果は次元属性を持つリストである．

  配列が返されるときはその次元名は \code{INDEX} の名前を使い名付けられ，
  (もしかすると変換の後の)グルーピング因子の水準に基づいている．

  リストの結果に対しては，空のセルに対応する要素は \code{NULL} である．.
}
\note{
  \code{...} 引数で与えられる \code{FUN} へのオプション引数は
  セルに分割されない．従って \code{FUN} に対して \code{X} と同じ長さの
  追加引数を期待するときは不適当である．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  便利関数 \code{\link{by}} と
  \code{\link{aggregate}} (\code{tapply} を使う);
  \code{\link{apply}},
  \code{\link{lapply}} とそのバージョン
  \code{\link{sapply}} と \code{\link{mapply}}．
}
\examples{
require(stats)
groups <- as.factor(rbinom(32, n = 5, prob = 0.4))
tapply(groups, groups, length) #- 次とほとんど同じ
table(groups)

## データフレームからの分割表：名前付き次元名を持つ配列
tapply(warpbreaks$breaks, warpbreaks[,-1], sum)
tapply(warpbreaks$breaks, warpbreaks[, 3, drop = FALSE], sum)

n <- 17; fac <- factor(rep(1:3, length = n), levels = 1:5)
table(fac)
tapply(1:n, fac, sum)
tapply(1:n, fac, sum, simplify = FALSE)
tapply(1:n, fac, range)
tapply(1:n, fac, quantile)

## ... 引数の例：四半期毎の平均を見つける
tapply(presidents, cycle(presidents), mean, na.rm = TRUE)

ind <- list(c(1, 2, 2), c("A", "A", "B"))
table(ind)
tapply(1:3, ind) #-> the split vector
tapply(1:3, ind, sum)
}
\keyword{iteration}
\keyword{category}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/tapply.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{tapply}
%\alias{tapply}
%\title{Apply a Function Over a Ragged Array}
%\description{
%  Apply a function to each cell of a ragged array, that is to each
%  (non-empty) group of values given by a unique combination of the
%  levels of certain factors.
%}
%\usage{
%tapply(X, INDEX, FUN = NULL, \dots, simplify = TRUE)
%}
%\arguments{
%  \item{X}{an atomic object, typically a vector.}
%  \item{INDEX}{list of one or more factors, each of same length as
%    \code{X}.  The elements are coerced to factors by \code{\link{as.factor}}.}
%  \item{FUN}{the function to be applied, or \code{NULL}.  In the case of
%    functions like \code{+}, \code{\%*\%}, etc., the function name must
%    be backquoted or quoted.  If \code{FUN} is \code{NULL}, tapply
%    returns a vector which can be used to subscript the multi-way array
%    \code{tapply} normally produces.}
%  \item{\dots}{optional arguments to \code{FUN}: the Note section.}
%  \item{simplify}{If \code{FALSE}, \code{tapply} always returns an array
%    of mode \code{"list"}.  If \code{TRUE} (the default), then if
%    \code{FUN} always returns a scalar, \code{tapply} returns an array
%    with the mode of the scalar.}
%}
%\value{
%  If \code{FUN} is not \code{NULL}, it is passed to
%  \code{\link{match.fun}}, and hence it can be a function or a symbol or
%  character string naming a function.
%
%  When \code{FUN} is present, \code{tapply} calls \code{FUN} for each
%  cell that has any data in it.  If \code{FUN} returns a single atomic
%  value for each such cell (e.g., functions \code{mean} or \code{var})
%  and when \code{simplify} is \code{TRUE}, \code{tapply} returns a
%  multi-way \link{array} containing the values, and \code{NA} for the
%  empty cells.  The array has the same number of dimensions as
%  \code{INDEX} has components; the number of levels in a dimension is
%  the number of levels (\code{nlevels()}) in the corresponding component
%  of \code{INDEX}.  Note that if the return value has a class (e.g., an
%  object of class \code{"\link{Date}"}) the class is discarded.
%
%  Note that contrary to S, \code{simplify = TRUE} always returns an
%  array, possibly 1-dimensional.
%
%  If \code{FUN} does not return a single atomic value, \code{tapply}
%  returns an array of mode \code{\link{list}} whose components are the
%  values of the individual calls to \code{FUN}, i.e., the result is a
%  list with a \code{\link{dim}} attribute.
%
%  When there is an array answer, its \code{\link{dimnames}} are named by
%  the names of \code{INDEX} and are based on the levels of the grouping
%  factors (possibly after coercion).
%
%  For a list result, the elements corresponding to empty cells are
%  \code{NULL}.
%}
%\note{
%  Optional arguments to \code{FUN} supplied by the \code{...} argument
%  are not divided into cells.  It is therefore inappropriate for
%  \code{FUN} to expect additional arguments with the same length as
%  \code{X}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  the convenience functions \code{\link{by}} and
%  \code{\link{aggregate}} (using \code{tapply});
%  \code{\link{apply}},
%  \code{\link{lapply}} with its versions
%  \code{\link{sapply}} and \code{\link{mapply}}.
%}
%\examples{
%require(stats)
%groups <- as.factor(rbinom(32, n = 5, prob = 0.4))
%tapply(groups, groups, length) #- is almost the same as
%table(groups)
%
%## contingency table from data.frame : array with named dimnames
%tapply(warpbreaks$breaks, warpbreaks[,-1], sum)
%tapply(warpbreaks$breaks, warpbreaks[, 3, drop = FALSE], sum)
%
%n <- 17; fac <- factor(rep(1:3, length = n), levels = 1:5)
%table(fac)
%tapply(1:n, fac, sum)
%tapply(1:n, fac, sum, simplify = FALSE)
%tapply(1:n, fac, range)
%tapply(1:n, fac, quantile)
%
%## example of ... argument: find quarterly means
%tapply(presidents, cycle(presidents), mean, na.rm = TRUE)
%
%ind <- list(c(1, 2, 2), c("A", "A", "B"))
%table(ind)
%tapply(1:3, ind) #-> the split vector
%tapply(1:3, ind, sum)
%}
%\keyword{iteration}
%\keyword{category}
%\encoding{UTF8}

\encoding{UTF8}

