% File src/library/base/man/tempfile.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{tempfile}
\alias{tempfile}
\alias{tempdir}
\title{Create Names for Temporary Files}
\description{
  \code{tempfile} は一時ファイルの名前として使うことが出来る文字列ベクトルを
  返す．
}
\usage{
tempfile(pattern = "file", tmpdir = tempdir(), fileext = "")
tempdir()
}
\arguments{
  \item{pattern}{名前の最初の部分を与える空でない文字列ベクトル．}
  \item{tmpdir}{ディレクトリ名を与える空でない文字列ベクトル．}
  \item{fileext}{ファイル拡張子を与える空でない文字列ベクトル．}
}
\value{
  \code{tempfile} に対しては可能な(一時)ファイルの名前を与える文字列ベクトル．
  \code{tempfile} はファイルを生成しないことを注意する．

  \code{tempdir} に対してはセッション毎の一時ディレクトリのパス．
#ifdef windows

  両者はパス分離記号としてバックスラッシュを使う．
#endif
}
\details{
  結果の長さは三つの引数の長さの最大値になる；
  短い引数の値はリサイクルされる．

  名前は \R セッションと同時に開かれている \R セッションの中では
  \code{tempfile} への呼び出しに関してユニークである可能性が非常に
  高い(\code{tmpdir} が指定されていない限り)．
  フェイル名は現在使われていないことが保証される.

  ファイル名は \code{tmpdir}, \code{pattern} 文字列，ランダムな16進数文字列，
  そして拡張子 \code{fileext} で与えられるパスを連結して得られる．

  既定では \code{tmpdir} は \code{tempdir()} で与えられるディレクトリになる．
  これは セッション毎のサブディレクトリで \R セッションが開始した時
  環境変数 \env{TMPDIR}, \env{TMP} そして \env{TEMP} が順にチェックされ
  書き込み可能なディレクトリを指し示す最初に見つかったものが使われる：
#ifdef unix
  もしどれも不成功なら \file{/tmp} が使われる．パスは空白を含んではならない．
#endif
#ifdef windows
  もしどれも不成功なら \env{R_USER} の値が使われる
  (\code{\link{Rconsole}} を見よ)．
  もしディレクトリへのパスが成分のどれかに空白を含めば，
  返されるパスはパスの短縮形を使う．
#endif
  \R セッション中のこれらの環境変数のどれかの設定は
  \code{tempdir()} に影響を与えない：セッション毎の一時ディレクトリは
  インタプリタが開始する前に作られる．
}
\section{並列化に関する注意}{
  パッケージ \pkg{parallel} (又は \CRANpkg{multicore}) 中の
  \code{\link{mclapply}} のような関数でフォークされた \R プロセスは
  セッション毎の一時ディレクトリを共有する．
  更に，\sQuote{現在使用中でないことの保証}は依頼時だけに適用され，
  二つの子プロセスは同時に依頼する可能性がある．これは異なった子プロセスが
  異なった名前で \code{tempfile} を呼び出すことで克服できる．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{ファイルを削除するには \code{\link{unlink}}．}
\examples{\donttest{
tempfile(c("ab", "a b c"))   # スペース入りのファイル名を与える!

tempfile("plot", fileext = c(".ps", ".pdf"))

tempdir() #全てのプラットフォームで動作するがプラットフォーム依存の結果
}}
\keyword{file}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/tempfile.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{tempfile}
%\alias{tempfile}
%\alias{tempdir}
%\title{Create Names for Temporary Files}
%\description{
%  \code{tempfile} returns a vector of character strings which can be used as
%  names for temporary files.
%}
%\usage{
%tempfile(pattern = "file", tmpdir = tempdir(), fileext = "")
%tempdir()
%}
%\arguments{
%  \item{pattern}{a non-empty character vector giving the initial part
%    of the name.}
%  \item{tmpdir}{a non-empty character vector giving the directory name}
%  \item{fileext}{a non-empty character vector giving the file extension}
%}
%\value{
%  For \code{tempfile} a character vector giving the names of possible
%  (temporary) files.  Note that no files are generated by \code{tempfile}.
%
%  For \code{tempdir}, the path of the per-session temporary directory.
%#ifdef windows
%
%  Both will use backslash as the path separator.
%#endif
%}
%\details{
%  The length of the result is the maximum of the lengths of the three
%  arguments; values of shorter arguments are recycled.
%
%  The names are very likely to be unique among calls to \code{tempfile}
%  in an \R session and across simultaneous \R sessions (unless
%  \code{tmpdir} is specified).  The filenames are guaranteed not to be
%  currently in use.
%
%  The file name is made by concatenating the path given by
%  \code{tmpdir}, the \code{pattern} string, a random string in hex and
%  a suffix of \code{fileext}.
%
%  By default, \code{tmpdir} will be the directory given by
%  \code{tempdir()}.  This will be a subdirectory of the per-session
%  temporary directory found by the following rule when the \R session is
%  started.  The environment variables \env{TMPDIR}, \env{TMP} and
%  \env{TEMP} are checked in turn and the first found which points to a
%  writable directory is used:
%#ifdef unix
%  if none succeeds \file{/tmp} is used.  The path should not contain spaces.
%#endif
%#ifdef windows
%  if none succeeds the value of \env{R_USER} (see
%  \code{\link{Rconsole}}) is used.  If the path to the directory
%  contains a space in any of the components, the path returned will use
%  the shortnames version of the path.
%#endif
%  Note that setting any of these environment variables in the \R session
%  has no effect on \code{tempdir()}: the per-session temporary directory
%  is created before the interpreter is started.
%}
%\section{Note on parallel}{
%  \R processes forked by functions such as \code{\link{mclapply}} in
%  package \pkg{parallel} (or \CRANpkg{multicore}) share a per-session
%  temporary directory.  Further, the \sQuote{guaranteed not to be
%    currently in use} applies only at the time of asking, and two
%  children could ask simultaneously.  This is circumvented
%  by ensuring that \code{tempfile} calls in different children try
%  different names.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{\code{\link{unlink}} for deleting files.}
%\examples{\donttest{
%tempfile(c("ab", "a b c"))   # give file name with spaces in!
%
%tempfile("plot", fileext = c(".ps", ".pdf"))
%
%tempdir() # works on all platforms with a platform-dependent result
%}}
%\keyword{file}
%\encoding{UTF8}

\encoding{UTF8}

