% File src/library/graphics/man/par.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{par}
\alias{par}
\alias{.Pars}
\concept{adj}
\concept{ann}
\concept{ask}
\concept{bg}
\concept{bty}
\concept{cex.axis}
\concept{cex.lab}
\concept{cex.main}
\concept{cex.sub}
\concept{cex}
\concept{cin}
\concept{col.axis}
\concept{col.lab}
\concept{col.main}
\concept{col.sub}
\concept{col}
\concept{cra}
\concept{crt}
\concept{csi}
\concept{cxy}
\concept{din}
\concept{err}
\concept{family}
\concept{fg}
\concept{fig}
\concept{fin}
\concept{font.axis}
\concept{font.lab}
\concept{font.main}
\concept{font.sub}
\concept{font}
\concept{lab}
\concept{las}
\concept{lend}
\concept{lheight}
\concept{ljoin}
\concept{lmitre}
\concept{lty}
\concept{lwd}
\concept{mai}
\concept{mar}
\concept{mex}
\concept{mfcol}
\concept{mfg}
\concept{mfrow}
\concept{mgp}
\concept{mkh}
\concept{new}
\concept{oma}
\concept{omd}
\concept{omi}
\concept{page}
\concept{pch}
\concept{pin}
\concept{plt}
\concept{ps}
\concept{pty}
\concept{smo}
\concept{srt}
\concept{tck}
\concept{tcl}
\concept{usr}
\concept{xaxp}
\concept{xaxs}
\concept{xaxt}
\concept{xlog}
\concept{xpd}
\concept{yaxp}
\concept{yaxs}
\concept{yaxt}
\concept{ylog}
\concept{color}
\concept{colour}
\alias{graphical parameter}
\alias{graphical parameters}

\title{Set or Query Graphical Parameters}

%% The 'real documentation' is the code in ../../../main/par.c
%% AND (defined AND commented)          in ../../../include/Graphics.h
%% Default initialization by GInit()    in ../../../main/graphics.c

\description{
  \code{par} はグラフィカルパラメータの設定や確認に使える．
  パラメータはそれらを \code{tag = value} 形式で \code{par} への
  引数として指定することで設定出来る．又はそれらを タグ付きリストとして
  渡す．
}
\usage{
par(\dots, no.readonly = FALSE)

\special{<highlevel plot> (..., <tag> = <value>)}
}

\arguments{
  \item{\dots}{\code{tag = value} 形式の引数，又はタグ付き値のリスト．
    タグは
    \sQuote{グラフィカルパラメータ}節で述べられるグラフィカルパラメータ
    の名前から来なければならない．}
  \item{no.readonly}{論理値；もし \code{TRUE} で他の引数がなければ，
    パラメータだけが返され，それは引き続く
    \emph{同じデバイス上での} \code{par()} 呼び出し
    で設定できる．}
}

\details{
  各デバイスはそれ自体のグラフィカルパラメータのセットを持つ．
  もし現在のデバイスがヌルデバイスならば，\code{par} は新しいデバイスを
  パラメータの問い合わせ/設定の前に開く．
  (どのデバイスかは \code{\link{options}("device")} で制御される．)

  パラメータは一つ又はそれ以上のパラメータ名の文字列ベクトルを
  \code{par} に与えることで問い合わせできる．

  \code{par()} (引数無し)又は \code{par(no.readonly = TRUE)} は
  \emph{全て}のグラフィカルパラメータを(名前付きリストとして)を得ることに
  使える．名前は現在未移出の変数 
  \code{graphics:::.Pars} から取られる．

  \emph{\bold{R.O.}} は\emph{\bold{読み取りのみの引数}}を表す：
  これらは問い合わせ中でのみ使われ設定は出来ない．
  (\code{"cin"}, \code{"cra"}, \code{"csi"}, \code{"cxy"}, \code{"din"} そして
  \code{"page"} は常に読み取り専用である．)

  幾つかのパラメータは \code{par()} の呼び出しによってのみ設定できる：
  \itemize{
    \item \code{"ask"},
    \item \code{"fig"}, \code{"fin"},
    \item \code{"lheight"},
    \item \code{"mai"}, \code{"mar"}, \code{"mex"},
    \code{"mfcol"}, \code{"mfrow"}, \code{"mfg"},
    \item \code{"new"},
    \item \code{"oma"}, \code{"omd"}, \code{"omi"},
    \item \code{"pin"}, \code{"plt"}, \code{"ps"}, \code{"pty"},
    \item \code{"usr"},
    \item \code{"xlog"}, \code{"ylog"},
    \item \code{"ylbias"}
  }
  残りのパラメータもまた
  \code{\link{plot.default}}, \code{\link{plot.window}},
  \code{\link{points}}, \code{\link{lines}}, \code{\link{abline}},
  \code{\link{axis}}, \code{\link{title}}, \code{\link{text}},
  \code{\link{mtext}}, \code{\link{segments}}, \code{\link{symbols}},
  \code{\link{arrows}}, \code{\link{polygon}}, \code{\link{rect}},
  \code{\link{box}}, \code{\link{contour}}, \code{\link{filled.contour}}
  そして \code{\link{image}} のような高水準関数への
  引数として設定できる(しばしば \code{\dots} として)．
  そうした設定は関数の実行中にだけ設定される．
  しかしながら
  \code{bg}, \code{cex}, \code{col}, \code{lty}, \code{lwd} そして
  \code{pch} に関するコメントを見よう．これらは
  グラフィカルパラメータではなくある種のプロット関数への
  \emph{引数}として使うことが出来る．

  \sQuote{文字サイズ}の意味は完全には定義されていない：
  これは \code{pointsize} を考慮するデバイスに対して設定されるが，
  しばしば実際に使われるフォント族を設定しない．
  内部的には対応するパラメータ
  (\code{cra}, \code{cin}, \code{cxy} そして \code{csi})が
  \code{mar} と \code{oma} を物理的なマージンに変換するのに
  使われる行間スペースを設定するためだけに使われる．
  (\code{lheight} 倍された同じ行間スペースが \code{text} と
  \code{strheight}中の複数行文字列に対して使われる．)

  グラフィカルパラメータは推奨であることを注意する：
  プロット関数とデバイスはそれらを使う必要が無い
  (そしてこれは特に，例えば \code{plot} に対する既定でない
  メソッドに対して真である)．
}

\value{
  パラメータが設定された時，
  それらの前の値が不可視の名前付きリストとして返される．
  そうしたリストはパラメータ値を回復するために
  \code{par} の引数として渡すことが出来る．
  回復することができるパラメータの完全なリストは \code{par(no.readonly = TRUE)}
  を使って得られる．
  しかしながらこれらすべてを回復するのは賢明ではない：
  \sQuote{注意}節を見よ．

  ただ一つのパラメータを問い合わせた時は，そのパラメータの値は
  (原子的な)ベクトルとして返される．
  二つもしくはそれ以上のパラメータを問い合わせした時は，
  それらの値はリストとして返され，リスト名がパラメータを与える．

  非一貫性に注意しよう：一つのパラメータの設定はリストを返すが，
  一つのパラメータの問い合わせはベクトルを返す．
}

\section{グラフィカルパラメータ}{
  \describe{
    \item{\code{adj}}{\code{adj} の値は
      \code{\link{text}}, \code{\link{mtext}} そして \code{\link{title}}
      中でテキスト文字列がジャスティファイされる仕方を決定する．
      値 \code{0} は左揃いのテキスト，
      \code{0.5} (既定)は中央化テキスト，そして \code{1}
      は右揃いのテキストを作り出す．
      (\eqn{[0, 1]} 中の任意の値が許され，そしてこの区間の外側の値も
      殆どのデバイスで使える．)

      \code{\link{text}} の \code{adj} \emph{引数}はまた
      x と y 方向の異なった補正のための
      \code{adj = c(x, y)} を認める．

      \code{text} に対してはそれはテキストのある点のまわりの
      位置決めを参照する一方，
      \code{mtext} と \code{title} に対してはそれは
      プロット又はデバイス領域内での配置を制御することを注意しよう．}
    \item{\code{ann}}{もし \code{FALSE} に設定すると，
      \code{\link{plot.default}} を呼び出す高水準プロット関数は
      それらが作り出すプロットに軸タイトルと全体タイトルを注釈しない．
      既定は注釈をする．}
    \item{\code{ask}}{論理値．もし \code{TRUE} (そして \R セッションが対話的なら)
      ユーザは新しい図が描かれる前に入力を求められる．
      これはデバイスに適用されるため，
      パッケージ \pkg{grid} と \CRANpkg{lattice} による出力にも影響する．
      これはスクリーンを使わないデバイスにさえも設定できるが
      そこでは何の効果もない．

      これは実際にはグラフィックスパラメータではなく，
      その使用は \code{\link{devAskNewPage}} を優先して廃止されている．
    }
    \item{\code{bg}}{デバイス領域の背景色．
      \code{par()} から呼び出されるとそれはまた \code{new = FALSE}
      を設定する．適当な値については\sQuote{色指定}節を見よ．
      多くのデバイスに対しては初期値は
      デバイスの \code{bg} 引数から取られ，そしてその他では普通
      \code{"white"} である．

      \code{\link{plot.default}} と \code{\link{points}}
      の様な幾つかのグラフィックス関数は
      この名前で異なった意味を持つ\emph{引数}を持つことを注意する．}
      
    \item{\code{bty}}{プロットのまわりに描かれる
      \code{\link{box}} のタイプを決める文字列．
      もし \code{bty} が \code{"o"} (既定), \code{"l"}, \code{"7"},
      \code{"c"}, \code{"u"} または \code{"]"} の一つなら，
      結果のボックスは対応する大文字に似る．
      値 \code{"n"} はボックスを描かない．}．
      
    \item{\code{cex}}{
      既定値に関してテキストとシンボルをどれだけ拡大するかを指定する数値．
      これはデバイスが開かれた時 \code{1} から出発し，
      レイアウトが変更，つまり \code{mfrow} の設定で，されるとリセットされる．

      \code{\link{plot.default}} の様な幾つかのグラフィックス関数は
      このグラフィックスパラメータを\emph{拡大}する同名の
      \emph{引数}を持ち，\code{\link{points}} と \code{\link{text}} のような
      ある種の関数はリサイクルされる値のベクトルを受け入れることを注意する．
    }
    
    \item{\code{cex.axis}}{
      軸注釈に対して使われる現在の \code{cex} の設定に関して相対的な
      拡大率．}
      
    \item{\code{cex.lab}}{
      現在の \code{cex} の設定に関して相対的な x と y ラベルに対して使われる
      拡大率．}
      
    \item{\code{cex.main}}{
      現在の \code{cex} の設定に関して相対的な主タイトルに対して使われる
      拡大率．}
      
    \item{\code{cex.sub}}{
      現在の \code{cex} の設定に関して相対的な副タイトルに対して使われる
      拡大率．}
      
    \item{\code{cin}}{\emph{\bold{R.O.}}；インチ単位の
      文字サイズ \code{(width, height)}．これらは異なった単位で表現された
      \code{cra} と同じ計測である．}
      
    \item{\code{col}}{既定のプロット色の指定．
      \sQuote{色指定}節を見よ．

      \code{\link{lines}} と \code{\link{text}} の様なある種の関数は
      リサイクルされる値のベクトルを受け入れ少し異なった解釈を
      されるかもしれない．
    }
    \item{\code{col.axis}}{軸の注釈に使われる色．既定では \code{"black"}．}
    \item{\code{col.lab}}{x と y ラベルに使われる色．既定では \code{"black"}．}
    \item{\code{col.main}}{プロットの主タイトルに対して使われる色．既定では \code{"black"}．}
    \item{\code{col.sub}}{プロットの副タイトルに対して使われる色．既定では \code{"black"}．}
    \item{\code{cra}}{\emph{\bold{R.O.}}；既定の文字の\sQuote{ラスター}(ピクセル)単位の
      \code{(width, height)}．ある種のデバイスはピクセルの概念を持たず
      従って任意のピクセルサイズを仮定し，普通 1/72 インチである．
      同じ計測が \code{cin} としてあり，異なった単位で表現される．}
    \item{\code{crt}}{一つの文字をどれだけ回転するか(度単位)を指示する
      数値．90度の倍数以外の値が使えると仮定するのは賢くない．
      文字列の回転を行う \code{srt} と比較せよ．}
    \item{\code{csi}}{\emph{\bold{R.O.}}；(既定サイズの)文字のインチ単位の高さ．
      \code{par("cin")[2]} と同じ．}
    \item{\code{cxy}}{\emph{\bold{R.O.}}；ユーザ座標単位での既定の文字サイズ
      \code{(width, height)}．
      \code{par("cxy")} はユーザ座標にスケール化された \code{par("cin")/par("pin")}
      である．
      与えられた \code{ch} に対しては \code{c(\link{strwidth}(ch), \link{strheight}(ch))}
      がより正確であることを注意する．}
    \item{\code{din}}{\emph{\bold{R.O.}}；インチ単位のデバイス次元
      \code{(width, height)}．\code{\link{dev.size}} も見よ，
      これはスクリーン上のデバイスウィンドのサイズが変更されると即座に
      更新される．}
    \item{\code{err}}{(\emph{未実装})；プロット領域外の点がプロット\emph{されない}時
      \R は警告しない．期待されるエラー報告の程度．}
      
    \item{\code{family}}{テキストを書くためのフォント族の名前．
      許される最大長は 200 バイトである．
      この名前は各デバイスによりデバイス固有のフォント記述にマップされる．
      既定値の \code{""} は既定のデバイスフォントを使うことを意味する
      (そしてこれらが何であるかはデバイスに対するヘルプページにリストされている)．
      標準の値は
      \code{"serif"}, \code{"sans"} そして \code{"mono"} で，そして
      \link{Hershey} フォント族もまた利用可能である．
      (デバイスは他を定義しているかもしれず，ある種のデバイスはこの設定を
      完全に無視する．
      \code{"Hershey"} で始まるフォントは特別に扱われ組み込みの
      Hershey フォントに対してだけ使われるべきである．)
      これは \code{\link{text}} に対してはインラインで指定できる．}

    \item{\code{fg}}{プロットの前面に対して使われる色．
      これは軸やプロット周りのボックスのようなものに対する既定色である．
      \code{par()} から呼び出された時はこれはまた
      パラメータ \code{col} を同じ値に設定する．
      \sQuote{色指定}節を見よ.初期値を設定する引数を持つデバイスがあり，
      それはさもなければ \code{"black"} である．}
      
    \item{\code{fig}}{
      形式 \code{c(x1, x2, y1, y2)} の数値ベクトルでデバイスの
      ディスプレイ領域中の図領域の(NDC)座標を与える．
      もしこれを設定すると，S とは異なり，新しいプロットを開始するので，
      既存のプロットに付け加えるには \code{new = TRUE} も使おう．}
      
    \item{\code{fin}}{インチ単位の図領域の次元 \code{(width, height)}．
      もしこれを設定すると，S とは異なり新しいプロットを開始する．}
      
    \item{\code{font}}{テキストに対して使われるフォントを指定する整数．
      もし可能ならデバイスドライバは， 1 が平文テキスト(既定)，
      2 が太字，3 がイタリック，そして
      4 が太字のイタリックに対応する様に按配する．
      又フォント 5 は Adobe のシンボルエンコーディングにおけるシンボルフォントに
      対応することが期待されている．
      ある種のデバイスではフォント族は異なった5フォントのセットを選ぶ
      \code{family} により選択できる．}
      
    \item{\code{font.axis}}{軸注釈に使われるフォント．}
    \item{\code{font.lab}}{ x と y ラベルに対して使われるフォント．}
    \item{\code{font.main}}{主タイトルに使われるフォント．}
    \item{\code{font.sub}}{副タイトルに使われるフォント．}
    
    \item{\code{lab}}{
      形式 \code{c(x, y, len)} の数値ベクトルで既定の軸の注釈を修正する．
      既定の  \code{x} と \code{y} の値は
      x と y 軸のチックマークの(近似的な)数を与え，
      \code{len} はラベルの長さを指定する．
      既定は \code{c(5, 5, 7)} である．
      これはユーザシステムが設定された時パラメータ \code{xaxp} と \code{yaxp}
      を設定される仕方にだけ影響し，軸が描かれる時だけ留意される
      ことを注意しよう．\R では \code{len} は\emph{未実装}である．}
      
    \item{\code{las}}{\{0,1,2,3\} 中の数値；軸ラベルのスタイル．
      \describe{
        \item{0:}{常に軸に平行[\emph{既定値}]，}
        \item{1:}{常に水平，}
        \item{2:}{常に軸に垂直，}
        \item{3:}{常に垂直．}
      }
      また \code{\link{mtext}} でサポートされる
      \code{par} への引数 \code{srt} を使った文字列/文字の回転は
      軸ラベルに影響\emph{しない}ことを注意する．
    }
    \item{\code{lend}}{線の端のスタイル．これは整数か文字列で指定できる：
      \describe{
        \item{\code{0}}{そして \code{"round"} は半円の線端を意味する
          [\emph{既定値}]；}
        \item{\code{1}}{そして \code{"butt"} は垂直でフラットな線端を意味する；}
        \item{\code{2}}{そして \code{"square"} は線幅の半分の四角形を意味する．}
      }
    }
    \item{\code{lheight}}{行の高さへの乗数．
      テキストの行の高さ(垂直にスペースを持つ複数行テキスト)は
      現在の文字の拡大と行の高さへの乗数として見出される．
      既定値は 1 である．\code{\link{text}} と \code{\link{strheight}} で使われる．}
    \item{\code{ljoin}}{線の結び目のスタイル．
      これは整数化文字列で指定できる：
      \describe{
        \item{\code{0}}{そして \code{"round"} は丸い結び目を意味する
          [\emph{既定}];}
        \item{\code{1}}{そして \code{"mitre"} は角の結び目を意味する；}
        \item{\code{2}}{そして \code{"bevel"} の斜めの結び目を意味する．}
      }
    }
    \item{\code{lmitre}}{線の角結び目の限界．これはいつ角の結び目を
      斜めの結び目に変換するかを制御する．値は 1 より大きくなければならず
      既定値は 10 である．
      全てのデバイスがこの設定を尊重するわけではない．}
    \item{\code{lty}}{線種．
      線種は整数(0=ブランク，1=実線(既定)，2=ダッシュ，3=ドット，
      4=ドットとダッシュ，5=長いダッシュ，6=二つのダッシュ)
      又は文字列 \code{"blank"}, \code{"solid"},
      \code{"dashed"}, \code{"dotted"}, \code{"dotdash"},
      \code{"longdash"} 又は \code{"twodash"} のいずれかで指定される．
      ここで \code{"blank"} は\sQuote{見えない線} (つまりそれらを描かない)
      を意味する．

      別法として，(\code{c(1:9,"A":"F")} からの)最大8文字を
      与えることが出来，交互に描かれたりスキップされる線分の長さを与える．
      \sQuote{線種の指定}節を見よ．

      \code{\link{lines}} や \code{\link{segments}} の様な関数は
      リサイクルされる値のベクトルを受け入れる．
    }
    \item{\code{lwd}}{線幅で\emph{正}の数，既定では \code{1}．
      解釈はデバイス固有で，ある種のデバイスは1未満の線幅を実装しない．
      (解釈の詳細についてはデバイスのヘルプを見よ．)

      \code{\link{lines}} と \code{\link{segments}} といった
      関数はリサイクルされる値のベクトルを受け入れる：
      そうした用法では値 \code{NA} 又は \code{NaN} に対応する線は無視される．
      \code{0} の解釈はデバイス固有である．
    }
    \item{\code{mai}}{
        形式 \code{c(bottom, left, top, right)} の数値ベクトルで
      インチ単位のマージンサイズを与える．\cr
      \if{html}{\figure{mai.png}{options: width="35\%" alt="Figure: mai.png"}}
      \if{latex}{\figure{mai.pdf}{options: width=7cm}}
    }
    \item{\code{mar}}{
      形式 \code{c(bottom, left, top, right)} の数値ベクトルで，
      プロットの四つの側面に指定されるマージンの行数．
      既定値は \code{c(5, 4, 4, 2) + 0.1}．}
      
    \item{\code{mex}}{
      \code{mex} は文字サイズの拡大因子で，
      プロットのマージン中の座標を記述するのに使われる．
      これはフォントサイズは変更せず，代わりに
      \code{mar} と \code{mai} の間，そして \code{oma} と
      \code{omi} の間の変換に使われる.
      フォントのサイズを指定する(\code{csi} の倍数として)．

      これはデバイスが開かれた時 \code{1} として出発し，
      レイアウトが変更された時リセットされる
      (\code{cex} のリセットとならんで)．
    }
    
    \item{\code{mfcol, mfrow}}{
      形式 \code{c(nr, nc)}. のベクトル．
      それ以降の図ははデバイス上
      \code{nr} x \code{nc} の配列中にそれぞれ
      \emph{列順} (\code{mfcol}) か，または
      \emph{行順} (\code{mfrow}) に描かれる．

      正確に二つの行と列を持つレイアウトでは
      \code{"cex"} の基本値は因子 0.83 倍縮小される：
      もし行か列が3かそれ以上であれば縮小因子は
      0.66 である．

      レイアウトの設定は
      \code{cex} の基本値をリセットし \code{mex} のそれを \code{1}
      にする．

      もしこれらのどれかが問い合わせられるとそれは現在のレイアウトを
      与えるので，問い合わせは配列が埋められた順序は教えてくれない．

      別の方法 \code{\link{layout}} と \code{\link{split.screen}} を
      考慮してみよう．
    }
    
    \item{\code{mfg}}{
      形式 \code{c(i, j)} の数値ベクトルで，
      \code{i} と \code{j} は図の配列中どの図が次に描かれるか
      (もし設定されていれば)または描かれているか(問い合わせの時)
      を指示する．配列は既に
      \code{mfcol} または \code{mfrow} で設定されていなければならない．

      S との互換性のために，
      \code{nr} と \code{nc} が現在の行数と列数ならば，
      形式 \code{c(i, j, nr, nc)} が又受け入れられる．
      ミスマッチは警告と共に無視される．}
      
    \item{\code{mgp}}{
      軸タイトル，軸ラベル，そして軸行に対するマージン行(\code{mex} 単位)．
      \code{mgp[1]} は \code{\link{title}} に影響し，
      一方 \code{mgp[2:3]} は \code{\link{axis}} に影響する．
      既定値は \code{c(3, 1, 0)}．}
      
    \item{\code{mkh}}{
      \code{pch} の値が整数の時描かれるシンボルのインチ単位の高さ．
      \R では\emph{完全に無視}される．
    }
    
    \item{\code{new}}{論理値で，既定値は \code{FALSE}．
      もし \code{TRUE} ならば，次の高水準プロット命令
      (実際は \code{\link{plot.new}}) は
      \emph{あたかもそれが\bold{\emph{新しい}}デバイスであるかのように}
      見做し，描く前にフレームを\emph{掃除すべきではない}．
      \code{new = TRUE} を現在高水準プロットを含まないデバイス上で
      使おうとすることはエラーである(警告と共に無視される)．}
      
    \item{\code{oma}}{
      A vector of the form
      開始期 \code{c(bottom, left, top, right)} のベクトルで，
      テキストの行単位の外部マージンのサイズを与える．
      \if{html}{\figure{oma.png}{options: width="25\%" alt="Figure: oma.png"}}
      \if{latex}{\figure{oma.pdf}{options: width=6cm}}
    }
    
    \item{\code{omd}}{形式 \code{c(x1, x2, y1, y2)} のベクトルで
      NDC (=正規化デバイス座標)での外部マージンの
      \emph{内部}領域を与える，つまり
      デバイス領域の割合(\eqn{[0, 1]} 中)である．}
      
    \item{\code{omi}}{
        A vector of the form
	形式 \code{c(bottom, left, top, right)} のベクトルで
	インチ単位の外部マージンのサイズを与える．}
	
    \item{\code{page}}{\emph{\bold{R.O.}};
	\code{\link{plot.new}} の次の呼び出しが新しいページを
	始めるかどうかを指示するブーリアン値．
	この値はもしページ上に複数の図があれば \code{FALSE}
	かもしれない．}
	
    \item{\code{pch}}{
      点のプロットで既定として使われるシンボルを指定する整数か
      単一の文字．可能な値とそれらの解釈は \code{\link{points}} を見よ．
      整数化単一文字のベクトルだけがグラフィカルパラメータとして
      設定できることを注意する(そして \code{NA} や \code{NULL} は使えない)．

      \code{\link{points}} の様なある種の関数はリサイクルされる値の
      ベクトルを受け入れる．
    }
    
    \item{\code{pin}}{インチ単位の現在のプロット次元 \code{(width, height)}．}
      
    \item{\code{plt}}{
      形式 \code{c(x1, x2, y1, y2)} のベクトルでプロット領域の座標を
      現在の図領域の割合で与える．}
      
    \item{\code{ps}}{整数；テキストのポイントサイズ(シンボルではない)．
      殆どのデバイスの \code{pointsize} 引数とは異なり，これは
      \code{mar} と \code{mai}の間
      の関係(\code{oma} と \code{omi} の間の関係も)を変更しない．

      \sQuote{ポイントサイズ}が意味するものはデバイス固有であるが，
      殆どのデバイスは 1bp を意味する，つまり 1/72 インチ．
    }
    
    \item{\code{pty}}{使用されるプロット領域のタイプを指定する文字列；
      \code{"s"} は正方形のプロット領域を，そして
      \code{"m"} は最大のプロット領域を作る．}
      
    \item{\code{smo}}{(\emph{未実装}) 円と円弧がどれだけ滑らかであるべきかを
      指示する値．}
      
    \item{\code{srt}}{度単位の文字列の回転．
      \code{crt} に関するコメントを見よ：
      \code{\link{text}} によってだけ設定される．
    }
    
    \item{\code{tck}}{
      プロット領域の幅もしくは高さの小さい方の割合としてのチックマークの長さ．
      もし \code{tck >= 0.5} ならこれは関連する側の割合と解釈されるので，
      例えば \code{tck = 1} ならばグリッド線が描かれる．
      既定の設定(\code{tck = NA})は \code{tcl = -0.5} を使う．}
      
    \item{\code{tcl}}{
      滝スト行の高さの割合としてのチックマークの長さ．
      既定値は \code{-0.5}；
      設定 \code{tcl = NA} は S の既定値である \code{tck = -0.01} を設定する．}
      
    \item{\code{usr}}{
      形式 \code{c(x1, x2, y1, y2)} のベクトルでプロット領域の
      ユーザ座標の極値を与える．
      対数スケールが使われていると(つまり \code{par("xlog")} が真，下を見よ)
      x の限界は \code{10 ^ par("usr")[1:2]} になる．
      y 軸に関しても同様である．
    }
    
    \item{\code{xaxp}}{
      A vector of the form
      形式 \code{c(x1, x2, n)} のベクトルで \code{par("xlog")} が偽の時
      端のチックマークの座標とチックマーク間の区間の数を与える．
      さもなければ，\emph{log} 座標がアクティブの時，三つの値は異なった
      意味を持つ：
      小さな範囲に対しては \code{n} は\emph{負}で，チックは線形の場合の
      様になる，さもなければ \code{n} は \code{1:3} でケースの数を指定し，
      そして \code{x1} と \code{x2} はユーザ座標内の最少と最大の10の巾乗である，
      \code{10 ^ par("usr")[1:2]}．
      (\code{"usr"} 座標はここで常用対数で変換されている!)

      \describe{
        \item{n = 1}{整数 \eqn{j} に対してチックマークを \eqn{10^j} に置く，}
        \item{n = 2}{マーク \eqn{k 10^j} を
	  \eqn{k \in \{1, 5\}}{k in {1,5}} に対して置く，}
        \item{n = 3}{マーク \eqn{k 10^j} を
	  \eqn{k \in \{1, 2, 5\}}{k in {1,2,5}} に対して置く．}
      }
      \R 純正のこれの移植については \code{\link{axTicks}()} を見よ．
      
      このパラメータはユーザ座標システムが設定された時リセットされる．
      例えば新しいページを開始したり，
      \code{\link{plot.window}} を呼び出したり，
      又は \code{par("usr")} の設定時である：
      \code{n} は \code{par("lab")} から取られる．
      これは側面 1 又は 3 に対する引き続く
      \code{\link{axis}} の呼び出しの既定挙動に影響する．

      これは既定の数値軸システムにだけ関係し，例えば日付には関係しない．
    }
    
    \item{\code{xaxs}}{
      x 軸に対して使われる軸区間計算のスタイル．
      可能な値は \code{"r"}, \code{"i"}, \code{"e"}, \code{"s"}, \code{"d"}．
      スタイルは一般に，もし与えられていれば，
      データもしくは \code{xlim} の範囲で制御される．\cr
      スタイル \code{"r"} (regular)は最初データ範囲を両端で4パーセント拡大し
      それから拡大範囲にフィットする見栄えの良いラベルを持つ軸を見出す．\cr
      スタイル \code{"i"} (internal)は単に本来の範囲にフィットする
      見栄えの良いラベルを持つ軸を見出す．\cr
      スタイル \code{"s"} (standard) はその内部に本来のデータ範囲が
      フィットする見栄えの良いラベルを持つ軸を見出す．\cr
      スタイル \code{"e"} (extended) はスタイル \code{"s"} に似るが，
      バウンディングボックス内部にシンボルのプロットのための
      余地があることをまた保証する点が異なる．\cr
      スタイル \code{"d"} (direct) は現在の軸が引き続くプロットで
      使われるべきことを指定する．\cr
      (\emph{スタイル \code{"r"} と \code{"i"} だけが \R に移植されてきている．})}
	
    \item{\code{xaxt}}{
      x 軸のタイプを指定する文字列．
      \code{"n"} の指定は軸のプロットを抑制する．
      標準値は \code{"s"}：
      S との一貫性から値
      \code{"l"} と \code{"t"} は受け入れられるが，
      \code{"s"} に同値である：
      \code{"n"} 以外の全ての値はプロットを意味する．}
      
    \item{\code{xlog}}{
      論理値(\code{\link{plot.default}} 中の \code{log} を見よ)．
      もし \code{TRUE} なら対数スケールが使われる
      (例えば \code{plot(*, log = "x")} の後)．
      新しいデバイスに対しては既定値は \code{FALSE}，つまり線形スケール．}
      
    \item{\code{xpd}}{
      論理値か \code{NA}．もし \code{FALSE} ならば，
      全てのプロットはプロット領域に切り詰められ，
      もし \code{TRUE} なら全てのプロットは図領域に切り詰められ，
      そしてもし \code{NA} なら全てのプロットはデバイス領域に
      切り詰められる．
      \code{\link{clip}} も見よ．}
      
    \item{\code{yaxp}}{
      形式 \code{c(y1, y2, n)} のベクトルで，対数軸以外で
      端にあるチックマークの座標とチックマーク間の区間数を
      与える．上の \code{xaxp} を見よ．}
      
    \item{\code{yaxs}}{y 軸に対して使われる軸区間計算のスタイル．
      上の \code{xaxs} を見よ．}
      
    \item{\code{yaxt}}{y 軸のタイプを指定する文字．
      \code{"n"} の指定はプロットを抑制する．}
      
    \item{\code{ylbias}}{
      テキストをマージンに配置するために
      \code{\link{axis}} と \code{\link{mtext}} に
      よって使われる正数．既定値は原則デバイス固有であるが，
      現在全ての \R 自体のデバイスでは \code{0.2} である．
      \code{x11} と \code{windows()} デバイス上の
      \R < 2.14.0 との一貫性のためにはこれを \code{0.2} に設定する．}
            
    \item{\code{ylog}}{論理値；上の \code{xlog} を見よ．}
  }
}

\section{色指定}{
  色は複数の異なった仕方で指定できる．最も簡単な方法は
  色名を与える文字列(例えば \code{"red"}) を使うことである．
  可能な色のリストは関数 \code{\link{colors}} で得られる．
  別法として，色は
  \code{"#RRGGBB"} の形式の文字列でそれらの RGB 成分を使って
  直接指定できる，ここで各対 \code{RR}, \code{GG},
  \code{BB} は範囲 \code{00} から \code{FF} までの16進数からなる．

  色は又小さな色のテーブル \code{\link{palette}} の添字を与えることで
  指定できる：添字は巡回されるので，既定のサイズ8のパレットでは
  \code{10} は \code{2} と同じである．
  これは S との互換性を提供する．
  添字 \code{0} は背景色に対応する．
  パレット(デバイス毎の \code{0} を除き)はセッション毎の設定である．

  負の整数色はエラーである．

  加えて，\code{"transparent"} は\emph{透明}で塗りつぶし領域
  (背景のような!)に対して有用で，線やテキストのようなものに
  対しては単に不可視である．
  殆どの状況(整数)で \code{NA} は \code{"transparent"}
  である(しかし \code{\link{text}} と \code{\link{mtext}} に対して
  は異なる)．

  半透明色はそれらをサポートするデバイス上で利用可能である．

  関数 \code{\link{rgb}}, \code{\link{hsv}}, \code{\link{hcl}},
  \code{\link{gray}} そして \code{\link{rainbow}} は色を生成する追加の
  方法を提供する．
}

\section{線種指定}{
  線種は少数の線種の組み込みテーブルの添字を指定する
  (1 = 実線, 2 = ダッシュ，等，上の \code{lty} を見よ)か，直接に
  適当な長さの線のオン・オフとして与えることが出来る．
  これは偶数(最大8)個の文字からなる文字列，つまり
  文字列中の引き続く位置中の長さを与える
  \emph{ゼロでない}(16進法の)数字である．
  例えば
  文字列 \code{"33"} は3単位の線分に3単位の空白が続くことを指示し，
  \code{"3313"} は
  3単位の線分に3単位の空白が続き，そして1単位の線分に3単位の空白が
  くことを指示する．
  ここで\sQuote{単位}とは(殆どのデバイスでは) \code{lwd} に比例し，
  \code{lwd = 1} ではピクセル単位又はポイント単位又は 1/96 インチである．

  五つの標準のダッシュとドットの線種(\code{lty = 2:6})は
  \code{c("44", "13", "1343", "73", "2262")} に対応する．

  \code{NA} は \code{lty} の適正な値ではない．
}

\note{
  デバイスのサイズが変更された時，例におけるような全ての(設定可能な)
  グラフィックスパラメータの回復の効果は予見しがたい．
  それらの幾つかは同じことを異なった仕方で設定しようとし，
  アルファベット順で最後のものが使われる．
  特に \code{mai}, \code{mar}, \code{pin}, \code{plt} そして
  \code{pty} の設定は，他のマージン設定，図のレイアウト，そして図領域サイズが
  そうするように，干渉しあう．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
}
\seealso{
  幾つかの高水準プロットパラメータ については \code{\link{plot.default}}；
  \code{\link{colors}}; \code{\link{clip}};
  他の設定用パラメータについては \code{\link{options}}；
  グラフィックデバイス \code{\link{x11}}, \code{\link{postscript}} そして
  デバイス領域の設定は \code{\link{layout}} と \code{\link{split.screen}}．
}

\examples{
op <- par(mfrow = c(2, 2), # 一つのプロットに 2 x 2 図
          pty = "s")       # 正方形のプロット領域
                           # デバイスサイズとは独立

## プロットの最後に以前の設定にリセット：
par(op)

## 別法
op <- par(no.readonly = TRUE) # 設定可能な全てのパラメータのリスト．
## たくさんのプロットと par(.) 呼び出し，そしてリセット：
par(op)
## これは一般に良い作法ではないことを注意する

par("ylog") # FALSE
plot(1 : 12, log = "y")
par("ylog") # TRUE

plot(1:2, xaxs = "i") # 外部余白の内部/外部の '内部的軸'
par(c("usr", "xaxp"))

( nr.prof <-
c(prof.pilots = 16, lawyers = 11, farmers = 10, salesmen = 9, physicians = 9,
  mechanics = 6, policemen = 6, managers = 6, engineers = 5, teachers = 4,
  housewives = 3, students = 3, armed.forces = 1))
par(las = 3)
barplot(rbind(nr.prof)) # R 0.63.2: 並べ方に問題
par(las = 0)  # 既定値にリセット

require(grDevices) # 灰色のため
## 'fg' の使用：
plot(1:12, type = "b", main = "'fg' : axes, ticks and box in gray",
     fg = gray(0.7), bty = "7" , sub = R.version.string)

ex <- function() {
   old.par <- par(no.readonly = TRUE) # 変更可能な全ての par 設定
   on.exit(par(old.par))
   ## ...
   ## ... 多数の par() 設定とプロット
   ## ...
   invisible() #-- 今や par(old.par) が実行される
}
ex()

## 線種
showLty <- function(ltys, xoff = 0, ...) {
   stopifnot((n <- length(ltys)) >= 1)
   op <- par(mar = rep(.5,4)); on.exit(par(op))
   plot(0:1, 0:1, type = "n", axes = FALSE, ann = FALSE)
   y <- (n:1)/(n+1)
   clty <- as.character(ltys)
   mytext <- function(x, y, txt)
      text(x, y, txt, adj = c(0, -.3), cex = 0.8, ...)
   abline(h = y, lty = ltys, ...); mytext(xoff, y, clty)
   y <- y - 1/(3*(n+1))
   abline(h = y, lty = ltys, lwd = 2, ...)
   mytext(1/8+xoff, y, paste(clty," lwd = 2"))
}
showLty(c("solid", "dashed", "dotted", "dotdash", "longdash", "twodash"))
par(new = TRUE)  # the same:
showLty(c("solid", "44", "13", "1343", "73", "2262"), xoff = .2, col = 2)
showLty(c("11", "22", "33", "44",   "12", "13", "14",   "21", "31"))
}
\keyword{iplot}
\keyword{dplot}
\keyword{environment}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/par.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{par}
%\alias{par}
%\alias{.Pars}
%\concept{adj}
%\concept{ann}
%\concept{ask}
%\concept{bg}
%\concept{bty}
%\concept{cex.axis}
%\concept{cex.lab}
%\concept{cex.main}
%\concept{cex.sub}
%\concept{cex}
%\concept{cin}
%\concept{col.axis}
%\concept{col.lab}
%\concept{col.main}
%\concept{col.sub}
%\concept{col}
%\concept{cra}
%\concept{crt}
%\concept{csi}
%\concept{cxy}
%\concept{din}
%\concept{err}
%\concept{family}
%\concept{fg}
%\concept{fig}
%\concept{fin}
%\concept{font.axis}
%\concept{font.lab}
%\concept{font.main}
%\concept{font.sub}
%\concept{font}
%\concept{lab}
%\concept{las}
%\concept{lend}
%\concept{lheight}
%\concept{ljoin}
%\concept{lmitre}
%\concept{lty}
%\concept{lwd}
%\concept{mai}
%\concept{mar}
%\concept{mex}
%\concept{mfcol}
%\concept{mfg}
%\concept{mfrow}
%\concept{mgp}
%\concept{mkh}
%\concept{new}
%\concept{oma}
%\concept{omd}
%\concept{omi}
%\concept{page}
%\concept{pch}
%\concept{pin}
%\concept{plt}
%\concept{ps}
%\concept{pty}
%\concept{smo}
%\concept{srt}
%\concept{tck}
%\concept{tcl}
%\concept{usr}
%\concept{xaxp}
%\concept{xaxs}
%\concept{xaxt}
%\concept{xlog}
%\concept{xpd}
%\concept{yaxp}
%\concept{yaxs}
%\concept{yaxt}
%\concept{ylog}
%\concept{color}
%\concept{colour}
%\alias{graphical parameter}
%\alias{graphical parameters}
%
%\title{Set or Query Graphical Parameters}
%
%%% The 'real documentation' is the code in ../../../main/par.c
%%% AND (defined AND commented)          in ../../../include/Graphics.h
%%% Default initialization by GInit()    in ../../../main/graphics.c
%
%\description{
%  \code{par} can be used to set or query graphical parameters.
%  Parameters can be set by specifying them as arguments to \code{par} in
%  \code{tag = value} form, or by passing them as a list of tagged
%  values.
%}
%\usage{
%par(\dots, no.readonly = FALSE)
%
%\special{<highlevel plot> (..., <tag> = <value>)}
%}
%
%\arguments{
%  \item{\dots}{arguments in \code{tag = value} form, or a list of tagged
%    values.  The tags must come from the names of graphical parameters
%    described in the \sQuote{Graphical Parameters} section.}
%  \item{no.readonly}{logical; if \code{TRUE} and there are no other
%    arguments, only parameters are returned which can be set by a
%    subsequent \code{par()} call \emph{on the same device}.}
%}
%
%\details{
%  Each device has its own set of graphical parameters.  If the current
%  device is the null device, \code{par} will open a new device before
%  querying/setting parameters.  (What device is controlled by
%  \code{\link{options}("device")}.)
%
%  Parameters are queried by giving one or more character vectors of
%  parameter names to \code{par}.
%
%  \code{par()} (no arguments) or \code{par(no.readonly = TRUE)} is used to
%  get \emph{all} the graphical parameters (as a named list).  Their
%  names are currently taken from the unexported variable
%  \code{graphics:::.Pars}.
%
%  \emph{\bold{R.O.}} indicates \emph{\bold{read-only arguments}}: These
%  may only be used in queries and cannot be set.  (\code{"cin"},
%  \code{"cra"}, \code{"csi"}, \code{"cxy"}, \code{"din"} and
%  \code{"page"} are always read-only.)
%
%  Several parameters can only be set by a call to \code{par()}:
%  \itemize{
%    \item \code{"ask"},
%    \item \code{"fig"}, \code{"fin"},
%    \item \code{"lheight"},
%    \item \code{"mai"}, \code{"mar"}, \code{"mex"},
%    \code{"mfcol"}, \code{"mfrow"}, \code{"mfg"},
%    \item \code{"new"},
%    \item \code{"oma"}, \code{"omd"}, \code{"omi"},
%    \item \code{"pin"}, \code{"plt"}, \code{"ps"}, \code{"pty"},
%    \item \code{"usr"},
%    \item \code{"xlog"}, \code{"ylog"},
%    \item \code{"ylbias"}
%  }
%  The remaining parameters can also be set as arguments (often via
%  \code{\dots}) to high-level plot functions such as
%  \code{\link{plot.default}}, \code{\link{plot.window}},
%  \code{\link{points}}, \code{\link{lines}}, \code{\link{abline}},
%  \code{\link{axis}}, \code{\link{title}}, \code{\link{text}},
%  \code{\link{mtext}}, \code{\link{segments}}, \code{\link{symbols}},
%  \code{\link{arrows}}, \code{\link{polygon}}, \code{\link{rect}},
%  \code{\link{box}}, \code{\link{contour}}, \code{\link{filled.contour}}
%  and \code{\link{image}}.  Such settings will be active during the
%  execution of the function, only.  However, see the comments on
%  \code{bg}, \code{cex}, \code{col}, \code{lty}, \code{lwd} and
%  \code{pch} which may be taken as \emph{arguments} to certain plot
%  functions rather than as graphical parameters.
%
%  The meaning of \sQuote{character size} is not well-defined: this is
%  set up for the device taking \code{pointsize} into account but often
%  not the actual font family in use.  Internally the corresponding pars
%  (\code{cra}, \code{cin}, \code{cxy} and \code{csi}) are used only to
%  set the inter-line spacing used to convert \code{mar} and \code{oma}
%  to physical margins.  (The same inter-line spacing multiplied by
%  \code{lheight} is used for multi-line strings in \code{text} and
%  \code{strheight}.)
%
%  Note that graphical parameters are suggestions: plotting functions and
%  devices need not make use of them (and this is particularly true of
%  non-default methods for e.g.\sspace{}\code{plot}).
%}
%
%\value{
%  When parameters are set, their previous values are returned in an
%  invisible named list.  Such a list can be passed as an argument to
%  \code{par} to restore the parameter values.  Use \code{par(no.readonly
%  = TRUE)} for the full list of parameters that can be restored.
%  However, restoring all of these is not wise: see the \sQuote{Note}
%  section.
%
%  When just one parameter is queried, the value of that parameter
%  is returned as (atomic) vector.  When two or more parameters are
%  queried, their values are returned in a list, with the list names
%  giving the parameters.
%
%  Note the inconsistency: setting one parameter returns a list, but
%  querying one parameter returns a vector.
%}
%
%\section{Graphical Parameters}{
%  \describe{
%    \item{\code{adj}}{The value of \code{adj} determines the way in
%      which text strings are justified in \code{\link{text}},
%      \code{\link{mtext}} and \code{\link{title}}.  A value of \code{0} produces
%      left-justified text, \code{0.5} (the default) centered text and \code{1}
%      right-justified text.  (Any value in \eqn{[0, 1]} is allowed, and
%      on most devices values outside that interval will also work.)
%
%      Note that the \code{adj} \emph{argument} of \code{\link{text}} also
%      allows \code{adj = c(x, y)} for different adjustment in x- and y-
%      directions.  Note that whereas for \code{text} it refers to
%      positioning of text about a point, for \code{mtext} and
%      \code{title} it controls placement within the plot or device region.}
%    \item{\code{ann}}{If set to \code{FALSE}, high-level plotting
%      functions calling \code{\link{plot.default}} do not annotate the
%      plots they produce with axis titles and overall titles.  The
%      default is to do annotation.}
%    \item{\code{ask}}{logical.  If \code{TRUE} (and the \R session is
%      interactive) the user is asked for input, before a new figure is
%      drawn.  As this applies to the device, it also affects output by
%      packages \pkg{grid} and \CRANpkg{lattice}.  It can be set even on
%      non-screen devices but may have no effect there.
%
%      This not really a graphics parameter, and its use is deprecated in
%      favour of \code{\link{devAskNewPage}}.
%    }
%    \item{\code{bg}}{The color to be used for the background of the
%      device region.  When called from \code{par()} it also sets
%      \code{new = FALSE}. See section \sQuote{Color Specification} for
%      suitable values.  For many devices the initial value is set from
%      the \code{bg} argument of the device, and for the rest it is
%      normally \code{"white"}.
%
%      Note that some graphics functions such as
%      \code{\link{plot.default}} and \code{\link{points}} have an
%      \emph{argument} of this name with a different meaning.}
%    \item{\code{bty}}{A character string which determined the type of
%      \code{\link{box}} which is drawn about plots.  If \code{bty} is
%      one of \code{"o"} (the default), \code{"l"}, \code{"7"},
%      \code{"c"}, \code{"u"}, or \code{"]"} the resulting box resembles
%      the corresponding upper case letter.  A value of \code{"n"}
%      suppresses the box.}
%    \item{\code{cex}}{A numerical value giving the amount by which
%      plotting text and symbols should be magnified relative to the
%      default.  This starts as \code{1} when a device is opened, and is
%      reset when the layout is changed, e.g.\sspace{}by setting \code{mfrow}.
%
%      Note that some graphics functions such as
%      \code{\link{plot.default}} have an \emph{argument} of this name
%      which \emph{multiplies} this graphical parameter, and some
%      functions such as \code{\link{points}} and \code{\link{text}}
%      accept a vector of values which are recycled.
%    }
%    \item{\code{cex.axis}}{The magnification to be used for axis
%      annotation relative to the current setting of \code{cex}.}
%    \item{\code{cex.lab}}{The magnification to be used for x and y
%      labels relative to the current setting of \code{cex}.}
%    \item{\code{cex.main}}{The magnification to be used for main titles
%      relative to the current setting of \code{cex}.}
%    \item{\code{cex.sub}}{The magnification to be used for sub-titles
%      relative to the current setting of \code{cex}.}
%    \item{\code{cin}}{\emph{\bold{R.O.}}; character size
%      \code{(width, height)} in inches.  These are the same measurements
%      as \code{cra}, expressed in different units.}
%    \item{\code{col}}{A specification for the default plotting color.  See
%      section \sQuote{Color Specification}.
%
%      Some functions such as \code{\link{lines}} and \code{\link{text}}
%      accept a vector of values which are recycled and may be
%      interpreted slightly differently.
%    }
%    \item{\code{col.axis}}{The color to be used for axis
%      annotation.  Defaults to \code{"black"}.}
%    \item{\code{col.lab}}{The color to be used for x and y labels.
%      Defaults to \code{"black"}.}
%    \item{\code{col.main}}{The color to be used for plot main titles.
%      Defaults to \code{"black"}.}
%    \item{\code{col.sub}}{The color to be used for plot sub-titles.
%      Defaults to \code{"black"}.}
%    \item{\code{cra}}{\emph{\bold{R.O.}}; size of default character
%      \code{(width, height)} in \sQuote{rasters} (pixels).  Some devices
%      have no concept of pixels and so assume an arbitrary pixel size,
%      usually 1/72 inch.  These are the same measurements
%      as \code{cin}, expressed in different units.}
%    \item{\code{crt}}{A numerical value specifying (in degrees) how
%      single characters should be rotated.  It is unwise to expect
%      values other than multiples of 90 to work.  Compare with
%      \code{srt} which does string rotation.}
%    \item{\code{csi}}{\emph{\bold{R.O.}}; height of (default-sized)
%      characters in inches.  The same as \code{par("cin")[2]}.}
%    \item{\code{cxy}}{\emph{\bold{R.O.}}; size of default character
%      \code{(width, height)} in user coordinate units.
%      \code{par("cxy")} is \code{par("cin")/par("pin")} scaled to user
%      coordinates.
%      Note that \code{c(\link{strwidth}(ch), \link{strheight}(ch))} for
%      a given string \code{ch} is usually much more precise.}
%    \item{\code{din}}{\emph{\bold{R.O.}}; the device dimensions,
%      \code{(width, height)}, in inches.  See also
%      \code{\link{dev.size}}, which is updated immediately when an
%      on-screen device windows is re-sized.}
%    \item{\code{err}}{(\emph{Unimplemented}; \R is silent when points
%      outside the plot region are \emph{not} plotted.)
%      The degree of error reporting desired.}
%    \item{\code{family}}{The name of a font family for drawing text.
%      The maximum allowed length is 200 bytes.
%      This name gets mapped by each graphics device to a device-specific
%      font description.  The default value is \code{""} which means that
%      the default device fonts will be used (and what those are should
%      be listed on the help page for the device).  Standard values are
%      \code{"serif"}, \code{"sans"} and \code{"mono"}, and the
%      \link{Hershey} font families are also available.  (Devices may
%      define others, and some devices will ignore this setting
%      completely.  Names starting with \code{"Hershey"} are treated
%      specially and should only be used for the built-in Hershey font
%      families.)  This can be specified inline for \code{\link{text}}.}
%    \item{\code{fg}}{The color to be used for the foreground of plots.
%      This is the default color used for things like axes and boxes
%      around plots.  When called from \code{par()} this also sets
%      parameter \code{col} to the same value.  See section \sQuote{Color
%        Specification}.  A few devices have an argument to set the
%      initial value, which is otherwise \code{"black"}.}
%    \item{\code{fig}}{A numerical vector of the form \code{c(x1, x2, y1,
%        y2)} which gives the (NDC) coordinates of the figure region in
%      the display region of the device. If you set this, unlike S, you
%      start a new plot, so to add to an existing plot use
%      \code{new = TRUE} as well.}
%    \item{\code{fin}}{The figure region dimensions,
%      \code{(width, height)}, in inches. If you set this, unlike S, you
%      start a new plot.}
%    \item{\code{font}}{An integer which specifies which font to use for
%      text.  If possible, device drivers arrange so that 1 corresponds
%      to plain text (the default), 2 to bold face, 3 to italic and 4 to
%      bold italic.  Also, font 5 is expected to be the symbol font, in
%      Adobe symbol encoding.  On some devices font families can be
%      selected by \code{family} to choose different sets of 5 fonts.}
%    \item{\code{font.axis}}{The font to be used for axis annotation.}
%    \item{\code{font.lab}}{The font to be used for x and y labels.}
%    \item{\code{font.main}}{The font to be used for plot main titles.}
%    \item{\code{font.sub}}{The font to be used for plot sub-titles.}
%    \item{\code{lab}}{A numerical vector of the form \code{c(x, y, len)}
%      which modifies the default way that axes are annotated.  The values of
%      \code{x} and \code{y} give the (approximate) number of tickmarks
%      on the x and y axes and \code{len} specifies the label length.  The
%      default is \code{c(5, 5, 7)}.  Note that this only affects the way
%      the parameters \code{xaxp} and \code{yaxp} are set when the user
%      coordinate system is set up, and is not consulted when axes are drawn.
%      \code{len} \emph{is unimplemented} in \R.}
%    \item{\code{las}}{numeric in \{0,1,2,3\}; the style of axis labels.
%      \describe{
%        \item{0:}{always parallel to the axis [\emph{default}],}
%        \item{1:}{always horizontal,}
%        \item{2:}{always perpendicular to the axis,}
%        \item{3:}{always vertical.}
%      }
%      Also supported by \code{\link{mtext}}.  Note that
%      string/character rotation \emph{via} argument \code{srt} to \code{par}
%      does \emph{not} affect the axis labels.
%    }
%    \item{\code{lend}}{The line end style.  This can be specified as an
%      integer or string:
%      \describe{
%        \item{\code{0}}{and \code{"round"} mean rounded line caps
%          [\emph{default}];}
%        \item{\code{1}}{and \code{"butt"} mean butt line caps;}
%        \item{\code{2}}{and \code{"square"} mean square line caps.}
%      }
%    }
%    \item{\code{lheight}}{The line height multiplier.
%      The height of a line of text (used to vertically space
%      multi-line text) is found by multiplying the character height
%      both by the current character expansion and by the
%      line height multiplier.  Default value is 1.  Used in
%      \code{\link{text}} and \code{\link{strheight}}.}
%    \item{\code{ljoin}}{The line join style.
%      This can be specified as an integer or string:
%      \describe{
%        \item{\code{0}}{and \code{"round"} mean rounded line joins
%          [\emph{default}];}
%        \item{\code{1}}{and \code{"mitre"} mean mitred line joins;}
%        \item{\code{2}}{and \code{"bevel"} mean bevelled line joins.}
%      }
%    }
%    \item{\code{lmitre}}{The line mitre limit.  This controls when
%      mitred line joins are automatically converted into bevelled line
%      joins.  The value must be larger than 1 and the default is 10.
%      Not all devices will honour this setting.}
%    \item{\code{lty}}{The line type.
%      Line types can either be specified as an integer (0=blank, 1=solid
%      (default), 2=dashed, 3=dotted, 4=dotdash, 5=longdash, 6=twodash)
%      or as one of the character strings \code{"blank"}, \code{"solid"},
%      \code{"dashed"}, \code{"dotted"}, \code{"dotdash"},
%      \code{"longdash"}, or \code{"twodash"}, where \code{"blank"} uses
%      \sQuote{invisible lines} (i.e., does not draw them).
%
%      Alternatively, a string of up to 8 characters (from \code{c(1:9,
%        "A":"F")}) may be given, giving the length of line segments
%      which are alternatively drawn and skipped.  See section
%      \sQuote{Line Type Specification}.
%
%      Functions such as \code{\link{lines}} and \code{\link{segments}}
%      accept a vector of values which are recycled.
%    }
%    \item{\code{lwd}}{The line width, a \emph{positive} number,
%      defaulting to \code{1}.  The interpretation is device-specific,
%      and some devices do not implement line widths less than one.
%      (See the help on the device for details of the interpretation.)
%
%      Functions such as \code{\link{lines}} and \code{\link{segments}}
%      accept a vector of values which are recycled: in such uses lines
%      corresponding to values \code{NA} or \code{NaN} are omitted.  The
%      interpretation of \code{0} is device-specific.
%    }
%    \item{\code{mai}}{A numerical vector of the form \code{c(bottom,
%        left, top, right)} which gives the margin size specified in
%      inches.\cr
%      \if{html}{\figure{mai.png}{options: width="35\%" alt="Figure: mai.png"}}
%      \if{latex}{\figure{mai.pdf}{options: width=7cm}}
%    }
%    \item{\code{mar}}{A numerical vector of the form \code{c(bottom,
%        left, top, right)} which gives the number of lines of margin to be
%      specified on the four sides of the plot.
%      The default is \code{c(5, 4, 4, 2) + 0.1}.}
%    \item{\code{mex}}{
%      \code{mex} is a character size expansion factor which is used to
%      describe coordinates in the margins of plots. Note that this does
%      not change the font size, rather specifies the size of font (as a
%      multiple of \code{csi}) used to convert between \code{mar} and
%      \code{mai}, and between \code{oma} and \code{omi}.
%
%      This starts as \code{1} when the device is opened, and is reset
%      when the layout is changed (alongside resetting \code{cex}).
%    }
%    \item{\code{mfcol, mfrow}}{A vector of the form \code{c(nr, nc)}.
%      Subsequent figures will be drawn in an \code{nr}-by-\code{nc}
%      array on the device by \emph{columns} (\code{mfcol}), or
%      \emph{rows} (\code{mfrow}), respectively.
%
%      In a layout with exactly two rows and columns the base value of
%      \code{"cex"} is reduced by a factor of 0.83: if there are three or
%      more of either rows or columns, the reduction factor is 0.66.
%
%      Setting a layout resets the base value of \code{cex} and that of
%      \code{mex} to \code{1}.
%
%      If either of these is queried it will give the current layout, so
%      querying cannot tell you the order in which the array will be filled.
%
%      Consider the alternatives, \code{\link{layout}} and
%      \code{\link{split.screen}}.
%    }
%    \item{\code{mfg}}{A numerical vector of the form \code{c(i, j)}
%      where \code{i} and \code{j} indicate which figure in an array of
%      figures is to be drawn next (if setting) or is being drawn (if
%      enquiring).  The array must already have been set by \code{mfcol}
%      or \code{mfrow}.
%
%      For compatibility with S, the form \code{c(i, j, nr, nc)} is also
%      accepted, when \code{nr} and \code{nc} should be the current
%      number of rows and number of columns.  Mismatches will be ignored,
%      with a warning.}
%    \item{\code{mgp}}{The margin line (in \code{mex} units) for the axis
%      title, axis labels and axis line.  Note that \code{mgp[1]} affects
%      \code{\link{title}} whereas \code{mgp[2:3]} affect \code{\link{axis}}.
%      The default is \code{c(3, 1, 0)}.}
%    \item{\code{mkh}}{The height in inches of symbols to be drawn when
%      the value of \code{pch} is an integer. \emph{Completely ignored in \R}.
%    }
%    \item{\code{new}}{logical, defaulting to \code{FALSE}.  If set to
%      \code{TRUE}, the next high-level plotting command (actually
%      \code{\link{plot.new}}) should \emph{not clean} the frame before
%      drawing \emph{as if it were on a \bold{\emph{new}} device}.  It is
%      an error (ignored with a warning) to try to use \code{new = TRUE}
%      on a device that does not currently contain a high-level plot.}
%    \item{\code{oma}}{A vector of the form \code{c(bottom, left, top,
%        right)} giving the size of the outer margins in lines of text.\cr
%      \if{html}{\figure{oma.png}{options: width="25\%" alt="Figure: oma.png"}}
%      \if{latex}{\figure{oma.pdf}{options: width=6cm}}
%    }
%    \item{\code{omd}}{A vector of the form \code{c(x1, x2, y1, y2)}
%      giving the region \emph{inside} outer margins in NDC (=
%      normalized device coordinates), i.e., as a fraction (in \eqn{[0, 1]})
%      of the device region.}
%    \item{\code{omi}}{A vector of the form \code{c(bottom, left, top,
%        right)} giving the size of the outer margins in inches.}
%    \item{\code{page}}{\emph{\bold{R.O.}}; A boolean value indicating
%        whether the next call to \code{\link{plot.new}} is going
%        to start a new page.  This value may be \code{FALSE} if there
%        are multiple figures on the page.}
%    \item{\code{pch}}{Either an integer specifying a symbol or a single
%      character to be used as the default in plotting points.  See
%      \code{\link{points}} for possible values and their interpretation.
%      Note that only integers and single-character strings can
%      be set as a graphics parameter (and not \code{NA} nor \code{NULL}).
%
%      Some functions such as \code{\link{points}} accept a vector of values
%      which are recycled.
%    }
%    \item{\code{pin}}{The current plot dimensions, \code{(width, height)},
%      in inches.}
%    \item{\code{plt}}{A vector of the form \code{c(x1, x2, y1, y2)}
%      giving the coordinates of the plot region as fractions of the
%      current figure region.}
%    \item{\code{ps}}{integer; the point size of text (but not symbols).  Unlike
%      the \code{pointsize} argument of most devices, this does not change
%      the relationship between \code{mar} and \code{mai} (nor \code{oma}
%      and \code{omi}).
%
%      What is meant by \sQuote{point size} is device-specific, but most
%      devices mean a multiple of 1bp, that is 1/72 of an inch.
%    }
%    \item{\code{pty}}{A character specifying the type of plot region to
%      be used; \code{"s"} generates a square plotting region and
%      \code{"m"} generates the maximal plotting region.}
%    \item{\code{smo}}{(\emph{Unimplemented}) a value which indicates how
%      smooth circles and circular arcs should be.}
%    \item{\code{srt}}{The string rotation in degrees.  See the comment
%      about \code{crt}.  Only supported by \code{\link{text}}.
%      %% NOT true for R (but for S): Causes \code{srt} to be set to the
%      %% same value. ?? Is `crt' meant here ??
%    }
%    \item{\code{tck}}{The length of tick marks as a fraction of the
%      smaller of the width or height of the plotting region.
%      If \code{tck >= 0.5} it is interpreted as a fraction of the
%      relevant side, so if \code{tck = 1} grid lines are drawn.  The
%      default setting (\code{tck = NA}) is to use \code{tcl = -0.5}.}
%    \item{\code{tcl}}{The length of tick marks as a fraction of the
%      height of a line of text.  The default value is \code{-0.5};
%      setting \code{tcl = NA} sets \code{tck = -0.01} which is S' default.}
%    \item{\code{usr}}{A vector of the form \code{c(x1, x2, y1, y2)}
%      giving the extremes of the user coordinates of the plotting
%      region.  When a logarithmic scale is in use (i.e.,
%      \code{par("xlog")} is true, see below), then the x-limits will be
%      \code{10 ^ par("usr")[1:2]}.  Similarly for the y-axis.
%    }
%    \item{\code{xaxp}}{A vector of the form \code{c(x1, x2, n)} giving
%      the coordinates of the extreme tick marks and the number of
%      intervals between tick-marks when \code{par("xlog")} is false.
%      Otherwise, when \emph{log} coordinates are active, the three
%      values have a different meaning: For a small range, \code{n} is
%      \emph{negative}, and the ticks are as in the linear case,
%      otherwise, \code{n} is in \code{1:3}, specifying a case number,
%      and \code{x1} and \code{x2} are the lowest and highest power of 10
%      inside the user coordinates, \code{10 ^ par("usr")[1:2]}. (The
%      \code{"usr"} coordinates are log10-transformed here!)
%
%      \describe{
%        \item{n = 1}{will produce tick marks at \eqn{10^j} for integer \eqn{j},}
%        \item{n = 2}{gives marks  \eqn{k 10^j} with
%	  \eqn{k \in \{1, 5\}}{k in {1,5}},}
%        \item{n = 3}{gives marks  \eqn{k 10^j} with
%	  \eqn{k \in \{1, 2, 5\}}{k in {1,2,5}}.}
%      }
%      See \code{\link{axTicks}()} for a pure \R implementation of this.
%
%      This parameter is reset when a user coordinate system is set up,
%      for example by starting a new page or by calling
%      \code{\link{plot.window}} or setting \code{par("usr")}: \code{n}
%      is taken from \code{par("lab")}.  It affects the default behaviour
%      of subsequent calls to \code{\link{axis}} for sides 1 or 3.
%
%      It is only relevant to default numeric axis systems, and not for
%      example to dates.
%    }
%    \item{\code{xaxs}}{The style of axis interval calculation to be used
%      for the x-axis.  Possible values are \code{"r"}, \code{"i"},
%      \code{"e"}, \code{"s"}, \code{"d"}.  The styles are generally
%      controlled by the range of data or \code{xlim}, if given.\cr
%      Style \code{"r"} (regular) first extends the data range by 4
%      percent at each end and then finds an axis with pretty labels
%      that fits within the extended range.\cr
%      Style \code{"i"} (internal) just finds an axis with pretty labels
%      that fits within the original data range.\cr
%      Style \code{"s"} (standard) finds an axis with pretty labels
%      within which the original data range fits.\cr
%      Style \code{"e"} (extended) is like style \code{"s"}, except that
%      it is also ensures that there is room for plotting symbols within
%      the bounding box.\cr
%      Style \code{"d"} (direct) specifies that the current axis should
%      be used on subsequent plots.\cr
%      (\emph{Only \code{"r"} and \code{"i"} styles have been
%        implemented in \R.})}
%    \item{\code{xaxt}}{A character which specifies the x axis type.
%      Specifying \code{"n"} suppresses plotting of the axis.  The
%      standard value is \code{"s"}: for compatibility with S values
%      \code{"l"} and \code{"t"} are accepted but are equivalent to
%      \code{"s"}: any value other than \code{"n"} implies plotting.}
%    \item{\code{xlog}}{A logical value (see \code{log} in
%      \code{\link{plot.default}}).  If \code{TRUE}, a logarithmic scale
%      is in use (e.g., after \code{plot(*, log = "x")}).
%      For a new device, it defaults to \code{FALSE}, i.e., linear scale.}
%    \item{\code{xpd}}{A logical value or \code{NA}.
%      If \code{FALSE}, all plotting is clipped to the plot region, if
%      \code{TRUE}, all plotting is clipped to the figure region, and if
%      \code{NA}, all plotting is clipped to the device region.  See also
%      \code{\link{clip}}.}
%    \item{\code{yaxp}}{A vector of the form \code{c(y1, y2, n)} giving
%      the coordinates of the extreme tick marks and the number of
%      intervals between tick-marks unless for log coordinates, see
%      \code{xaxp} above.}
%    \item{\code{yaxs}}{The style of axis interval calculation to be used
%      for the y-axis.  See \code{xaxs} above.}
%    \item{\code{yaxt}}{A character which specifies the y axis type.
%      Specifying \code{"n"} suppresses plotting.}
%    \item{\code{ylbias}}{A positive real value used in the positioning
%      of text in the margins by \code{\link{axis}} and
%      \code{\link{mtext}}.  The default is in principle device-specific,
%      but currently \code{0.2} for all of \R's own devices.  Set this to
%      \code{0.2} for compatibility with \R < 2.14.0 on \code{x11} and
%      \code{windows()} devices.}
%    \item{\code{ylog}}{A logical value; see \code{xlog} above.}
%  }
%}
%
%\section{Color Specification}{
%  Colors can be specified in several different ways. The simplest way is
%  with a character string giving the color name (e.g., \code{"red"}).  A
%  list of the possible colors can be obtained with the function
%  \code{\link{colors}}.  Alternatively, colors can be specified directly
%  in terms of their RGB components with a string of the form
%  \code{"#RRGGBB"} where each of the pairs \code{RR}, \code{GG},
%  \code{BB} consist of two hexadecimal digits giving a value in the
%  range \code{00} to \code{FF}.  Colors can also be specified by giving
%  an index into a small table of colors, the \code{\link{palette}}:
%  indices wrap round so with the default palette of size 8, \code{10} is
%  the same as \code{2}.  This provides compatibility with S.  Index
%  \code{0} corresponds to the background color.  Note that the palette
%  (apart from \code{0} which is per-device) is a per-session setting.
%
%  Negative integer colours are errors.
%
%  Additionally, \code{"transparent"} is \emph{transparent}, useful for
%  filled areas (such as the background!), and just invisible for things
%  like lines or text.  In most circumstances (integer) \code{NA}
%  is equivalent to \code{"transparent"} (but not for
%  \code{\link{text}} and \code{\link{mtext}}).
%
%  Semi-transparent colors are available for use on devices that support
%  them.
%
%  The functions \code{\link{rgb}}, \code{\link{hsv}}, \code{\link{hcl}},
%  \code{\link{gray}} and \code{\link{rainbow}} provide additional ways
%  of generating colors.
%}
%
%\section{Line Type Specification}{
%  Line types can either be specified by giving an index into a small
%  built-in table of line types (1 = solid, 2 = dashed, etc, see
%  \code{lty} above) or directly as the lengths of on/off stretches of
%  line.  This is done with a string of an even number (up to eight)
%  of characters, namely \emph{non-zero}
%  (hexadecimal) digits which give the lengths in consecutive positions
%  in the string.  For example, the string \code{"33"} specifies three
%  units on followed by three off and \code{"3313"} specifies three units
%  on followed by three off followed by one on and finally three off.
%  The \sQuote{units} here are (on most devices) proportional to
%  \code{lwd}, and with \code{lwd = 1} are in pixels or points or 1/96
%  inch.
%
%  The five standard dash-dot line types (\code{lty = 2:6}) correspond to
%  \code{c("44", "13", "1343", "73", "2262")}.
%
%  Note that \code{NA} is not a valid value for \code{lty}.
%}
%
%\note{
%  The effect of restoring all the (settable) graphics parameters as
%  in the examples is hard to predict if the device has been resized.
%  Several of them are attempting to set the same things in different
%  ways, and those last in the alphabet will win.  In particular, the
%  settings of \code{mai}, \code{mar}, \code{pin}, \code{plt} and
%  \code{pty} interact, as do the outer margin settings, the figure
%  layout and figure region size.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%}
%\seealso{
%  \code{\link{plot.default}} for some high-level plotting parameters;
%  \code{\link{colors}}; \code{\link{clip}};
%  \code{\link{options}} for other setup parameters;
%  graphic devices \code{\link{x11}}, \code{\link{postscript}} and
%  setting up device regions by \code{\link{layout}} and
%  \code{\link{split.screen}}.
%}
%
%\examples{
%op <- par(mfrow = c(2, 2), # 2 x 2 pictures on one plot
%          pty = "s")       # square plotting region,
%                           # independent of device size
%
%## At end of plotting, reset to previous settings:
%par(op)
%
%## Alternatively,
%op <- par(no.readonly = TRUE) # the whole list of settable par's.
%## do lots of plotting and par(.) calls, then reset:
%par(op)
%## Note this is not in general good practice
%
%par("ylog") # FALSE
%plot(1 : 12, log = "y")
%par("ylog") # TRUE
%
%plot(1:2, xaxs = "i") # 'inner axis' w/o extra space
%par(c("usr", "xaxp"))
%
%( nr.prof <-
%c(prof.pilots = 16, lawyers = 11, farmers = 10, salesmen = 9, physicians = 9,
%  mechanics = 6, policemen = 6, managers = 6, engineers = 5, teachers = 4,
%  housewives = 3, students = 3, armed.forces = 1))
%par(las = 3)
%barplot(rbind(nr.prof)) # R 0.63.2: shows alignment problem
%par(las = 0)  # reset to default
%
%require(grDevices) # for gray
%## 'fg' use:
%plot(1:12, type = "b", main = "'fg' : axes, ticks and box in gray",
%     fg = gray(0.7), bty = "7" , sub = R.version.string)
%
%ex <- function() {
%   old.par <- par(no.readonly = TRUE) # all par settings which
%                                      # could be changed.
%   on.exit(par(old.par))
%   ## ...
%   ## ... do lots of par() settings and plots
%   ## ...
%   invisible() #-- now,  par(old.par)  will be executed
%}
%ex()
%
%## Line types
%showLty <- function(ltys, xoff = 0, ...) {
%   stopifnot((n <- length(ltys)) >= 1)
%   op <- par(mar = rep(.5,4)); on.exit(par(op))
%   plot(0:1, 0:1, type = "n", axes = FALSE, ann = FALSE)
%   y <- (n:1)/(n+1)
%   clty <- as.character(ltys)
%   mytext <- function(x, y, txt)
%      text(x, y, txt, adj = c(0, -.3), cex = 0.8, ...)
%   abline(h = y, lty = ltys, ...); mytext(xoff, y, clty)
%   y <- y - 1/(3*(n+1))
%   abline(h = y, lty = ltys, lwd = 2, ...)
%   mytext(1/8+xoff, y, paste(clty," lwd = 2"))
%}
%showLty(c("solid", "dashed", "dotted", "dotdash", "longdash", "twodash"))
%par(new = TRUE)  # the same:
%showLty(c("solid", "44", "13", "1343", "73", "2262"), xoff = .2, col = 2)
%showLty(c("11", "22", "33", "44",   "12", "13", "14",   "21", "31"))
%}
%\keyword{iplot}
%\keyword{dplot}
%\keyword{environment}
%
%\encoding{UTF8}
%