% File src/library/graphics/man/plotfactor.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{plot.factor}
\title{Plotting Factor Variables}
\usage{
\method{plot}{factor}(x, y, legend.text = NULL, \dots)
}
\alias{plot.factor}
\arguments{
    \item{x, y}{数値か因子．\code{y} は無いかもしれない．}
    \item{legend.text}{
      因子の \code{y} の場合に y 軸の注釈に使われる文字列ベクトル：
      既定値は \code{levels(y)}．
      これは \code{\link{spineplot}} の \code{yaxlabels} 引数を設定する．}
    \item{\dots}{
      \code{\link{barplot}},
      \code{\link{boxplot}}, \code{\link{spineplot}} 又は
      \code{\link{plot}} への適当な引数．
      これら全てはグラフィカルパラメータ(\code{\link{par}} を見よ)と
      \code{\link{title}} と \code{axes = FALSE} へ渡される注釈引数
      を除く全てを受け入れる．
      \code{type} はどれも受け入れない．}
}
\description{
  この関数は \emph{総称的}な \code{\link{plot}} の
  因子引数に対する散布図メソッドを実装する．

  もし \code{y} がなければ \code{\link{barplot}} が作られる．
  数値の \code{y} に対し画は \code{\link{boxplot}} が使われ，
  因子の \code{y} に対しては \code{\link{spineplot}} が示される．
  他の任意のタイプの \code{y} に対しては次の \code{plot} メソッドが呼び出される．
  これは通常 \code{\link{plot.default}} である．
}
\seealso{
    \code{\link{plot.default}}, \code{\link{plot.formula}},
    \code{\link{barplot}}, \code{\link{boxplot}}, \code{\link{spineplot}}.
}
\examples{
require(grDevices)
% this does not call plot.factor!
% plot(PlantGrowth)                                # -> plot.data.frame
plot(weight ~ group, data = PlantGrowth)           # 数値ベクトル ~ 因子
plot(cut(weight, 2) ~ group, data = PlantGrowth)   # 因子 ~ 因子
## 最後に spineplot() に "..." を渡す
plot(cut(weight, 3) ~ group, data = PlantGrowth,
     col = hcl(c(0, 120, 240), 50, 70))

plot(PlantGrowth$group, axes = FALSE, main = "no axes")  # 極めて馬鹿げている
}
\keyword{hplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/plotfactor.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot.factor}
%\title{Plotting Factor Variables}
%\usage{
%\method{plot}{factor}(x, y, legend.text = NULL, \dots)
%}
%\alias{plot.factor}
%\arguments{
%    \item{x, y}{numeric or factor. \code{y} may be missing.}
%    \item{legend.text}{character vector for annotation of y axis in the
%      case of a factor \code{y}: defaults to \code{levels(y)}.  This
%      sets the \code{yaxlabels} argument of \code{\link{spineplot}}.}
%    \item{\dots}{Further arguments to \code{\link{barplot}},
%      \code{\link{boxplot}}, \code{\link{spineplot}} or
%      \code{\link{plot}} as appropriate.  All of these accept
%      \link{graphical parameters} (see \code{\link{par}}) and
%      annotation arguments passed
%      to \code{\link{title}} and \code{axes = FALSE}.  None accept \code{type}.
%    }
%}
%\description{
%  This functions implements a scatterplot method for
%  \code{\link{factor}} arguments of the \emph{generic}
%  \code{\link{plot}} function.
%
%  If \code{y} is missing \code{\link{barplot}} is produced.
%  For numeric \code{y} a \code{\link{boxplot}} is used, and for a factor
%  \code{y} a \code{\link{spineplot}} is shown.  For any other type of
%  \code{y} the next \code{plot} method is called, normally
%  \code{\link{plot.default}}.
%}
%\seealso{
%    \code{\link{plot.default}}, \code{\link{plot.formula}},
%    \code{\link{barplot}}, \code{\link{boxplot}}, \code{\link{spineplot}}.
%}
%\examples{
%require(grDevices)
%% this does not call plot.factor!
%% plot(PlantGrowth)                                # -> plot.data.frame
%plot(weight ~ group, data = PlantGrowth)           # numeric vector ~ factor
%plot(cut(weight, 2) ~ group, data = PlantGrowth)   # factor ~ factor
%## passing "..." to spineplot() eventually:
%plot(cut(weight, 3) ~ group, data = PlantGrowth,
%     col = hcl(c(0, 120, 240), 50, 70))
%
%plot(PlantGrowth$group, axes = FALSE, main = "no axes")  # extremely silly
%}
%\keyword{hplot}
%
%\encoding{UTF8}
%