% File src/library/graphics/man/plothistogram.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{plot.histogram}
\alias{plot.histogram}
\alias{lines.histogram}
\title{Plot Histograms}
\description{
  これらは典型的に \code{\link{hist}} が作るクラス
  \code{"histogram"} のオブジェクトに対するメソッドである．
}
\usage{
\method{plot}{histogram}(x, freq = equidist, density = NULL, angle = 45,
               col = NULL, border = par("fg"), lty = NULL,
               main = paste("Histogram of",
                            paste(x$xname, collapse = "\n")),
               sub = NULL, xlab = x$xname, ylab,
               xlim = range(x$breaks), ylim = NULL,
               axes = TRUE, labels = FALSE, add = FALSE,
               ann = TRUE, \dots)

\method{lines}{histogram}(x, \dots)
}
\arguments{
  \item{x}{\code{histogram} オブジェクト，又は成分
    \code{density}, \code{mid}, 等を持つリスト，
    \code{x} の成分に関する情報については \code{\link{hist}} を見よ．}
  \item{freq}{論理値；もし \code{TRUE} ならば
    ヒストグラムグラフィックは頻度，つまり \code{x$counts} の表現を与える；
    もし \code{FALSE} ならば，\emph{相対}頻度
    (確率)，つまり \code{x$density} がプロットされる．
    等間隔の \code{breaks} に対しては既定は真で，さもなければ偽である．}
  \item{col}{棒を塗りつぶすのに使われる色．既定
    \code{NULL} は塗りつぶし無し．}
  \item{border}{棒の輪郭の色．}
  \item{angle, density}{棒の陰影線：\code{\link{rect}} を見よ．}
  \item{lty}{棒に使われる線種，\code{\link{lines}} も見よ．}
  \item{main, sub, xlab, ylab}{
    \code{title} へのこれらの引数はここでは有用な既定値を持つ．}
  \item{xlim, ylim}{意味のある既定値を x と y の値の範囲．}
  \item{axes}{論理値，軸を描くかどうか指示する．}
  \item{labels}{論理値又は文字列．
    もし \code{FALSE} でなければ追加で棒の上にラベルを書く；
    もし \code{TRUE} ならばカウントか丸められた密度を書く；
    もし \code{labels} が文字列ならばそれ自体を書く．}
  \item{add}{論理値．もし \code{TRUE} ならば，現在のプロットに
    棒だけが加えられる．
    これが \code{lines.histogram(*)} が実行することである．}
  \item{ann}{論理値．注釈(タイトルと軸タイトル)をプロットすべきか?}
  \item{\dots}{
    \code{title} と \code{axis} への追加のグラフィカルパラメータ．}
}
\details{
  \code{lines.histogram(*)} は
  \code{plot.histogram(*, add = TRUE)} と同じである．
}
\seealso{
  \code{\link{hist}},
  \code{\link{stem}},
  \code{\link{density}}.
}
\examples{
(wwt <- hist(women$weight, nclass = 7, plot = FALSE))
plot(wwt, labels = TRUE) # wwt$xname を使った既定の main & xlab
plot(wwt, border = "dark blue", col = "light blue",
     main = "Histogram of 15 women's weights", xlab = "weight [pounds]")

## インチキ "lines" 例，既定でないラベルを使う：
w2 <- wwt; w2$counts <- w2$counts - 1
lines(w2, col = "Midnight Blue", labels = ifelse(w2$counts, "> 1", "1"))
}
\keyword{hplot}
\keyword{iplot}

\encoding{UTF8}
