% File src/library/parallel/man/windows/mcdummies.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2014 R Core Team
% Distributed under GPL 2 or later

\name{mclapply}
\alias{mclapply}
\alias{pvec}
\alias{mcmapply}
\alias{mcMap}

\title{Serial versions of \code{mclapply}, \code{mcmapply} and \code{pvec}}
\description{
  これらはフォークが使えない Windows に対する簡単な
  \code{mcMap} そして \code{pvec} のバージョンである．
}
\usage{
mclapply(X, FUN, ..., mc.preschedule = TRUE, mc.set.seed = TRUE,
         mc.silent = FALSE, mc.cores = 1L,
         mc.cleanup = TRUE, mc.allow.recursive = TRUE)

mcmapply(FUN, ..., MoreArgs = NULL, SIMPLIFY = TRUE, USE.NAMES = TRUE,
        mc.preschedule = TRUE, mc.set.seed = TRUE,
        mc.silent = FALSE, mc.cores = 1L, mc.cleanup = TRUE)

mcMap(f, ...)

pvec(v, FUN, ..., mc.set.seed = TRUE, mc.silent = FALSE,
     mc.cores = 1L, mc.cleanup = TRUE)
}
\arguments{
  \item{X}{ベクトル(原子的又はリスト)か表現式のベクトル．
    他のオブジェクト(クラス付きオブジェクトを含む)は
    \code{\link{as.list}} で変換される．}
  \item{v}{操作対象のベクトル．}
  \item{FUN}{
     \code{X} 又は \code{v} の各要素に適用される関数，
     又は並列的にに \code{...} に適用されるもの．}
  \item{f}{並列的に \code{\dots} に適用される関数．}
  \item{...}{\code{mclapply} と \code{pvec} に対しては
     \code{FUN} への追加のオプション引数．
     \code{mcmapply} そして \code{mcMap} に対してはベクトルもしくはリストの
     入力：\code{\link{mapply}} を見よ．}
  \item{MoreArgs, SIMPLIFY, USE.NAMES}{\code{\link{mapply}} を見よ．}
  \item{mc.preschedule, mc.set.seed, mc.silent, mc.cleanup, mc.allow.recursive}{
    Windows では無視される．}
  \item{mc.cores}{使用するコア数，つまり最大幾つの子プロセスが
    同時に実行されるか．
    Windows では正確に 1 でなければならない(マスタープロセスを使う)．}
}

\details{
  \code{mclapply} は \code{\link{lapply}} を呼び出し，\code{pvec}
  は \code{FUN(v, ...)} の単一の呼び出しを作る．
  Unix 風システムでは \code{mc.cores > 1}
  が認められ並列計算を使う．
}

\value{
  \code{mclapply} に対しては
  \code{X} と同じ長さのリストで
  \code{X} で名前が付く．

  \code{mcmapply} に対してはリスト，ベクトル又は配列：
  \code{\link{mapply}} を見よ．

  \code{mcMap} に対してはリスト．

  \code{pvec} に対しては
  \code{v} と同じ長さのベクトル．
}

\seealso{
  \code{\link{parLapply}}, \code{\link{clusterMap}}.
}

\keyword{interface}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/parallel/man/windows/mcdummies.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mclapply}
%\alias{mclapply}
%\alias{pvec}
%\alias{mcmapply}
%\alias{mcMap}
%
%\title{Serial versions of \code{mclapply}, \code{mcmapply} and \code{pvec}}
%\description{
%  These are simple serial versions of \code{mclapply}, \code{mcmapply},
%  \code{mcMap}  and \code{pvec} for Windows where forking is not available.
%}
%\usage{
%mclapply(X, FUN, ..., mc.preschedule = TRUE, mc.set.seed = TRUE,
%         mc.silent = FALSE, mc.cores = 1L,
%         mc.cleanup = TRUE, mc.allow.recursive = TRUE)
%
%mcmapply(FUN, ..., MoreArgs = NULL, SIMPLIFY = TRUE, USE.NAMES = TRUE,
%        mc.preschedule = TRUE, mc.set.seed = TRUE,
%        mc.silent = FALSE, mc.cores = 1L, mc.cleanup = TRUE)
%
%mcMap(f, ...)
%
%pvec(v, FUN, ..., mc.set.seed = TRUE, mc.silent = FALSE,
%     mc.cores = 1L, mc.cleanup = TRUE)
%}
%\arguments{
%  \item{X}{a vector (atomic or list) or an expressions vector.  Other
%    objects (including classed objects) will be coerced by
%    \code{\link{as.list}}.}
%  \item{v}{vector to operate on.}
%  \item{FUN}{the function to be applied to each element of \code{X} or
%     \code{v}, or in parallel to \code{...} .}
%  \item{f}{the function to be applied in parallel to \code{\dots}.}
%  \item{...}{For \code{mclapply} and \code{pvec}, optional arguments to
%     \code{FUN}.  For \code{mcmapply} and \code{mcMap}, vector or list
%     inputs: see \code{\link{mapply}}.}
%  \item{MoreArgs, SIMPLIFY, USE.NAMES}{see \code{\link{mapply}}.}
%  \item{mc.preschedule, mc.set.seed, mc.silent, mc.cleanup, mc.allow.recursive}{
%    Ignored on Windows.}
%  \item{mc.cores}{The number of cores to use, i.e.\sspace{}at most how many
%    child processes will be run simultaneously.   Must be exactly 1 on
%    Windows (which uses the master process).}
%}
%
%\details{
%  \code{mclapply} calls \code{\link{lapply}} and \code{pvec} makes a
%  single call \code{FUN(v, ...)}.   On Unix-alikes \code{mc.cores > 1}
%  is allowed and uses parallel operations.
%}
%
%\value{
%  For \code{mclapply}, a list of the same length as \code{X} and named
%  by \code{X}.
%
%  For \code{mcmapply}, a list, vector or array: see
%  \code{\link{mapply}}.
%
%  For \code{mcMap}, a list.
%
%  For \code{pvec}, a vector of the same length as \code{v}.
%}
%
%\seealso{
%  \code{\link{parLapply}}, \code{\link{clusterMap}}.
%}
%
%\keyword{interface}
%
%\encoding{UTF8}
%